* Diese Datei: panel_12131415_v1.do (02/2020)
*    https://www.gesis.org/missy/files/documents/MZ/panel_12131415_v1.do
* Dateiformat: Dos/Windows
* Zeichensatz: Unicode (UTF-8)

/* =============================================================================
Zusammenführung der Daten Mikrozensus Scientific Use File 2012 bis 2015
zu einem Panel
  
Siehe 
Herter-Eschweiler/Schimpl-Neimanns (2018): Möglichkeiten der Verknüpfung von
Mikrozensus-Querschnittserhebungen ab 2012 zu Panels. Bonn/Mannheim.
 https://www.gesis.org/missy/files/documents/MZ/panelbildung_suf2012.pdf
 
3.  Panelbildung
3.1 Version 1 (Längsschnittorientierung)
    Für die Analyse von Brutto-Veränderungen und Verlaufsdatenanalysen 
	
------------------------------------------------------------------------------
Programmstruktur

1   Aufbereitung der Querschnittdaten SUF MZ 2012 ff.
      Erstellung des Personenidentifkators ohne Kennung des Jahresüberhangs
      Prüfung auf doppelte IDs
      Zuordnung der Jahresüberhänge aus Erhebung t zu t-1

2   Files untereinander Stellen (long format)
      Prüfung auf doppelte Fälle und Datenbereinigung
      Ausschluss doppelter Sätze pro Panelzeitpunkt
      Kennzeichnung der Ausfallsätze
      Ermittlung der Anzahl der Sätze mit Angaben zum Panelzeitpunkt
      Fortlaufende Satznummer pro Panel-ID erstellen

3   Typisierung zum Ausfall erstellen
      Erste Ausfallanalysen

4   Files nebeneinander stellen (wide format)
      Weitere Ausfallanalysen
	  
5   Beispielanalysen zur Antwortkonsistenz (Geschlecht und Geburtsjahr)

---
Das Programm orientiert sich eng an der Version für die Zusammenführung der 
Daten 2012 und 2013, siehe 
https://www.gesis.org/missy/files/documents/MZ/panel_1213_v1.do .
Die Änderungen betreffen insbesondere die Typisierungen (ptyp* und ausftyp).
Um Platz zu sparen werden die zeitbezogenen Angaben für Personen und 
Auswahlbezirke nicht mehr mit zwei, sondern nur noch mit einer Stelle 
angegeben (z. B. für den Panelzeitpunkt 2012, alt: "12"; neu: "2"). 
---

Programmautor: Bernhard Schimpl-Neimanns

============================================================================= */

* Stata 15.1

set dp comma

* Arbeitsverzeichnis eintragen, z.B: cd "c:\temp" 
cd <Arbeitsverzeichnis>

* Dateiname ggf. ändern
log using panel_12131415_v1.log, text replace

/* 
1   Aufbereitung der Querschnittdaten SUF MZ 2012 ff.

1.1 Aufbereitung SUF MZ 2012 - Variablenauswahl
    Die Dateinamen entsprechen 
       https://www.gesis.org/missy/files/documents/MZ/setups/stata/setup12.do.
    In Anpassung an vorliegende Daten ggf. Variablennamen von Groß- in 
       Kleinschreibung ändern. */
use EF1   /// Bundesland 
    EF3   /// Nr. des Auswahlbezirks (systemfrei)
    EF4   /// Nr. des Haushalts im Auswahlbezirk (systemfrei)
    EF5b  /// Jahresüberhang aus dem Vorjahr
    EF12  /// Berichtsquartal
    EF63  /// Personennummer  
    EF5a  /// Nr. der Person im Haushalt (systemfrei)
    EF30  /// Bevölkerung: Haupt- oder Nebenwohnsitz
    EF31  /// Bevölkerung: Privathaushalte
    EF45  /// Zuzug (i. d. letzten 12 Monaten)
    EF46  /// Geschlecht
    EF47  /// Geburtsjahr
    EF451 /// Selber Wohnsitz (vor einem Jahr) (FB)
    EF952 /// Standardhochrechnungsfaktor Jahr (in 1000) - neuer Hochrechnungsrahmen
    id    /// Identifikationsnummer
 using <Vollstädiger Dateiname SUF MZ 2012>, replace

* Variablennamen Groß- => Kleinschreibung
renpfix EF ef

rename id id12

* Auswahl für Panel: Ohne Jahresüberhänge (ef5b = 1, 2), die gemäß 
*         Stichprobenplan zu 2011 zählen.
keep if ef5b==0
* n = 498.033 

* Vorbereitung der Identifkatoren für das Zusammenführen der Querschnitte
tostring ef1  , generate(s1)  format(%02.0f)
tostring ef3  , generate(s3)  format(%06.0f)
tostring ef5b , generate(s5b) format(%02.0f)
tostring ef12 , generate(s12) format(%01.0f)
tostring ef4  , generate(s4)  format(%03.0f)
tostring ef63 , generate(s63) format(%02.0f)

* ID Person ohne Kennungen für Jahresüberhänge 
*    Verkettung der Ordnungsnummern zum alphanumerischen Indikator idpers
generate idpers = s1 + s3 + s4 + s63
lab var idpers "ID Person (ef1 ef3 ef4 ef63)"

* Doppelte IDs ?
sort idpers
egen n_idpers = total(ef1>=1 & ef1<=16), by(idpers)
tab n_idpers, miss
* ok
drop n_idpers

* Zuordnung der Jahresüberhänge zu t-1
gen file = 1
format file %1.0f
lab var file "Datenquelle"
lab def file 1 "2012 (ef5b=0)" ///
             2 "2012 <- 2013 (ef5b=1,2)" ///
             3 "2013 (ef5b=0,-7)"
lab val file file

sort file idpers

* Dateiname ggf. ändern
save suf12_1.dta, replace
* n = 498.033

* =============================================================================

/* 
1.2 Aufbereitung SUF MZ 2013, Variablenauswahl
    Die Dateinamen entsprechen
       https://www.gesis.org/missy/files/documents/MZ/setups/stata/setup13.do.
    In Anpassung an vorliegende Daten ggf. Variablennamen von Groß- in 
       Kleinschreibung ändern.
*/	 
use EF1   /// Bundesland 
    EF3   /// Nr. des Auswahlbezirks (systemfrei)
    EF4   /// Nr. des Haushalts im Auswahlbezirk (systemfrei)
    EF5b  /// Jahresüberhang aus dem Vorjahr
    EF12  /// Berichtsquartal
    EF63  /// Personennummer  
    EF5a  /// Nr. der Person im Haushalt (systemfrei)
    EF30  /// Bevölkerung: Haupt- oder Nebenwohnsitz
    EF31  /// Bevölkerung: Privathaushalte
    EF45  /// Zuzug (i. d. letzten 12 Monaten)
    EF46  /// Geschlecht
    EF47  /// Geburtsjahr
    EF451 /// Selber Wohnsitz (vor einem Jahr) (FB)
    EF952 /// Standardhochrechnungsfaktor Jahr (in 1000) - neuer Hochrechnungsrahmen
    id    /// Identifikationsnummer
  using <Vollstädiger Dateiname SUF MZ 2013>, replace

* Variablennamen Groß- => Kleinschreibung
renpfix EF ef
 
rename id id13
 
* Vorbereitung der Identifkatoren für das Zusammenführen der Querschnitte
tostring ef1  , generate(s1)  format(%02.0f)
tostring ef3  , generate(s3)  format(%06.0f)
tostring ef5b , generate(s5b) format(%02.0f)
tostring ef12 , generate(s12) format(%01.0f)
tostring ef4  , generate(s4)  format(%03.0f)
tostring ef63 , generate(s63) format(%02.0f)

* ID Person ohne Kennungen für Jahresüberhänge 
*    Verkettung der Ordnungsnummern zum alphanumerischen Indikator idpers
generate idpers = s1 + s3 + s4 + s63
lab var idpers "ID Person (ef1 ef3 ef4 ef63)"

* Zuordnung der Jahresüberhänge zu t-1 => 2012, sonst => 2013
recode ef5b (1 2 = 2) (* = 3), gen(file)
format file %1.0f
lab var file "Datenquelle"
lab def file 1 "2012 (ef5b=0)" ///
             2 "2012 <- 2013 (ef5b=1,2)" ///
             3 "2013 (ef5b=0,-7)"
lab val file file

* Doppelte IDs pro Panelzeitpunkt (file)?
sort idpers file
egen n_idpers = total(ef1>=1 & ef1<=16), by(idpers file)
tab n_idpers, miss

list idpers id13 ef12 ef5b if n_idpers==2, noobs nol sepby(idpers)
* Datenbereinigung - betrifft nur Ausfallsätze mit doppelter Panelzeit (file)
replace file = -1 if (id13==55626)
replace file = -1 if (id13==126328)
replace file = -1 if (id13==384549)
replace file = -1 if (id13==385396)
replace file = -1 if (id13==390124)
lab def file -1 "doppelte Sätze: 2013, ef5b=-7",  add modify

drop n_idpers

sort file idpers

* Dateiname ggf. ändern
save suf13_1.dta, replace
* n = 525.787 

* =============================================================================

/* 
1.3 Aufbereitung SUF MZ 2014, Variablenauswahl
    Die Dateinamen entsprechen 
       https://www.gesis.org/missy/files/documents/MZ/setups/stata/setup14.do.
    In Anpassung an vorliegende Daten ggf. Variablennamen von Groß- in 
       Kleinschreibung ändern.
*/	 
use EF1   /// Bundesland 
    EF3   /// Nr. des Auswahlbezirks (systemfrei)
    EF4   /// Nr. des Haushalts im Auswahlbezirk (systemfrei)
    EF5b  /// Jahresüberhang aus dem Vorjahr
    EF12  /// Berichtsquartal
    EF63  /// Personennummer  
    EF5a  /// Nr. der Person im Haushalt (systemfrei)
    EF30  /// Bevölkerung: Haupt- oder Nebenwohnsitz
    EF31  /// Bevölkerung: Privathaushalte
    ef45  /// Zuzug (i. d. letzten 12 Monaten)
    EF46  /// Geschlecht
    ef47  /// Geburtsjahr
    EF451 /// Selber Wohnsitz (vor einem Jahr) (FB)
    ef952 /// Standardhochrechnungsfaktor Jahr (in 1000) - neuer Hochrechnungsrahmen
    id    /// Identifikationsnummer
 using <Vollstädiger Dateiname SUF MZ 2014>, replace

* Variablennamen Groß- => Kleinschreibung
renpfix EF ef
 
rename id id14
 
* Vorbereitung der Identifkatoren für das Zusammenführen der Querschnitte
tostring ef1  , generate(s1)  format(%02.0f)
tostring ef3  , generate(s3)  format(%06.0f)
tostring ef5b , generate(s5b) format(%02.0f)
tostring ef12 , generate(s12) format(%01.0f)
tostring ef4  , generate(s4)  format(%03.0f)
tostring ef63 , generate(s63) format(%02.0f)

* ID Person ohne Kennungen für Jahresüberhänge 
*    Verkettung der Ordnungsnummern zum alphanumerischen Indikator idpers
generate idpers = s1 + s3 + s4 + s63
lab var idpers "ID Person (ef1 ef3 ef4 ef63)"

* Zuordnung der Jahresüberhänge zu t-1 => 2013, sonst => 2014
recode ef5b (1 2 = 4) (* = 5), gen(file)
format file %1.0f
lab var file "Datenquelle"
lab def file 1 "2012 (ef5b=0)" ///
             2 "2012 <- 2013 (2013: ef5b=1,2)" ///
             3 "2013 (2013: ef5b<=0" ///
			 4 "2013 <- 2014 (2014: ef5b=1,2)" ///
			 5 "2014 (2014: ef5b<=0)"
lab val file file

* Doppelte IDs pro Panelzeitpunkt (file)?
sort idpers file
egen n_idpers = total(ef1>=1 & ef1<=16), by(idpers file)
tab n_idpers file, miss nolab

tab ef5b ef30 if n_idpers==2, nol

* Datenbereinigung - betrifft nur Ausfallsätze mit doppelter Panelzeit (file)
* Satz mit niedrigerem Quartal als doppelt kennzeichnen
egen min_idpers = min(ef12) if n_idpers==2, by(idpers file)
replace file = -2 if (ef12==min_idpers) & n_idpers==2

drop n_idpers
egen n_idpers = total(ef1>=1 & ef1<=16), by(idpers file)

* Korrektur
replace file = 5 if id14==351460 | id14==354667
lab def file -2 "doppelte Sätze: 2014, ef5b=-8",  add modify

drop n_idpers min_idpers

sort file idpers

* Dateiname ggf. ändern
save suf14_1.dta, replace
* n = 526.201

* =============================================================================

/* 
1.4 Aufbereitung SUF MZ 2015, Variablenauswahl
    Die Dateinamen entsprechen 
       https://www.gesis.org/missy/files/documents/MZ/setups/stata/setup15.do.
    In Anpassung an vorliegende Daten ggf. Variablennamen von Groß- in 
       Kleinschreibung ändern.
*/	 
use EF1   /// Bundesland 
    EF3   /// Nr. des Auswahlbezirks (systemfrei)
    EF4   /// Nr. des Haushalts im Auswahlbezirk (systemfrei)
    EF5b  /// Jahresüberhang aus dem Vorjahr
    EF12  /// Berichtsquartal
    EF63  /// Personennummer  
    EF5a  /// Nr. der Person im Haushalt (systemfrei)
    EF30  /// Bevölkerung: Haupt- oder Nebenwohnsitz
    EF31  /// Bevölkerung: Privathaushalte
    EF45  /// Zuzug (i. d. letzten 12 Monaten)
    EF46  /// Geschlecht
    EF47  /// Geburtsjahr
    EF451 /// Selber Wohnsitz (vor einem Jahr) (FB)
    EF952 /// Standardhochrechnungsfaktor Jahr (in 1000) - neuer Hochrechnungsrahmen
    id    /// Identifikationsnummer
  using <Vollstädiger Dateiname SUF MZ 2015>, replace

* Variablennamen Groß- => Kleinschreibung
renpfix EF ef
 
rename id id15
 
* Vorbereitung der Identifkatoren für das Zusammenführen der Querschnitte
tostring ef1  , generate(s1)  format(%02.0f)
tostring ef3  , generate(s3)  format(%06.0f)
tostring ef5b , generate(s5b) format(%02.0f)
tostring ef12 , generate(s12) format(%01.0f)
tostring ef4  , generate(s4)  format(%03.0f)
tostring ef63 , generate(s63) format(%02.0f)

* ID Person ohne Kennungen für Jahresüberhänge 
*    Verkettung der Ordnungsnummern zum alphanumerischen Indikator idpers
generate idpers = s1 + s3 + s4 + s63
lab var idpers "ID Person (ef1 ef3 ef4 ef63)"

* Zuordnung der Jahresüberhänge zu t-1 => 2014, sonst => 2015
recode ef5b (1 2 = 6) (* = 7), gen(file)
format file %1.0f
lab var file "Datenquelle"
lab def file 1 "2012 (ef5b=0)" ///
             2 "2012 <- 2013 (2013: ef5b=1,2)" ///
             3 "2013 (2013: ef5b<=0" ///
			 4 "2013 <- 2014 (2014: ef5b=1,2)" ///
			 5 "2014 (2014: ef5b<=0)" ///
			 6 "2014 <- 2015 (2015: ef5b=1,2)" ///
             7 "2015 (2015: ef5b<=0)"
lab val file file

* Doppelte IDs pro Panelzeitpunkt (file)?
sort idpers file
egen n_idpers = total(ef1>=1 & ef1<=16), by(idpers file)
tab n_idpers file, miss nolab

tab ef5b ef30 if n_idpers==2, nol // OK, no observations

drop n_idpers

sort file idpers

* Dateiname ggf. ändern
save suf15_1.dta, replace
* n = 531.738

* =============================================================================

* 2 Files untereinander stellen (long format)

clear

append using suf12_1.dta suf13_1.dta suf14_1.dta suf15_1.dta, gen(ejahr)

* numlabel EF45_VL, add mask("[#] ") force

lab var ejahr "Erhebungsjahr"
lab def ejahr 1 "2012" ///  ohne Jahresüberhänge
              2 "2013" ///
              3 "2014" ///
			  4 "2015"
lab val ejahr ejahr
numlabel ejahr, add mask("[#] ") force

lab def file 1 "2012 (ef5b=0)" ///
             2 "2012 <- 2013 (2013: ef5b=1,2)" ///
             3 "2013 (2013: ef5b<=0" ///
             4 "2013 <- 2014 (2014: ef5b=1,2)" ///
             5 "2014 (2014: ef5b<=0)" ///
             6 "2014 <- 2015 (2015: ef5b=1,2)" ///
             7 "2015 (2015: ef5b<=0)" ///
            -1 "doppelte Sätze: 2013, ef5b=-7" ///
            -2 "doppelte Sätze: 2014, ef5b=-8",  add modify
numlabel file, add mask("[#] ") force

lab def EF5b_VL -8 "Entfällt (leerstehende Wohnung, ausgefallene Privathaushalte und Gemeinschaftsunterkünfte)" ///
                -7 "Entfällt (Auswahlbezirk ohne befragten Haushalt)", add modify

* === Datenbereinigungen === 
* Prüfung auf doppelte Fälle und Datenbereinigung. 
* Datenbereinigung betrifft nur Sätze mit doppelter Panelzeit (file).
* Die einzelnen Schritte der Dateninspektion werden aus Platzgründen nicht 
* dargestellt.

replace file = -3 if (id13==74945)  
replace file = -3 if (id13==128105)
replace file = -3 if (id13==225706)
* MZ 2015
replace file = -4 if (id15==175755)
replace file = -4 if (id15==175756)

lab def file -3 "doppelte Sätze: 2013|2012, 2013: ef5b=1" ///
             -4 "doppelte Sätze: 2015|2014, 2015: ef5b=1", add modify
numlabel file, add mask("[#] ") force

/* -----------------------------------------------------------------------------
Bei Dateninspektionen ist aufgefallen, dass im Unterschied zum MZ 2014 im 
MZ 2015 in Variable EF5b die Jahresüberhänge bzw. Ausfallsätze nicht mit 
 -8 oder -7 recodiert sind. 
Die Angaben im MZ 2015 sind deshalb in Bezug auf Haushalte des Jahresüberhangs
informativer. 
Dies spricht dafür, bei doppelten Fällen die Angaben zum Jahresüberhang 
(ef5b=1,2) aus dem MZ 2015 (ejahr=4) als Angaben zum Panelzeitpunkt 2014 zu 
verwenden und die Angaben der Ausfallsätze (EF5b<0) aus dem MZ 2014 (ejahr=3) 
als 2013 zu befragende Jahresüberhänge zu codieren. */

egen n_t3 = total(file>=5 & file<=6), by(idpers) // Panelzeitpunkt 2014
tab n_t3 ef5b, miss
* n=1.238 doppelte Nennungen (n_t3=2) bei Ausfallsätzen (ausfall=1)

tab file ef5b if n_t3==2

* doppelte Ausfallsätze 
replace file = 4 if (ejahr==3 & file>=5 & file<=6 & n_t3==2 & ef5b<0)
* Ausnahmen
replace file = -4 if ejahr==3 & file==4 & id14==539591
replace file = -4 if ejahr==3 & file==4 & id14==539592

drop n_t3

tab file, m
/*                          Datenquelle |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
[-4] doppelte Sätze: 2015|2014, 2015: e |          4        0,00        0,00
[-3] doppelte Sätze: 2013|2012, 2013: e |          3        0,00        0,00
     [-2] doppelte Sätze: 2014, ef5b=-8 |        672        0,03        0,03
     [-1] doppelte Sätze: 2013, ef5b=-7 |          5        0,00        0,03
                      [1] 2012 (ef5b=0) |     498033       23,92       23,96
      [2] 2012 <- 2013 (2013: ef5b=1,2) |      16534        0,79       24,75
               [3] 2013 (2013: ef5b=<=0 |     509245       24,46       49,21
      [4] 2013 <- 2014 (2014: ef5b=1,2) |      18654        0,90       50,11
               [5] 2014 (2014: ef5b<=0) |     506873       24,35       74,46
      [6] 2014 <- 2015 (2015: ef5b=1,2) |      20733        1,00       75,45
               [7] 2015 (2015: ef5b<=0) |     511003       24,55      100,00
----------------------------------------+-----------------------------------
                                  Total |    2081759      100,00
*/

* ------------------------------------------------------------------------------

* Doppelte Fälle ausschließen
keep if (file>=1 & file<=7)
* n = 2.081.075

* Kennzeichnung der Ausfallsätze 
gen ausfall = (ef63<0 | ef5b<0 | ef31<0)
lab var ausfall "Ausfallsatz (ef63<0 | ef5b<0 | ef31<0)"
lab def ausfall 0 "nein" 1 "ja"
format ausfall %1.0f

* Für jede Panel-ID (idpers) Anzahl der Sätze mit Angaben zu den Paneljahren
*   ermitteln.
* Sortierfolge "idpers ausfall file": Befragtensätze stehen vor Ausfallsätzen.
sort idpers ausfall file

* Satznummer pro idpers 
bysort idpers : gen p1 = _n
lab var p1 "Satznummer zu idpers"
format p1 %2.0f

gen t1 = (file>=1 & file<=2) // Angaben zu 2012: 0=nein, 1=ja
gen t2 = (file>=3 & file<=4) //            2013
gen t3 = (file>=5 & file<=6) //            2014
gen t4 = (file==7)           //            2015
format t1 t2 t3 t4 %1.0f

egen n_t1 = total(t1), by(idpers)
egen n_t2 = total(t2), by(idpers)
egen n_t3 = total(t3), by(idpers)
egen n_t4 = total(t4), by(idpers)

* Kontrolle: pro Panelzeitpunkt max. 1 Satz?
summ n_t*

sort idpers ausfall file

* Angaben zu den Panelzeitpunkten pro Panel-ID 
generate ptyp = .	
replace ptyp =  0 if n_t1==1 & n_t2==1 & n_t3==1 & n_t4==1
replace ptyp =  1 if n_t1==1 & n_t2==0 & n_t3==0 & n_t4==0
replace ptyp =  2 if n_t1==1 & n_t2==1 & n_t3==0 & n_t4==0
replace ptyp =  3 if n_t1==1 & n_t2==1 & n_t3==1 & n_t4==0
replace ptyp =  4 if n_t1==1 & n_t2==1 & n_t3==0 & n_t4==1
replace ptyp =  5 if n_t1==1 & n_t2==0 & n_t3==1 & n_t4==0
replace ptyp =  6 if n_t1==1 & n_t2==0 & n_t3==1 & n_t4==1
replace ptyp =  7 if n_t1==1 & n_t2==0 & n_t3==0 & n_t4==1
replace ptyp =  8 if n_t1==0 & n_t2==1 & n_t3==0 & n_t4==0
replace ptyp =  9 if n_t1==0 & n_t2==1 & n_t3==1 & n_t4==0
replace ptyp = 10 if n_t1==0 & n_t2==1 & n_t3==1 & n_t4==1
replace ptyp = 11 if n_t1==0 & n_t2==1 & n_t3==0 & n_t4==1
replace ptyp = 12 if n_t1==0 & n_t2==0 & n_t3==1 & n_t4==0
replace ptyp = 13 if n_t1==0 & n_t2==0 & n_t3==1 & n_t4==1
replace ptyp = 14 if n_t1==0 & n_t2==0 & n_t3==0 & n_t4==1

lab def ptyp 0 "2345"  1 "2---"  2 "23--"  3 "234-"  4 "23-5"  5 "2-4-"  ///
             6 "2-45"  7 "2--5"  8 "-3--"  9 "-34-" 10 "-345" 11 "-3-5" ///
            12 "--4-" 13 "--45" 14 "---5", add modify
lab var ptyp "Panelsätze - Personenebene (incl. Ausfallsätze) 201*"
lab val ptyp ptyp
format ptyp %1.0f
numlabel ptyp, add mask("[#] ") force
tab ptyp, miss
/*
 Panelsätze |
          - |
Personenebe |
  ne (incl. |
 Ausfallsät |
        ze) |      Freq.     Percent        Cum.
------------+-----------------------------------
   [0] 2345 |     363336       17,46       17,46
   [1] 2--- |     174783        8,40       25,86
   [2] 23-- |     270422       12,99       38,85
   [3] 234- |     334800       16,09       54,94
   [4] 23-5 |       1662        0,08       55,02
   [5] 2-4- |       2244        0,11       55,13
   [6] 2-45 |       1182        0,06       55,18
   [7] 2--5 |        138        0,01       55,19
   [8] -3-- |      87416        4,20       59,39
   [9] -34- |      46260        2,22       61,61
  [10] -345 |     235461       11,31       72,93
  [11] -3-5 |       1334        0,06       72,99
  [12] --4- |      64831        3,12       76,11
  [13] --45 |     314416       15,11       91,22
  [14] ---5 |     182790        8,78      100,00
------------+-----------------------------------
      Total |    2081075      100,00
*/

* =============================================================================

* 3 Typisierung zum Ausfall erstellen

* === PSU-Ebene === 
* ID Auswahlbezirk
generate idpsu = s1 + s3
lab var idpsu "ID Auswahlbezirk (ef1 ef3)"

* 1. Satz eines Auswahlbezirks
*    Nach Sortierung stehen Ausfallsätze nach Sätzen befragter Personen
sort idpsu ausfall idpers ptyp
bysort idpsu : gen psu_1 = _n
lab var psu_1 "1. Satz eines Auswahlbezirks (PSU)"
format psu_1 %3.0f
tab psu_1 if psu_1==1 & ausfall==0 & ef63<0, miss
* no observations: ok

* Ausfallgrund "Wechsel der Rotationsgruppe" näherungsweise ermitteln
* Nur für Sätze, die in EF4 oder EF5b gültige Werte aufweisen, d. h. bei
*   Ausfallsätzen werden Sätze ausgeschlossen, die in EF4 oder EF5b mit 
*   -7 oder -8 codiert sind.
sort idpsu ausfall idpers ptyp 

egen n_psu12 = total(t1==1 & ef5b>=0 & ef5b<=2 & ef4>=0 & ef4<=999), by(idpsu)
egen n_psu13 = total(t2==1 & ef5b>=0 & ef5b<=2 & ef4>=0 & ef4<=999), by(idpsu)
egen n_psu14 = total(t3==1 & ef5b>=0 & ef5b<=2 & ef4>=0 & ef4<=999), by(idpsu)
egen n_psu15 = total(t4==1 & ef5b>=0 & ef5b<=2 & ef4>=0 & ef4<=999), by(idpsu)

lab var n_psu12 "Anzahl gültige Sätze 2012 im Auswahlbezirk" // Panelzeitpunkte
lab var n_psu13 "Anzahl gültige Sätze 2013 im Auswahlbezirk"
lab var n_psu14 "Anzahl gültige Sätze 2014 im Auswahlbezirk"
lab var n_psu15 "Anzahl gültige Sätze 2015 im Auswahlbezirk"

format n_psu12 n_psu13 n_psu14 n_psu15 %3.0f

generate ptyp_psu = .
replace ptyp_psu =  0 if n_psu12>=1  & n_psu13>=1 & n_psu14>=1 & n_psu15>=1
replace ptyp_psu =  1 if n_psu12>=1  & n_psu13==0 & n_psu14==0 & n_psu15==0
replace ptyp_psu =  2 if n_psu12>=1  & n_psu13>=1 & n_psu14==0 & n_psu15==0
replace ptyp_psu =  3 if n_psu12>=1  & n_psu13>=1 & n_psu14>=1 & n_psu15==0
replace ptyp_psu =  4 if n_psu12>=1  & n_psu13>=1 & n_psu14==0 & n_psu15>=1
replace ptyp_psu =  5 if n_psu12>=1  & n_psu13==0 & n_psu14>=1 & n_psu15==0
replace ptyp_psu =  6 if n_psu12>=1  & n_psu13==0 & n_psu14>=1 & n_psu15>=1
replace ptyp_psu =  7 if n_psu12>=1  & n_psu13==0 & n_psu14==0 & n_psu15>=1
replace ptyp_psu =  8 if n_psu12==0  & n_psu13>=1 & n_psu14==0 & n_psu15==0
replace ptyp_psu =  9 if n_psu12==0  & n_psu13>=1 & n_psu14>=1 & n_psu15==0
replace ptyp_psu = 10 if n_psu12==0  & n_psu13>=1 & n_psu14>=1 & n_psu15>=1
replace ptyp_psu = 11 if n_psu12==0  & n_psu13>=1 & n_psu14==0 & n_psu15>=1
replace ptyp_psu = 12 if n_psu12==0  & n_psu13==0 & n_psu14>=1 & n_psu15==0
replace ptyp_psu = 13 if n_psu12==0  & n_psu13==0 & n_psu14>=1 & n_psu15>=1
replace ptyp_psu = 14 if n_psu12==0  & n_psu13==0 & n_psu14==0 & n_psu15>=1
replace ptyp_psu = -1 if ptyp_psu==. & ausfall==1 // := if n_psu12==0 & n_psu13==0 & n_psu14==0 & n_psu15==0

lab var ptyp_psu "Panelsätze - PSU-Ebene (ohne Ausfallsätze: ef63<0 | ef5b<0 | ef31<0)"
lab def ptyp_psu 0 "2345"  1 "2---"  2 "23--"  3 "234-"  4 "23-5"  5 "2-4-"  ///
                 6 "2-45"  7 "2--5"  8 "-3--"  9 "-34-" 10 "-345" 11 "-3-5" ///
                12 "--4-" 13 "--45" 14 "---5" -1 "Ausfallsatz", add modify
format ptyp_psu %10.0f
lab val ptyp_psu ptyp_psu
numlabel ptyp_psu, add mask("[#] ") force

tab ptyp_psu, miss
/*               Freq.
------------------------
 -1 Ausfallsatz 12998
  0 2345       514534
  1 2---       128531
  2 23--       265190
  3 234-       387740
  4 23-5          427
  5 2-4-           21
  8 -3--        38267
  9 -34-         2677
 10 -345       285486
 11 -3-5          178
 12 --4-         1674
 13 --45       319413
 14 ---5       123939
---------------------
 Total       2081075 
*/

* t*_psu : Panelzeitpunkte eines Auswahlbezirks (1. Satz einer PSU, ohne 
*          Ausfallsätze, die in EF4 oder EF5b mit -7 oder -8 codiert sind.) 
recode n_psu12 (0=0) (1/400=1) if psu_1==1, gen(t1_psu)
lab var t1_psu "PSU in 2012  (ohne Ausfallsätze, 1. PSU-Satz)"

recode n_psu13 (0=0) (1/400=1) if psu_1==1, gen(t2_psu)
lab var t2_psu "PSU in 2013 (ohne Ausfallsätze, 1. PSU-Satz)"

recode n_psu14 (0=0) (1/400=1) if psu_1==1, gen(t3_psu)
lab var t3_psu "PSU in 2014 (ohne Ausfallsätze, 1. PSU-Satz)"

recode n_psu15 (0=0) (1/400=1) if psu_1==1, gen(t4_psu)
lab var t4_psu "PSU in 2015 (ohne Ausfallsätze, 1. PSU-Satz)"


* Ausfalltypisierung: Angaben für Personen | Angaben für Auswahlbezirke
gen ausftyp = -1
* ptyp = ptyp_psu
replace ausftyp =  0 if (ptyp== 0 & ptyp_psu== 0) 
replace ausftyp =  1 if (ptyp== 1 & ptyp_psu== 1)
replace ausftyp =  2 if (ptyp== 2 & ptyp_psu== 2)
replace ausftyp =  3 if (ptyp== 3 & ptyp_psu== 3)
replace ausftyp =  4 if (ptyp== 4 & ptyp_psu== 4)
replace ausftyp =  5 if (ptyp== 8 & ptyp_psu== 8)
replace ausftyp =  6 if (ptyp== 9 & ptyp_psu== 9)
replace ausftyp =  7 if (ptyp==10 & ptyp_psu==10)
replace ausftyp =  8 if (ptyp==11 & ptyp_psu==11)
replace ausftyp =  9 if (ptyp==12 & ptyp_psu==12)
replace ausftyp = 10 if (ptyp==13 & ptyp_psu==13)
replace ausftyp = 11 if (ptyp==14 & ptyp_psu==14)
* ptyp < ptyp_psu
replace ausftyp = 12 if (ptyp== 1 & ptyp_psu== 2)
replace ausftyp = 13 if (ptyp== 1 & ptyp_psu== 3)
replace ausftyp = 14 if (ptyp== 1 & ptyp_psu== 4)
replace ausftyp = 15 if (ptyp== 1 & ptyp_psu== 5)
replace ausftyp = 16 if (ptyp== 2 & ptyp_psu== 3)
replace ausftyp = 17 if (ptyp== 2 & ptyp_psu== 4)
replace ausftyp = 18 if (ptyp== 8 & ptyp_psu== 9)
replace ausftyp = 19 if (ptyp== 8 & ptyp_psu==10)
replace ausftyp = 20 if (ptyp== 8 & ptyp_psu==11)
replace ausftyp = 21 if (ptyp== 9 & ptyp_psu==10)
replace ausftyp = 22 if (ptyp==12 & ptyp_psu==13)
* ptyp > ptyp_psu
replace ausftyp = 23 if (ptyp== 1 & ptyp_psu== 0)
replace ausftyp = 24 if (ptyp== 2 & ptyp_psu== 0)
replace ausftyp = 25 if (ptyp== 3 & ptyp_psu== 0)
replace ausftyp = 26 if (ptyp== 4 & ptyp_psu== 0)
replace ausftyp = 27 if (ptyp== 5 & ptyp_psu== 0)
replace ausftyp = 28 if (ptyp== 5 & ptyp_psu== 3)
replace ausftyp = 29 if (ptyp== 6 & ptyp_psu== 0)
replace ausftyp = 30 if (ptyp== 7 & ptyp_psu== 0)
replace ausftyp = 31 if (ptyp== 8 & ptyp_psu== 0)
replace ausftyp = 32 if (ptyp== 8 & ptyp_psu== 2)
replace ausftyp = 33 if (ptyp== 8 & ptyp_psu== 3)
replace ausftyp = 34 if (ptyp== 8 & ptyp_psu== 4)
replace ausftyp = 35 if (ptyp== 9 & ptyp_psu== 0)
replace ausftyp = 36 if (ptyp== 9 & ptyp_psu== 3)
replace ausftyp = 37 if (ptyp==10 & ptyp_psu== 0)
replace ausftyp = 38 if (ptyp==11 & ptyp_psu== 0)
replace ausftyp = 39 if (ptyp==11 & ptyp_psu==10)
replace ausftyp = 40 if (ptyp==12 & ptyp_psu== 0)
replace ausftyp = 41 if (ptyp==12 & ptyp_psu== 3)
replace ausftyp = 42 if (ptyp==12 & ptyp_psu== 5)
replace ausftyp = 43 if (ptyp==12 & ptyp_psu== 9)
replace ausftyp = 44 if (ptyp==12 & ptyp_psu==10)
replace ausftyp = 45 if (ptyp==13 & ptyp_psu== 0)
replace ausftyp = 46 if (ptyp==13 & ptyp_psu==10)
replace ausftyp = 47 if (ptyp==14 & ptyp_psu== 0)
replace ausftyp = 48 if (ptyp==14 & ptyp_psu== 4)
replace ausftyp = 49 if (ptyp==14 & ptyp_psu==10)
replace ausftyp = 50 if (ptyp==14 & ptyp_psu==11)
replace ausftyp = 51 if (ptyp==14 & ptyp_psu==13)
replace ausftyp = -1 if ausfall==1
lab var ausftyp "Ausfalltyp: Ausfall Satz | Angaben Auswahlbezirk (Proxy) 201*"
lab def ausftyp  0 "2345|2345" /// ptyp = ptyp_psu
                 1 "2---|2---" ///
                 2 "23--|23--" ///
                 3 "234-|234-" ///
                 4 "23-5|23-5" ///
                 5 "-3--|-3--" /// 
				 6 "-34-|-34-" ///
				 7 "-345|-345" ///
				 8 "-3-5|-3-5" ///
				 9 "--4-|--4-" ///
				10 "--45|--45" ///
				11 "---5|---5" ///
				12 "2---|23--" /// ptyp < ptyp_psu
				13 "2---|234-" ///
				14 "2---|23-5" ///
				15 "2---|2-4-" ///
				16 "23--|234-" ///
				17 "23--|23-5" ///
				18 "-3--|-34-" ///
				19 "-3--|-345" ///
				20 "-3--|-3-5" ///
				21 "-34-|-345" ///
				22 "--4-|--45" ///
				23 "2---|2345" /// ptyp > ptyp_psu
				24 "23--|2345" ///
				25 "234-|2345" ///
				26 "23-5|2345" ///
				27 "2-4-|2345" ///
				28 "2-4-|234-" ///
				29 "2-45|2345" ///
				30 "2--5|2345" ///
				31 "-3--|2345" ///
				32 "-3--|23--" ///
				33 "-3--|234-" ///
				34 "-3--|23-5" ///
				35 "-34-|2345" ///
				36 "-34-|234-" ///
				37 "-345|2345" ///
				38 "-3-5|2345" ///
				39 "-3-5|-345" ///
				40 "--4-|2345" ///
				41 "--4-|234-" ///
				42 "--4-|2-4-" ///
				43 "--4-|-34-" ///
				44 "--4-|-345" ///
				45 "--45|2345" ///
				46 "--45|-345" ///
				47 "---5|2345" ///
				48 "---5|23-5" ///
				49 "---5|-345" ///
				50 "---5|-3-5" ///
				51 "---5|--45" ///
                -1 "Ausfallsätze ef4<0 | ef5b<0 | ef63<0"
lab val ausftyp ausftyp
numlabel ausftyp, add mask("[#] ") force
format ausftyp %19.0f

tab ausftyp, m
/*   Ausfalltyp: Ausfall Satz | Angaben |
             Auswahlbezirk (Proxy) 201* |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
[-1] Ausfallsätze ef4<0 | ef5b<0 | ef63 |     173605        8,34        8,34
                          [0] 2345|2345 |     352348       16,93       25,27
                          [1] 2---|2--- |     120644        5,80       31,07
                          [2] 23--|23-- |     218504       10,50       41,57
                          [3] 234-|234- |     294330       14,14       55,71
                          [4] 23-5|23-5 |        111        0,01       55,72
                          [5] -3--|-3-- |      35843        1,72       57,44
                          [6] -34-|-34- |       1886        0,09       57,53
                          [7] -345|-345 |     203895        9,80       67,33
                          [8] -3-5|-3-5 |         54        0,00       67,33
                          [9] --4-|--4- |       1290        0,06       67,39
                         [10] --45|--45 |     262228       12,60       79,99
                         [11] ---5|---5 |     117580        5,65       85,64
                         [12] 2---|23-- |      13219        0,64       86,28
                         [13] 2---|234- |      12384        0,60       86,87
                         [14] 2---|23-5 |         30        0,00       86,88
                         [15] 2---|2-4- |          2        0,00       86,88
                         [16] 23--|234- |      19328        0,93       87,80
                         [17] 23--|23-5 |         56        0,00       87,81
                         [18] -3--|-34- |        190        0,01       87,82
                         [19] -3--|-345 |       9226        0,44       88,26
                         [20] -3--|-3-5 |         18        0,00       88,26
                         [21] -34-|-345 |      17482        0,84       89,10
                         [22] --4-|--45 |      18318        0,88       89,98
                         [23] 2---|2345 |      12651        0,61       90,59
                         [24] 23--|2345 |      19148        0,92       91,51
                         [25] 234-|2345 |      28338        1,36       92,87
                         [26] 23-5|2345 |        942        0,05       92,92
                         [27] 2-4-|2345 |        296        0,01       92,93
                         [28] 2-4-|234- |        862        0,04       92,97
                         [29] 2-45|2345 |       1020        0,05       93,02
                         [30] 2--5|2345 |        102        0,00       93,03
                         [31] -3--|2345 |       2710        0,13       93,16
                         [32] -3--|23-- |      11076        0,53       93,69
                         [33] -3--|234- |       2541        0,12       93,81
                         [34] -3--|23-5 |          3        0,00       93,81
                         [35] -34-|2345 |       3782        0,18       93,99
                         [36] -34-|234- |      17174        0,83       94,82
                         [37] -345|2345 |      22473        1,08       95,90
                         [38] -3-5|2345 |        204        0,01       95,91
                         [39] -3-5|-345 |        684        0,03       95,94
                         [40] --4-|2345 |       2609        0,13       96,07
                         [41] --4-|234- |      10287        0,49       96,56
                         [42] --4-|2-4- |          5        0,00       96,56
                         [43] --4-|-34- |        298        0,01       96,57
                         [44] --4-|-345 |       2877        0,14       96,71
                         [45] --45|2345 |      16352        0,79       97,50
                         [46] --45|-345 |      20266        0,97       98,47
                         [47] ---5|2345 |       9544        0,46       98,93
                         [48] ---5|23-5 |         58        0,00       98,93
                         [49] ---5|-345 |       7842        0,38       99,31
                         [50] ---5|-3-5 |         52        0,00       99,31
                         [51] ---5|--45 |      14308        0,69      100,00
----------------------------------------+-----------------------------------
                                  Total |    2081075      100,00
*/

/* ausftyp  Panelangaben zur Person | Auswahlbezirk 

         0  2345|2345 := Angaben zu 2012-2015 für Personen und Auswahlbez. 
		 
         1  2---|2--- := nur Angaben zu 2012 für Personen und Auswahlbez. 
                          ~ nicht informativer Ausfall (Rotationsgruppe ausgeschieden) ~

            (...)

        12  2---|23-- := Angaben nur zu 2012 für Personen, 2012-2013 für Auswahlbez.
                          ~ Wegzug, Todesfall ... ~
            (...)

        30  2--5|2345 := Angaben zu 2012 und 2015 für Personen, 2012-2015 für Auswahlbez.
		                  ~ temporärer Ausfall 2013 und 2014 ~ 
						  
            (...) 
		
		47 ---5|2345  := Angaben zu 2015 für Personen, 2012-2015 für Auswahlbez.
		                  ~ Ausfälle 2012-2014 aufgrund von Zuzügen oder Geburten ~
--------
Hinweis auf Differenzierungsmöglichkeiten nach 
EF45 Zuzug (i. d. letzten 12 Monaten): 
     Code -5 Entfällt (Keine Wiederholungsbefragung)
     = erstmals befragte Rotationsgruppe.
*/

* Recodierung Panelzeitpunkte
recode file (1 2 = 1) (3 4 = 2) (5 6 = 3) (7=4), gen(t)
lab var t "Panelzeitpukt"
lab def t 1 "2012" 2 "2013" 3 "2014" 4 "2015"
lab val t t
format t %1.0f

* === Erste Ausfallanalysen  ===

* --- Zusammenführung der Daten auf Auswahlbezirksebene (PSU) ---

* Zusammenführung 2012 und 2013 - PSU-Ebene, ohne Ausfallsätze, 
*   Erhebungszeitpunkte 2012-2015
tab t2_psu t1_psu if psu_1==1 & ef63>0, m col
/*
    PSU in |
2013 (ohne |  PSU in 2012  (ohne
 Ausfallsä |   Ausfallsätze, 1.
   tze, 1. |       PSU-Satz)
 PSU-Satz) |         0          1 |     Total
-----------+----------------------+----------
         0 |     19508       8543 |     28051 
           |     68,21      25,37 |     45,04 
-----------+----------------------+----------
         1 |      9092      25134 |     34226 
           |     31,79      74,63 |     54,96 
-----------+----------------------+----------
     Total |     28600      33677 |     62277 
           |    100,00     100,00 |    100,00 
*/

* Zusammenführung 2012 und 2015 - PSU-Ebene, ohne Ausfallsätze, 
*   Erhebungszeitpunkte 2012-2015
tab t4_psu t1_psu if psu_1==1 & ef63>0, m col
/*  PSU in |
2015 (ohne |  PSU in 2012  (ohne
 Ausfallsä |   Ausfallsätze, 1.
   tze, 1. |       PSU-Satz)
 PSU-Satz) |         0          1 |     Total
-----------+----------------------+----------
         0 |      2955      25389 |     28344 
           |     10,33      75,39 |     45,51 
-----------+----------------------+----------
         1 |     25645       8288 |     33933 
           |     89,67      24,61 |     54,49 
-----------+----------------------+----------
     Total |     28600      33677 |     62277 
           |    100,00     100,00 |    100,00 
*/

* 1. Personensatz
* table ausftyp ptyp if p1==1, missing row col stubw(20)

compress

save panel_12131415_v1.dta, replace

* ==============================================================================

* 4 Files nebeneinander stellen (wide format)

* Nicht mehr benötigte Variablen löschen
drop p1 psu_1 

* idpers (string) muss für "xtset" numerisch sein => idpers_n
egen idpers_n = group(idpers)
lab var idpers_n "ID Person (ef1 ef3 ef4 ef63) - numerisch"

sort idpers_n t file

/* Zeitkonstante und zeitveränderliche (xij) Variablen ermitteln
gen fail = (t==4)
stset t, id(idpers_n) failure(fail)
stvary
* (...)
drop fail _st _d _t _t0
*/

xtset idpers_n t

* xtdescribe

* xij-Variablen umbenennen (incl. zeitkonst. Var: id12, t1_psu, t2_psu, t3_psu)
rename (file  ejahr  ef5b  s5b  ef12  s12  ef5a  ef30  ef31  ef45  ef46  ef47  ef451  ef952  id12  id13  id14  id15  t1  t2  t3  t4  n_psu12  n_psu13  n_psu14  n_psu15  t1_psu  t2_psu  t3_psu  t4_psu ) ///
       (file_ ejahr_ ef5b_ s5b_ ef12_ s12_ ef5a_ ef30_ ef31_ ef45_ ef46_ ef47_ ef451_ ef952_ id12_ id13_ id14_ id15_ t1_ t2_ t3_ t4_ n_psu12_ n_psu13_ n_psu14_ n_psu15_ t1_psu_ t2_psu_ t3_psu_ t4_psu_)

reshape wide file_ ejahr_ ef5b_ s5b_ ef12_ s12_ ef5a_ ef30_ ef31_ ef45_ ef46_ ef47_ ef451_ ef952_  id12_ id13_ id14_ id15_ t1_ t2_ t3_ t4_ n_psu12_ n_psu13_ n_psu14_ n_psu15_ t1_psu_ t2_psu_ t3_psu_ t4_psu_, i(idpers_n) j(t)

* -----------------------------------------------------------------------------

tab ptyp, miss
/*
 Panelsätze |
          - |
Personenebe |
  ne (incl. |
 Ausfallsät |
        ze) |      Freq.     Percent        Cum.
------------+-----------------------------------
   [0] 2345 |      90834        8,19        8,19
   [1] 2--- |     174783       15,76       23,95
   [2] 23-- |     135211       12,19       36,14
   [3] 234- |     111600       10,06       46,20
   [4] 23-5 |        554        0,05       46,25
   [5] 2-4- |       1122        0,10       46,35
   [6] 2-45 |        394        0,04       46,39
   [7] 2--5 |         69        0,01       46,40
   [8] -3-- |      87416        7,88       54,28
   [9] -34- |      23130        2,09       56,36
  [10] -345 |      78487        7,08       63,44
  [11] -3-5 |        667        0,06       63,50
  [12] --4- |      64831        5,85       69,34
  [13] --45 |     157208       14,17       83,52
  [14] ---5 |     182790       16,48      100,00
------------+-----------------------------------
      Total |    1109096      100,00
*/

tab ptyp_psu, m
/*
    Panelsätze - |
 PSU-Ebene (ohne |
   Ausfallsätze: |
 ef63<0 | ef5b<0 |
       | ef31<0) |      Freq.     Percent        Cum.
-----------------+-----------------------------------
[-1] Ausfallsatz |       6879        0,62        0,62
        [0] 2345 |     183786       16,57       17,19
        [1] 2--- |     128511       11,59       28,78
        [2] 23-- |     150721       13,59       42,37
        [3] 234- |     164549       14,84       57,20
        [4] 23-5 |        289        0,03       57,23
        [5] 2-4- |         18        0,00       57,23
        [8] -3-- |      38134        3,44       60,67
        [9] -34- |       1666        0,15       60,82
       [10] -345 |     124850       11,26       72,08
       [11] -3-5 |        149        0,01       72,09
       [12] --4- |       1625        0,15       72,24
       [13] --45 |     183988       16,59       88,83
       [14] ---5 |     123931       11,17      100,00
-----------------+-----------------------------------
           Total |    1109096      100,00
*/

tab ausftyp, m
/*
     Ausfalltyp: Ausfall Satz | Angaben |
             Auswahlbezirk (Proxy) 201* |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
[-1] Ausfallsätze ef4<0 | ef5b<0 | ef63 |     132497       11,95       11,95
                          [0] 2345|2345 |      88087        7,94       19,89
                          [1] 2---|2--- |     120644       10,88       30,77
                          [2] 23--|23-- |     109252        9,85       40,62
                          [3] 234-|234- |      98110        8,85       49,46
                          [4] 23-5|23-5 |         37        0,00       49,47
                          [5] -3--|-3-- |      35843        3,23       52,70
                          [6] -34-|-34- |        943        0,09       52,78
                          [7] -345|-345 |      67965        6,13       58,91
                          [8] -3-5|-3-5 |         27        0,00       58,91
                          [9] --4-|--4- |       1290        0,12       59,03
                         [10] --45|--45 |     131114       11,82       70,85
                         [11] ---5|---5 |     117580       10,60       81,45
                         [12] 2---|23-- |      13219        1,19       82,64
                         [13] 2---|234- |      12384        1,12       83,76
                         [14] 2---|23-5 |         30        0,00       83,76
                         [15] 2---|2-4- |          2        0,00       83,76
                         [16] 23--|234- |       9664        0,87       84,64
                         [17] 23--|23-5 |         28        0,00       84,64
                         [18] -3--|-34- |        190        0,02       84,66
                         [19] -3--|-345 |       9226        0,83       85,49
                         [20] -3--|-3-5 |         18        0,00       85,49
                         [21] -34-|-345 |       8741        0,79       86,28
                         [22] --4-|--45 |      18318        1,65       87,93
                         [23] 2---|2345 |      12651        1,14       89,07
                         [24] 23--|2345 |       9574        0,86       89,93
                         [25] 234-|2345 |       9446        0,85       90,78
                         [26] 23-5|2345 |        314        0,03       90,81
                         [27] 2-4-|2345 |        148        0,01       90,83
                         [28] 2-4-|234- |        431        0,04       90,86
                         [29] 2-45|2345 |        340        0,03       90,90
                         [30] 2--5|2345 |         51        0,00       90,90
                         [31] -3--|2345 |       2710        0,24       91,14
                         [32] -3--|23-- |      11076        1,00       92,14
                         [33] -3--|234- |       2541        0,23       92,37
                         [34] -3--|23-5 |          3        0,00       92,37
                         [35] -34-|2345 |       1891        0,17       92,54
                         [36] -34-|234- |       8587        0,77       93,32
                         [37] -345|2345 |       7491        0,68       93,99
                         [38] -3-5|2345 |        102        0,01       94,00
                         [39] -3-5|-345 |        342        0,03       94,03
                         [40] --4-|2345 |       2609        0,24       94,27
                         [41] --4-|234- |      10287        0,93       95,19
                         [42] --4-|2-4- |          5        0,00       95,20
                         [43] --4-|-34- |        298        0,03       95,22
                         [44] --4-|-345 |       2877        0,26       95,48
                         [45] --45|2345 |       8176        0,74       96,22
                         [46] --45|-345 |      10133        0,91       97,13
                         [47] ---5|2345 |       9544        0,86       97,99
                         [48] ---5|23-5 |         58        0,01       98,00
                         [49] ---5|-345 |       7842        0,71       98,71
                         [50] ---5|-3-5 |         52        0,00       98,71
                         [51] ---5|--45 |      14308        1,29      100,00
----------------------------------------+-----------------------------------
                                  Total |    1109096      100,00
*/

recode n_t1 (0=0) (1=1), gen(t1)
recode n_t2 (0=0) (1=1), gen(t2)
recode n_t3 (0=0) (1=1), gen(t3)
recode n_t4 (0=0) (1=1), gen(t4)

lab var t1 "Angaben zu 2012" // 0=nein, 1=ja
lab var t2 "Angaben zu 2013"
lab var t3 "Angaben zu 2014"
lab var t4 "Angaben zu 2015"


* Angaben zu 2013 und 2012
* - Befragtensätze incl. Ausfallsätze
tab t2 t1, miss
/*
Angaben zu |    Angaben zu 2012
      2013 |         0          1 |     Total
-----------+----------------------+----------
         0 |    404829     176368 |    581197 
         1 |    189700     338199 |    527899 
-----------+----------------------+----------
     Total |    594529     514567 |   1109096 
*/

* Angaben zu 2014 und 2013
tab t3 t2, miss
/*
Angaben zu |    Angaben zu 2013
      2014 |         0          1 |     Total
-----------+----------------------+----------
         0 |    357642     223848 |    581490 
         1 |    223555     304051 |    527606 
-----------+----------------------+----------
     Total |    581197     527899 |   1109096 
*/

* Angaben zu 2015 und 2012
tab t4 t1, miss
/*
Angaben zu |    Angaben zu 2012
      2015 |         0          1 |     Total
-----------+----------------------+----------
         0 |    175377     422716 |    598093 
         1 |    419152      91851 |    511003 
-----------+----------------------+----------
     Total |    594529     514567 |   1109096 
*/

* Z. B. Bevölkerung: Haupt- oder Nebenwohnsitz (ef30*) 
*   incl. Ausfallsätze (ef30*=-8, -7) und Panelausfälle (ef30*=.).
tab ef30_4 ef30_1, m
/*
                      |                              1 ef30_
              4 ef30_ | Entfällt   Entfällt   Bevölkeru  Bevölkeru  Bevölkeru          . |     Total
----------------------+------------------------------------------------------------------+----------
Entfällt (leerstehend |      2344          0          0          0          0      25619 |     27963 
Entfällt (Auswahlbezi |         0        678          0          0          0      18799 |     19477 
Bevölkerung am Hauptw |         0          0      85721       1009        447     364292 |    451469 
Bevölkerung am Hauptw |         0          0        613        374         58       6001 |      7046 
Bevölkerung am Nebenw |         0          0        191         72        344       4441 |      5048 
                    . |     24902       2231     383274       7323       4986     175377 |    598093 
----------------------+------------------------------------------------------------------+----------
                Total |     27246       2909     469799       8778       5835     594529 |   1109096 
*/

* -----------------------------------------------------------------------------

* === Weitere Ausfallanalysen ===
/* 
Für die Zusammenführung der Daten 2012 und 2013 wird für die Daten aus 2012
eine Zusammenführungsquote von 64,9 % und für die Daten aus 2013 von 67,7 %
berichtet (Herter-Eschweiler/Schimpl-Neimanns 2018, S. 6).

Für den Panelzeitpunkt t=2 (2013) sind aus der Erhebung 2014 Angaben aus den
Jahresüberhängen hinzugekommen. Werden diese berücksichtigt, ergeben sich
andere Zusammenführungsquoten.
*/
* 2012 Befragte mit gültigen Angaben (ohne Ausfallsätze) und mit Angaben zu 2013
tab t2 t1 if (ef30_1>=1 & ef30_1<=3) | (ef30_2>=1 & ef30_2<=3), m col
/*
+-------------------+
| Key               |
|-------------------|
|     frequency     |
| column percentage |
+-------------------+

Angaben zu |    Angaben zu 2012
      2013 |         0          1 |     Total
-----------+----------------------+----------
         0 |         0     159900 |    159900 
           |      0,00      33,01 |     24,90 
-----------+----------------------+----------
         1 |    157696     324512 |    482208 
           |    100,00      66,99 |     75,10 
-----------+----------------------+----------
     Total |    157696     484412 |    642108 
           |    100,00     100,00 |    100,00 
*/

* -----------------------------------------------------------------------------

/* Differenzierung von Ausfallgründen - der Fall neuer Rotationsgruppen

Siehe Herter-Eschweiler/Schimpl-Neimanns (2018, S. 8: 
"Nähere Aufklärungen fehlender Angaben zum Zeitpunkt t (2012) können mit den 
Angaben der Erhebung t + 1 (2013) zum Zuzug in den letzten 12 Monaten (EF45) 
oder zum Wohnsitz vor 12 Monaten (EF451, ohne Auskunftspflicht) ermittelt 
werden." 
Der Code EF45 = -5 "Entfällt (Keine Wiederholungsbefragung)" weist darauf hin, 
dass eine neue Rotationsgruppe erstmals befragt wurde.
Beispiel:
Für die nicht zusammenführbaren (gültigen) Personensätze der Paneljahre 2012 und 
2013 (t1==0 & t2==1) soll geprüft werden, ob die Ausfälle mit erstmals befragten
Rotationsgruppen bedingt zusammenhängen. 
*/
tab ausftyp ef45_2 if (ef30_1>=1 & ef30_1<=3) | (ef30_2>=1 & ef30_2<=3) & t1==0 & t2==1
/*
  Ausfalltyp: Ausfall |
       Satz | Angaben |
Auswahlbezirk (Proxy) |                   2 ef45_
                 201* | [-5] Entf     [1] Ja   [8] Nein  [9] Keine |     Total
----------------------+--------------------------------------------+----------
        [0] 2345|2345 |         0        182      87899          6 |     88087 
        [2] 23--|23-- |         0        238     109014          0 |    109252 
        [3] 234-|234- |         0        179      97927          4 |     98110 
        [4] 23-5|23-5 |         0          0         37          0 |        37 
        [5] -3--|-3-- |     34922        418        503          0 |     35843 
        [6] -34-|-34- |       331        221        391          0 |       943 
        [7] -345|-345 |     67474        125        366          0 |     67965 
        [8] -3-5|-3-5 |        27          0          0          0 |        27 
       [16] 23--|234- |         0         71       9592          1 |      9664 
       [17] 23--|23-5 |         0          0         28          0 |        28 
       [18] -3--|-34- |       109         34         47          0 |       190 
       [19] -3--|-345 |      9169         15         42          0 |      9226 
       [20] -3--|-3-5 |        18          0          0          0 |        18 
       [21] -34-|-345 |      8643         23         75          0 |      8741 
       [24] 23--|2345 |         0         74       9499          1 |      9574 
       [25] 234-|2345 |         0         41       9402          3 |      9446 
       [26] 23-5|2345 |         0          2        312          0 |       314 
       [31] -3--|2345 |         0       2113        597          0 |      2710 
       [32] -3--|23-- |         0       9231       1843          2 |     11076 
       [33] -3--|234- |         0       2010        531          0 |      2541 
       [34] -3--|23-5 |         0          3          0          0 |         3 
       [35] -34-|2345 |         0       1489        402          0 |      1891 
       [36] -34-|234- |         0       7215       1369          3 |      8587 
       [37] -345|2345 |         0       6003       1488          0 |      7491 
       [38] -3-5|2345 |         0         62         40          0 |       102 
       [39] -3-5|-345 |       342          0          0          0 |       342 
----------------------+--------------------------------------------+----------
                Total |    121035      29749     331404         20 |    482208 
* 25,1 % (= 121035 / 482208) der Ausfälle sind durch eine neue Rotationsgruppe 
*    bedingt (ef45_2 = -5).
*/

* -----------------------------------------------------------------------------
/* 2012 Befragte mit gültigen Angaben (ohne Ausfallsätze) und mit Angaben zu 
   2015 */
tab ausftyp  if ( (ef30_1>=1 & ef30_1<=3) | (ef30_4>=1 & ef30_4<=3) ) & t1==1, m
/*   Ausfalltyp: Ausfall Satz | Angaben |
             Auswahlbezirk (Proxy) 201* |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
                          [0] 2345|2345 |      88087       18,18       18,18
                          [1] 2---|2--- |     120644       24,91       43,09
                          [2] 23--|23-- |     109252       22,55       65,64
                          [3] 234-|234- |      98110       20,25       85,90
                          [4] 23-5|23-5 |         37        0,01       85,90
                         [12] 2---|23-- |      13219        2,73       88,63
                         [13] 2---|234- |      12384        2,56       91,19
                         [14] 2---|23-5 |         30        0,01       91,20
                         [15] 2---|2-4- |          2        0,00       91,20
                         [16] 23--|234- |       9664        1,99       93,19
                         [17] 23--|23-5 |         28        0,01       93,20
                         [23] 2---|2345 |      12651        2,61       95,81
                         [24] 23--|2345 |       9574        1,98       97,78
                         [25] 234-|2345 |       9446        1,95       99,73
                         [26] 23-5|2345 |        314        0,06       99,80
                         [27] 2-4-|2345 |        148        0,03       99,83
                         [28] 2-4-|234- |        431        0,09       99,92
                         [29] 2-45|2345 |        340        0,07       99,99
                         [30] 2--5|2345 |         51        0,01      100,00
----------------------------------------+-----------------------------------
                                  Total |     484412      100,00
*/

* -----------------------------------------------------------------------------

/* 2012 Befragte mit gültigen Angaben (ohne Ausfallsätze) und mit Angaben zu 
   2015 */
tab ptyp  if ( (ef30_1>=1 & ef30_1<=3) | (ef30_4>=1 & ef30_4<=3) ) & t1==1, m
/*
 Panelsätze |
          - |
Personenebe |
  ne (incl. |
 Ausfallsät |
   ze) 201* |      Freq.     Percent        Cum.
------------+-----------------------------------
   [0] 2345 |      88087       18,18       18,18
   [1] 2--- |     158930       32,81       50,99
   [2] 23-- |     128518       26,53       77,52
   [3] 234- |     107556       22,20       99,73
   [4] 23-5 |        351        0,07       99,80
   [5] 2-4- |        579        0,12       99,92
   [6] 2-45 |        340        0,07       99,99
   [7] 2--5 |         51        0,01      100,00
------------+-----------------------------------
      Total |     484412      100,00
*/

* ============================================================================

* Panelzeitpunkte für Auswahlbezirke (PSU)
* - für Auswertungen auf der Ebene der Auswahlbezirke 
*   analog zu Auswertungen der Daten im long format (3) -

egen t1_psu = rowmax(t1_psu_1 t1_psu_2 t1_psu_3 t1_psu_4)
egen t2_psu = rowmax(t2_psu_1 t2_psu_2 t2_psu_3 t2_psu_4)
egen t3_psu = rowmax(t3_psu_1 t3_psu_2 t3_psu_3 t3_psu_4)
egen t4_psu = rowmax(t4_psu_1 t4_psu_2 t4_psu_3 t4_psu_4)

lab var t1_psu "PSU in 2012 (ohne Ausfallsätze, 1. PSU-Satz)"
lab var t2_psu "PSU in 2013 (ohne Ausfallsätze, 1. PSU-Satz)"
lab var t3_psu "PSU in 2014 (ohne Ausfallsätze, 1. PSU-Satz)"
lab var t4_psu "PSU in 2015 (ohne Ausfallsätze, 1. PSU-Satz)"

* Zusammenführung 2012 und 2015 - PSU-Ebene, ohne Ausfallsätze, Erhebungszeitpunkte 2012-2015
tab t4_psu  t1_psu if ef63>0, col
/*  PSU in |
2015 (ohne |  PSU in 2012  (ohne
 Ausfallsä |   Ausfallsätze, 1.
   tze, 1. |       PSU-Satz)
 PSU-Satz) |         0          1 |     Total
-----------+----------------------+----------
         0 |      2955      25389 |     28344 
           |     10,33      75,39 |     45,51 
-----------+----------------------+----------
         1 |     25645       8288 |     33933 
           |     89,67      24,61 |     54,49 
-----------+----------------------+----------
     Total |     28600      33677 |     62277 
           |    100,00     100,00 |    100,00 
*/

* ==============================================================================

* 5   Beispielanalysen zur Antwortkonsistenz (Geschlecht und Geburtsjahr)

* (1) Antwortkonsistenz Geschlecht (ohne Ausfallsätze)
*     Angaben für Panelzeitpunkte 2012-2015 insgesamt, einschließlich 
*     inkonsistenter Angaben, ohne Ausfallsätze
quietly count if ptyp==0 & ausfall==0
scalar i = r(N)

* darunter: konsistente Angaben 
quietly count if ptyp==0 & ausfall==0 & ef46_1==ef46_2 & ef46_1==ef46_3 & ef46_1==ef46_4
scalar k = r(N)

* Anteil konsistenter Angaben zum Geschlecht
di "Konsistente Angabe: " k " von Insgesamt: " i " = " k/i * 100 " %"
* Der Anteil konsistenter Angaben zum Geschlecht beträgt rund 99 %.

scalar drop i k

* ------------------------------------------------------------------------------

* (2) Antwortkonsistenz Geburtsjahr für Geburtsjahrgänge 1917 - 2012
*     (Unterschiedliche Zusammenfassungen für Geburtsjahrgänge vor 1917)
generate v47_1 = ef47_1 if ptyp==0 & ausfall==0 & ef47_1>=1917 & ef47_1<=2012
generate v47_2 = ef47_2 if ptyp==0 & ausfall==0 & ef47_2>=1917 & ef47_2<=2012
generate v47_3 = ef47_3 if ptyp==0 & ausfall==0 & ef47_3>=1917 & ef47_3<=2012
generate v47_4 = ef47_4 if ptyp==0 & ausfall==0 & ef47_4>=1917 & ef47_4<=2012
lab var v47_1 "Geburtsjahr - t1 | ptyp=0 & ausfall=0 recodiert"
lab var v47_2 "Geburtsjahr - t2 | ptyp=0 & ausfall=0 recodiert"
lab var v47_3 "Geburtsjahr - t2 | ptyp=0 & ausfall=0 recodiert"
lab var v47_4 "Geburtsjahr - t2 | ptyp=0 & ausfall=0 recodiert"

* Angaben für Panelzeitpunkte 2012-2015 der Geburtsjahrgänge 1917 - 2012 
* insgesamt, einschließlich inkonsistenter Angaben, ohne Ausfallsätze
quietly count if ptyp==0 & ausfall==0 & (v47_1!=. & v47_2!=. & v47_3!=. & v47_4!=.)
scalar i = r(N)

* darunter: konsistente Angaben 
quietly count if ptyp==0 & ausfall==0 & v47_1==v47_2 & v47_1==v47_3 & v47_1==v47_4
scalar k = r(N)

* Anteil konsistenter Angaben zum Geburtsjahr
di "Konsistente Angabe: " k " von Insgesamt: " i " = " k/i * 100 " %"
* Der Anteil konsistenter Angaben zum Geburtsjahr beträgt rund 95 %.

scalar drop i k 

* ------------------------------------------------------------------------------

* ID Haushalte ohne Kennung für Jahresüberhänge 
generate idhh = s1 + s3 + s4
lab var idhh "ID Haushalt (ef1 ef3 ef4)"

/*
* Variablen Label. Ggf. aktivieren.

lab var ef1 "Bundesland"
lab var s1 "Bundesland alphanum."
lab var ef3 "Nr. des Auswahlbezirks (systemfrei)"
lab var s3 "Nr. des Auswahlbezirks (systemfrei) alphanum."
lab var ef4 "Nr. des Haushalts im Auswahlbezirk (systemfrei)"
lab var s4 "Nr. des Haushalts im Auswahlbezirk (systemfrei) alphanum."
lab var ef63 "Personennummer"
lab var s63 "Personennummer alphanum."
lab var idpers "ID Person (ef1 ef3 ef4 ef63) alphanum."
lab var idpers_n "ID Person (ef1 ef3 ef4 ef63) numerisch"
lab var idpsu "ID Auswahlbezirk (ef1 ef3) alphanum."
lab var idhh "ID Haushalt (ef1 ef3 ef4) alphanum."
lab var ptyp "Panelsätze - Personenebene (incl. Ausfallsätze)"
lab var ausftyp "Ausfalltyp: Ausfall Satz  Angaben Auswahlbezirk (Proxy)"
lab var ausfall "Ausfallsatz (ef63<0 | ef5b<0 | ef31<0)"
lab var ptyp_psu "Panelsätze - PSU-Ebene (ohne Ausfallsätze: ef63<0 | ef5b<0 | ef31<0)"
lab var t1 "Angaben zu 2012"
lab var t2 "Angaben zu 2013"
lab var t3 "Angaben zu 2014"
lab var t4 "Angaben zu 2015"
lab var id12_1 "Identifikationsnummer MZ 2012 - t1"
lab var id12_2 "Identifikationsnummer MZ 2012 - t2"
lab var id12_3 "Identifikationsnummer MZ 2012 - t3"
lab var id12_4 "Identifikationsnummer MZ 2012 - t4"
lab var id13_1 "Identifikationsnummer MZ 2013 - t1"
lab var id13_2 "Identifikationsnummer MZ 2013 - t2"
lab var id13_3 "Identifikationsnummer MZ 2013 - t3"
lab var id13_4 "Identifikationsnummer MZ 2013 - t4"
lab var id14_1 "Identifikationsnummer MZ 2014 - t1"
lab var id14_2 "Identifikationsnummer MZ 2014 - t2"
lab var id14_3 "Identifikationsnummer MZ 2014 - t3"
lab var id14_4 "Identifikationsnummer MZ 2014 - t4"
lab var id15_1 "Identifikationsnummer MZ 2015 - t1"
lab var id15_2 "Identifikationsnummer MZ 2015 - t2"
lab var id15_3 "Identifikationsnummer MZ 2015 - t3"
lab var id15_4 "Identifikationsnummer MZ 2015 - t4"
lab var file_1 "Datenquelle - t1"
lab var file_2 "Datenquelle - t2"
lab var file_3 "Datenquelle - t3"
lab var file_4 "Datenquelle - t4"
lab var ejahr_1 "Erhebungsjahr - t1"
lab var ejahr_2 "Erhebungsjahr - t2"
lab var ejahr_3 "Erhebungsjahr - t3"
lab var ejahr_4 "Erhebungsjahr - t4"
lab var ef5b_1 "Jahresüberhang aus dem Vorjahr - t1"
lab var ef5b_2 "Jahresüberhang aus dem Vorjahr - t2"
lab var ef5b_3 "Jahresüberhang aus dem Vorjahr - t3"
lab var ef5b_4 "Jahresüberhang aus dem Vorjahr - t4"
lab var s5b_1 "Jahresüberhang aus dem Vorjahr alphanum. - t1"
lab var s5b_2 "Jahresüberhang aus dem Vorjahr alphanum. - t2"
lab var s5b_3 "Jahresüberhang aus dem Vorjahr alphanum. - t3"
lab var s5b_4 "Jahresüberhang aus dem Vorjahr alphanum. - t4"
lab var ef12_1 "Berichtsquartal - t1"
lab var ef12_2 "Berichtsquartal - t2"
lab var ef12_3 "Berichtsquartal - t3"
lab var ef12_4 "Berichtsquartal - t4"
lab var s12_1 "Berichtsquartal alphanum. - t1"
lab var s12_2 "Berichtsquartal alphanum. - t2"
lab var s12_3 "Berichtsquartal alphanum. - t3"
lab var s12_4 "Berichtsquartal alphanum. - t4"
lab var ef5a_1 "Nr. der Person im Haushalt (systemfrei) - t1"
lab var ef5a_2 "Nr. der Person im Haushalt (systemfrei) - t2"
lab var ef5a_3 "Nr. der Person im Haushalt (systemfrei) - t3"
lab var ef5a_4 "Nr. der Person im Haushalt (systemfrei) - t4"
lab var ef30_1 "Bevölkerung: Haupt- oder Nebenwohnsitz - t1"
lab var ef30_2 "Bevölkerung: Haupt- oder Nebenwohnsitz - t2"
lab var ef30_3 "Bevölkerung: Haupt- oder Nebenwohnsitz - t3"
lab var ef30_4 "Bevölkerung: Haupt- oder Nebenwohnsitz - t4"
lab var ef31_1 "Bevölkerung: Privathaushalte - t1"
lab var ef31_2 "Bevölkerung: Privathaushalte - t2"
lab var ef31_3 "Bevölkerung: Privathaushalte - t3"
lab var ef31_4 "Bevölkerung: Privathaushalte - t4"
lab var ef45_1 "Zuzug (i. d. letzten 12 Monaten) - t1"
lab var ef45_2 "Zuzug (i. d. letzten 12 Monaten) - t2"
lab var ef45_3 "Zuzug (i. d. letzten 12 Monaten) - t3"
lab var ef45_4 "Zuzug (i. d. letzten 12 Monaten) - t4"
lab var ef46_1 "Geschlecht - t1"
lab var ef46_2 "Geschlecht - t2"
lab var ef46_3 "Geschlecht - t3"
lab var ef46_4 "Geschlecht - t4"
lab var ef47_1 "Geburtsjahr - t1"
lab var ef47_2 "Geburtsjahr - t2"
lab var ef47_3 "Geburtsjahr - t3"
lab var ef47_4 "Geburtsjahr - t4"
lab var ef451_1 "Selber Wohnsitz (vor einem Jahr) (FB) - t1"
lab var ef451_2 "Selber Wohnsitz (vor einem Jahr) (FB) - t2"
lab var ef451_3 "Selber Wohnsitz (vor einem Jahr) (FB) - t3"
lab var ef451_4 "Selber Wohnsitz (vor einem Jahr) (FB) - t4"
lab var ef952_1 "Standardhochrechnungsfaktor Jahr - t1"
lab var ef952_2 "Standardhochrechnungsfaktor Jahr - t2"
lab var ef952_3 "Standardhochrechnungsfaktor Jahr - t3"
lab var ef952_4 "Standardhochrechnungsfaktor Jahr - t4"
lab var t1_1 "Angaben zu 2012 - t1"
lab var t1_2 "Angaben zu 2012 - t2"
lab var t1_3 "Angaben zu 2012 - t3"
lab var t1_4 "Angaben zu 2012 - t4"
lab var t2_1 "Angaben zu 2013 - t1"
lab var t2_2 "Angaben zu 2013 - t2"
lab var t2_3 "Angaben zu 2013 - t3"
lab var t2_4 "Angaben zu 2013 - t4"
lab var t3_1 "Angaben zu 2014 - t1"
lab var t3_2 "Angaben zu 2014 - t2"
lab var t3_3 "Angaben zu 2014 - t3"
lab var t3_4 "Angaben zu 2014 - t4"
lab var t4_1 "Angaben zu 2015 - t1"
lab var t4_2 "Angaben zu 2015 - t2"
lab var t4_3 "Angaben zu 2015 - t3"
lab var t4_4 "Angaben zu 2015 - t4"
lab var t1_psu_1 "PSU in 2012  (ohne Ausfallsätze, 1. PSU-Satz) - t1"
lab var t1_psu_2 "PSU in 2012  (ohne Ausfallsätze, 1. PSU-Satz) - t2"
lab var t1_psu_3 "PSU in 2012  (ohne Ausfallsätze, 1. PSU-Satz) - t3"
lab var t1_psu_4 "PSU in 2012  (ohne Ausfallsätze, 1. PSU-Satz) - t4"
lab var t2_psu_1 "PSU in 2013  (ohne Ausfallsätze, 1. PSU-Satz) - t1"
lab var t2_psu_2 "PSU in 2013  (ohne Ausfallsätze, 1. PSU-Satz) - t2"
lab var t2_psu_3 "PSU in 2013  (ohne Ausfallsätze, 1. PSU-Satz) - t3"
lab var t2_psu_4 "PSU in 2013  (ohne Ausfallsätze, 1. PSU-Satz) - t4"
lab var t3_psu_1 "PSU in 2014  (ohne Ausfallsätze, 1. PSU-Satz) - t1"
lab var t3_psu_2 "PSU in 2014  (ohne Ausfallsätze, 1. PSU-Satz) - t2"
lab var t3_psu_3 "PSU in 2014  (ohne Ausfallsätze, 1. PSU-Satz) - t3"
lab var t3_psu_4 "PSU in 2014  (ohne Ausfallsätze, 1. PSU-Satz) - t4"
lab var t4_psu_1 "PSU in 2015  (ohne Ausfallsätze, 1. PSU-Satz) - t1"
lab var t4_psu_2 "PSU in 2015  (ohne Ausfallsätze, 1. PSU-Satz) - t2"
lab var t4_psu_3 "PSU in 2015  (ohne Ausfallsätze, 1. PSU-Satz) - t3"
lab var t4_psu_4 "PSU in 2015  (ohne Ausfallsätze, 1. PSU-Satz) - t4"
lab var n_t1 "Angaben zu 2012 (Person)"
lab var n_t2 "Angaben zu 2013 (Person)"
lab var n_t3 "Angaben zu 2014 (Person)"
lab var n_t4 "Angaben zu 2015 (Person)"
lab var n_psu12_1 "Anzahl gültige Sätze 2012 im Auswahlbezirk - t1"
lab var n_psu12_2 "Anzahl gültige Sätze 2012 im Auswahlbezirk - t2"
lab var n_psu12_3 "Anzahl gültige Sätze 2012 im Auswahlbezirk - t3"
lab var n_psu12_4 "Anzahl gültige Sätze 2012 im Auswahlbezirk - t4"
lab var n_psu13_1 "Anzahl gültige Sätze 2013 im Auswahlbezirk - t1"
lab var n_psu13_2 "Anzahl gültige Sätze 2013 im Auswahlbezirk - t2"
lab var n_psu13_3 "Anzahl gültige Sätze 2013 im Auswahlbezirk - t3"
lab var n_psu13_4 "Anzahl gültige Sätze 2013 im Auswahlbezirk - t4"
lab var n_psu14_1 "Anzahl gültige Sätze 2014 im Auswahlbezirk - t1"
lab var n_psu14_2 "Anzahl gültige Sätze 2014 im Auswahlbezirk - t2"
lab var n_psu14_3 "Anzahl gültige Sätze 2014 im Auswahlbezirk - t3"
lab var n_psu14_4 "Anzahl gültige Sätze 2014 im Auswahlbezirk - t4"
lab var n_psu15_1 "Anzahl gültige Sätze 2015 im Auswahlbezirk - t1"
lab var n_psu15_2 "Anzahl gültige Sätze 2015 im Auswahlbezirk - t2"
lab var n_psu15_3 "Anzahl gültige Sätze 2015 im Auswahlbezirk - t3"
lab var n_psu15_4 "Anzahl gültige Sätze 2015 im Auswahlbezirk - t4"
*/

* ------------------------------------------------------------------------------

* Nicht benötigte Variablen löschen. Ggf. aktivieren.
* drop v47_1 v47_2 v47_3  

* ------------------------------------------------------------------------------

compress

save panel_12131415_v1w.dta, replace

log close

* exit, clear
