/* Diese Datei: panel_12131415_v1.sas  (02/2020)
   https://www.gesis.org/missy/files/documents/MZ/panel_12131415_v1.sas
 Dateiformat: Dos/Windows
 Zeichensatz: Windows-1252 */

/* ============================================================================
Zusammenfhrung der Daten Mikrozensus Scientific Use File 2012 bis 2015
zu einem Panel
 
Siehe 
Herter-Eschweiler/Schimpl-Neimanns (2018): Mglichkeiten der Verknpfung von 
Mikrozensus-Querschnittserhebungen ab 2012 zu Panels. Bonn/Mannheim.
https://www.gesis.org/missy/files/documents/MZ/panelbildung_suf2012.pdf

3.  Panelbildung
3.1 Version 1 (Lngsschnittorientierung)
    Fr die Analyse von Brutto-Vernderungen und Verlaufsdatenanalysen 

--------------------------------------------------------------------------------
Programmstruktur

1   Aufbereitung der Querschnittdaten SUF MZ 2012 ff.
      Erstellung des Personenidentifkators ohne Kennung des Jahresberhangs
      Prfung auf doppelte IDs
      Zuordnung der Jahresberhnge aus Erhebung t zu t-1
 
2   Files untereinander Stellen (long format)
      Prfung auf doppelte Flle und Datenbereinigung
      Ausschluss doppelter Stze pro Panelzeitpunkt
      Kennzeichnung der Ausfallstze
      Ermittlung der Anzahl der Stze mit Angaben zum Panelzeitpunkt
      Fortlaufende Satznummer pro Panel-ID erstellen

3   Typisierung zum Ausfall erstellen
      Erste Ausfallanalysen

4   Files nebeneinander stellen (wide format)
      Weitere Ausfallanalysen

5   Beispielanalysen zur Antwortkonsistenz (Geschlecht und Geburtsjahr)

---
Das Programm orientiert sich eng an der Version fr die Zusammenfhrung der 
Daten 2012 und 2013, siehe 
https://www.gesis.org/missy/files/documents/MZ/panel_1213_v1.sas.
Die nderungen betreffen insbesondere die Typisierungen (ptyp* und ausftyp).

Programmautor: Bernhard Schimpl-Neimanns

============================================================================ */

* Verzeichnis der Daten ;
libname p '<Arbeits-/Datenverzeichnis>'; 

* Verzeichnis der Formate ;
libname library '<Arbeits-/Datenverzeichnis>' ; 

* Falls keine Formate vorliegen. Ggf. aktivieren;
* options nofmterr;

* Datendateien komprimieren. Ggf. aktivieren;
* options compress = binary;

* ----------------------------------------------------------------------------;

* 1   Aufbereitung der Querschnittdaten SUF MZ 2012 ff. ;

* 1.1 Aufbereitung SUF MZ 2012 - Variablenauswahl
*       Die Dateinamen entsprechen 
*       https://www.gesis.org/missy/files/documents/MZ/setups/sas/setup12.sas;

* Auswahl fr Panel: Ohne Jahresberhnge (ef5b = 1, 2), die gem 
*         Stichprobenplan zu 2011 zhlen;
data suf12_1 (where = (ef5b>=-8 & ef5b<=0)) ;
  set "<Vollstndiger Dateiname der SAS Datendatei SUF 2012>" 
  (keep = 
    EF1   /* Bundesland */
    EF3   /* Nr. des Auswahlbezirks (systemfrei) */
    EF4   /* Nr. des Haushalts im Auswahlbezirk (systemfrei) */
    EF5b  /* Jahresberhang aus dem Vorjahr */
    EF12  /* Berichtsquartal */
    EF63  /* Personennummer */
    EF5a  /* Nr. der Person im Haushalt (systemfrei) */
    EF30  /* Bevlkerung: Haupt- oder Nebenwohnsitz */
    EF31  /* Bevlkerung: Privathaushalte */
    EF45  /* Zuzug (i. d. letzten 12 Monaten) */
    EF46  /* Geschlecht */
    EF47  /* Geburtsjahr */
    EF451 /* Selber Wohnsitz (vor einem Jahr) (FB) */
    EF952 /* Standardhochrechnungsfaktor Jahr (in 1000) - neuer Hochrechnungsrahmen */
    ID    /* Identifikationsnummer */ ) ;

*  Generiere Personenidentifikator ohne Kennung des Jahresberhangs ;
idpers =    strip(putn(ef1,"Z2.0"))  /* Bundesland */
         || strip(putn(ef3,"Z6.0"))  /* Nr. des Auswahlbezirks (systemfrei) */
         || strip(putn(ef4,"Z3.0"))  /* Nr. des Haushalts im Auswahlbezirk (systemfrei) */
         || strip(putn(ef63,"Z2.0")) /* Personennummer */
        ;
  label idpers= "ID Person (ef1 ef3 ef4 ef63)";

  file = 1 ;
  label file= "Datenquelle";

  rename id = id12;
run;

* Doppelte IDs ? ;
proc sort data=suf12_1;
     by idpers;
run;

data suf12_1 (compress=yes);
  set suf12_1;
retain pnr;
if (idpers=lag(idpers))    then pnr = pnr+1;
if (idpers ne lag(idpers)) then pnr = 0;
run;

proc freq data=suf12_1 ;
  table pnr / nocol norow nopercent missing;
run;
* OK;

data suf12_1 (drop = pnr); 
     set suf12_1;
run;

* ============================================================================;

* 1.2 Aufbereitung SUF MZ 2013, Variablenauswahl.
*       Die Dateinamen entsprechen
*       https://www.gesis.org/missy/files/documents/MZ/setups/sas/setup13.sas;

data suf13_1 ; 
  set "<Vollstndiger Dateiname der SAS Datendatei SUF 2013>" 
  (keep = 
    EF1   /* Bundesland */
    EF3   /* Nr. des Auswahlbezirks (systemfrei) */
    EF4   /* Nr. des Haushalts im Auswahlbezirk (systemfrei) */
    EF5b  /* Jahresberhang aus dem Vorjahr */
    EF12  /* Berichtsquartal */
    EF63  /* Personennummer */
    EF5a  /* Nr. der Person im Haushalt (systemfrei) */
    EF30  /* Bevlkerung: Haupt- oder Nebenwohnsitz */
    EF31  /* Bevlkerung: Privathaushalte */
    EF45  /* Zuzug (i. d. letzten 12 Monaten) */
    EF46  /* Geschlecht */
    EF47  /* Geburtsjahr */
    EF451 /* Selber Wohnsitz (vor einem Jahr) (FB) */
    EF952 /* Standardhochrechnungsfaktor Jahr (in 1000) - neuer Hochrechnungsrahmen */
    ID    /* Identifikationsnummer */ ) ;

*  Generiere Personenidentifikator ohne Kennung des Jahresberhangs ;
idpers =    strip(putn(ef1,"Z2.0"))  /* Bundesland */
         || strip(putn(ef3,"Z6.0"))  /* Nr. des Auswahlbezirks (systemfrei) */
         || strip(putn(ef4,"Z3.0"))  /* Nr. des Haushalts im Auswahlbezirk (systemfrei) */
         || strip(putn(ef63,"Z2.0")) /* Personennummer */
        ;
  label idpers= "ID Person (ef1 ef3 ef4 ef63)";

  if (ef5b>=1 & ef5b<=2)  then file = 2 ; /* Zuordnung Jahresberhnge => 2012, sonst => 2013 */
  if (ef5b>=-8 & ef5b<=0) then file = 3;
  label file= "Datenquelle";

  rename id = id13;
run;

* Doppelte IDs pro Panelzeitpunkt (file)? ;
proc sort data=suf13_1;
     by idpers file;
run;

proc summary data = suf13_1 nway noprint; 
 class idpers file ; 
 var ef1;
       output out = temp(drop= _type_ _freq_) n = n_file; 
run; 

proc sort data = temp; 
 by idpers; 
run; 

data suf13_1; 
 merge suf13_1 temp; 
 by idpers ; 
run; 

proc sort data=suf13_1;
     by idpers file;
run;

proc print data=suf13_1  (where = (n_file=2)); 
    var idpers file ef12 id13; 
run;

data suf13_1 (drop = n_file); 
     set suf13_1;
* Datenbereinigung - betrifft nur Ausfallstze mit doppelter Panelzeit (file) ;
   if (id13 =  55626) then file = -1;
   if (id13 = 126328) then file = -1;
   if (id13 = 384549) then file = -1;
   if (id13 = 385396) then file = -1;
   if (id13 = 390124) then file = -1;
run;
* n = 525.787 ;

* =============================================================================;

* 1.3 Aufbereitung SUF MZ 2014, Variablenauswahl.
*       Die Dateinamen entsprechen
*       https://www.gesis.org/missy/files/documents/MZ/setups/sas/setup14.sas;

data suf14_1; 
  set "<Vollstndiger Dateiname der SAS Datendatei SUF 2014>" 
  (keep = 
    EF1   /* Bundesland */
    EF3   /* Nr. des Auswahlbezirks (systemfrei) */
    EF4   /* Nr. des Haushalts im Auswahlbezirk (systemfrei) */
    EF5b  /* Jahresberhang aus dem Vorjahr */
    EF12  /* Berichtsquartal */
    EF63  /* Personennummer */
    EF5a  /* Nr. der Person im Haushalt (systemfrei) */
    EF30  /* Bevlkerung: Haupt- oder Nebenwohnsitz */
    EF31  /* Bevlkerung: Privathaushalte */
    EF45  /* Zuzug (i. d. letzten 12 Monaten) */
    EF46  /* Geschlecht */
    EF47  /* Geburtsjahr */
    EF451 /* Selber Wohnsitz (vor einem Jahr) (FB) */
    EF952 /* Standardhochrechnungsfaktor Jahr (in 1000) - neuer Hochrechnungsrahmen */
    ID    /* Identifikationsnummer */ ) ;

*  Generiere Personenidentifikator ohne Kennung des Jahresberhangs ;
idpers =    strip(putn(ef1,"Z2.0"))  /* Bundesland */
         || strip(putn(ef3,"Z6.0"))  /* Nr. des Auswahlbezirks (systemfrei) */
         || strip(putn(ef4,"Z3.0"))  /* Nr. des Haushalts im Auswahlbezirk (systemfrei) */
         || strip(putn(ef63,"Z2.0")) /* Personennummer */
        ;
  label idpers= "ID Person (ef1 ef3 ef4 ef63)";

  if (ef5b>=1 & ef5b<=2)  then file = 4 ; /* Zuordnung Jahresberhnge => 2013, sonst => 2014 */
  if (ef5b>=-8 & ef5b<=0) then file = 5;
  label file= "Datenquelle";

  rename id = id14;
run;

* Doppelte IDs pro Panelzeitpunkt (file)? ;
proc sort data=suf14_1;
     by idpers file ef12;
run;

proc summary data = suf14_1 nway noprint; 
 class idpers file ; 
 var ef1;
       output out = temp(drop=_freq_ _type_ ) n = n_idpers;
run; 

data suf14_1; 
 merge suf14_1 temp; 
 by idpers file; 
run; 

proc freq data = suf14_1;
  tables  n_idpers*file n_idpers*ef5b /norow nocol nopercent ;
run;

* Datenbereinigung betrifft nur Ausfallstze mit doppelter Panelzeit (file).
* Satz mit niedrigerem Quartal als doppelt kennzeichnen;
proc summary data=suf14_1 nway noprint; 
 class idpers file ; 
 var ef12; 
 output out= temp(drop=_freq_ _type_ )min=min_idpers;
run;

data suf14_1; 
 merge suf14_1 temp; 
 by idpers file; 
run; 

data suf14_1; 
   set suf14_1;
      if ( (ef12=min_idpers) & n_idpers=2) then file = -2;
run;

* Doppelte Flle neu ermitteln;
proc summary data = suf14_1 nway noprint; 
 class idpers file ; 
 var ef1;
       output out = temp(drop=_freq_ _type_ ) n = n_idpers;
run; 

data suf14_1; 
 merge suf14_1 temp; 
 by idpers file; 
run; 

proc print data = suf14_1 (where=(n_idpers=2));
      var idpers file id14 ef12 ef5b ef30 ef4 ef63;
run;

* Korrektur  ;
data suf14_1; 
   set suf14_1;
   if (id14=351460 | id14=354667) then file = 5;
run;

data suf14_1 (drop = n_idpers min_idpers); 
     set suf14_1;
run;
* n = 526201 ;

* =============================================================================;

* 1.4 Aufbereitung SUF MZ 2015, Variablenauswahl.
*       Die Dateinamen entsprechen
*       https://www.gesis.org/missy/files/documents/MZ/setups/sas/setup15.sas;

data suf15_1; 
  set "<Vollstndiger Dateiname der SAS Datendatei SUF 2015>" 
  (keep = 
    EF1   /* Bundesland */
    EF3   /* Nr. des Auswahlbezirks (systemfrei) */
    EF4   /* Nr. des Haushalts im Auswahlbezirk (systemfrei) */
    EF5b  /* Jahresberhang aus dem Vorjahr */
    EF12  /* Berichtsquartal */
    EF63  /* Personennummer */
    EF5a  /* Nr. der Person im Haushalt (systemfrei) */
    EF30  /* Bevlkerung: Haupt- oder Nebenwohnsitz */
    EF31  /* Bevlkerung: Privathaushalte */
    EF45  /* Zuzug (i. d. letzten 12 Monaten) */
    EF46  /* Geschlecht */
    EF47  /* Geburtsjahr */
    EF451 /* Selber Wohnsitz (vor einem Jahr) (FB) */
    EF952 /* Standardhochrechnungsfaktor Jahr (in 1000) - neuer Hochrechnungsrahmen */
    ID    /* Identifikationsnummer */ ) ;

*  Generiere Personenidentifikator ohne Kennung des Jahresberhangs ;
idpers =    strip(putn(ef1,"Z2.0"))  /* Bundesland */
         || strip(putn(ef3,"Z6.0"))  /* Nr. des Auswahlbezirks (systemfrei) */
         || strip(putn(ef4,"Z3.0"))  /* Nr. des Haushalts im Auswahlbezirk (systemfrei) */
         || strip(putn(ef63,"Z2.0")) /* Personennummer */
        ;
  label idpers= "ID Person (ef1 ef3 ef4 ef63)";

  if (ef5b>=1 & ef5b<=2)  then file = 6; /* Zuordnung Jahresberhnge => 2014, sonst => 2015 */
  if (ef5b>=-8 & ef5b<=0) then file = 7;
  label file= "Datenquelle";

  rename id = id15;
run;

* Doppelte IDs pro Panelzeitpunkt (file)? ;
proc sort data=suf15_1;
     by idpers file ef12;
run;

proc summary data = suf15_1 nway noprint; 
 class idpers file ; 
 var ef1;
       output out = temp(drop=_freq_ _type_ ) n = n_idpers;
run; 

data suf15_1; 
 merge suf15_1 temp; 
 by idpers file; 
run; 

proc freq data = suf15_1;
  tables  n_idpers*file n_idpers*ef5b /norow nocol nopercent ;
run;
* OK;

data suf15_1 (drop = n_idpers); 
     set suf15_1;
run;
* n = 531.738 ;


* ============================================================================;

* 2 Files untereinander stellen (long format) ;

data p.panel_12131415_v1; 
set suf12_1 suf13_1 suf14_1 suf15_1; 
   if (file=1) then ejahr = 1;            /* 2012 */
   if (file>=2 & file<=3) then ejahr = 2; /* 2013 */
   if (file>=4 & file<=5) then ejahr = 3; /* 2014 */ 
   if (file>=6 & file<=7) then ejahr = 4; /* 2015 */ 
   label ejahr = "Erhebungsjahr";
run;

proc freq data=p.panel_12131415_v1 ; 
    tables file  /norow nocol nopercent missing; 
run;

* ----------------------------------------------------------------------------;
* Prfung auf doppelte Flle und Datenbereinigung ; 
* Datenbereinigung betrifft nur Stze mit doppelter Panelzeit (file);
* Die einzelnen Schritte der Dateninspektion werden aus Platzgrnden nicht 
* dargestellt;

data p.panel_12131415_v1 ;
  set p.panel_12131415_v1;

  * MZ 2013 file=-3: doppelte Ausfallstze: 2013|2012, 2013: ef5b=1;
  if (id13 =  74945) then file = -3;
  if (id13 = 128105) then file = -3;
  if (id13 = 225706) then file = -3;

  * MZ 2015 file=-4: doppelte Stze 2015|2014, 2015: ef5b=1;
  if (id15=175755)   then file = -4;
  if (id15=175756)   then file = -4; 

  * t3: Prfung doppelte Flle MZ 2015/2014 (s.u.);
  t3 =  (file>=5 & file<=6);
run;

proc freq data=p.panel_12131415_v1 ; 
    tables file  /norow nocol nopercent missing; 
run;

/* -----------------------------------------------------------------------------
Bei Dateninspektionen ist aufgefallen, dass im Unterschied zum MZ 2014 im 
MZ 2015 in Variable EF5b die Jahresberhnge bzw. Ausfallstze nicht mit 
 -8 oder -7 recodiert sind. 
Die Angaben im MZ 2015 sind deshalb in Bezug auf Haushalte des Jahresberhangs
informativer. 
Dies spricht dafr, bei doppelten Fllen die Angaben zum Jahresberhang 
(ef5b=1,2) aus dem MZ 2015 (ejahr=4) als Angaben zum Panelzeitpunkt 2014 zu 
verwenden und die Angaben der Ausfallstze (EF5b<0) aus dem MZ 2014 (ejahr=3) 
als 2013 zu befragende Jahresberhnge zu codieren. 
*/

proc sort data=p.panel_12131415_v1;
     by idpers;
run;

proc summary data = p.panel_12131415_v1 nway noprint; 
 by idpers; 
 var t3;
     output out = temp(drop= _type_ _freq_) sum= n_t3; 
run;

data p.panel_12131415_v1; 
 merge p.panel_12131415_v1 temp; 
 by idpers ; 
run; 

* ----------------------------------------------------------------------------;

* doppelte Stze rekodieren ;
data p.panel_12131415_v1; 
  set p.panel_12131415_v1;
  * doppelte Ausfallstze;
  if (ejahr=3 & file>=5 & file<=6 & n_t3=2 & ef5b<0) then file = 4; 
  * Ausnahmen;
  if (ejahr=3 & file=4 & id14=539591) then file = -4;
  if (ejahr=3 & file=4 & id14=539592) then file = -4;
run;

proc sort data=p.panel_12131415_v1;
     by idpers file;
run;

* Satznummer pro idpers ;
data p.panel_12131415_v1;
  set p.panel_12131415_v1;
	 by idpers ;
        retain p1 0;
        if first.idpers       then p1 = 0;
        if (ef1>=1 & ef1<=16) then p1 = p1 + 1;
run;

proc sort data=p.panel_12131415_v1;
     by idpers file;
run;

proc freq data=p.panel_12131415_v1 ; 
     tables file /norow nocol nopercent missing; 
     tables file * p1 /norow nocol nopercent missing; 
run;
/*                     Kumulative
file    Hufigkeit     Hufigkeit
---------------------------------
  -4            4             4
  -3            3             7
  -2          672           679
  -1            5           684
   1       498033        498717
   2        16534        515251
   3       509245       1024496
   4        18654       1043150
   5       506873       1550023
   6        20733       1570756
   7       511003       2081759
*/

* doppelte Stze ausschlieen;
data  p.panel_12131415_v1 (where = (file>=1 & file<=7));
  set p.panel_12131415_v1 (drop = t3 n_t3);

  * Kennzeichnung der Ausfallstze; 
  ausfall = (ef63<0 | ef5b<0 | ef31<0);
  label ausfall= "Ausfallsatz (ef63<0 | ef5b<0 | ef31<0)";

  * Angaben zu 2012,...,2015: 0=nein, 1=ja;
  t1 = (file>=1 & file<=2); /* 2012 */
  t2 = (file>=3 & file<=4); /* 2013 */
  t3 = (file>=5 & file<=6); /* 2014 */
  t4 = (file=7);            /* 2015 */
run;

proc sort data=p.panel_12131415_v1;
     by idpers ausfall file;
run;

proc summary data = p.panel_12131415_v1 nway noprint; 
 by idpers; 
 var t1 t2 t3 t4;
     output out = temp(drop= _type_ _freq_) sum= n_t1 n_t2 n_t3 n_t4;  
run;

* Kontrolle: pro Panelzeitpunkt max. 1 Satz?;
proc means data=temp n mean stddev min max maxdec=8; 
run; 
* OK;

* ----------------------------------------------------------------------------;

* Angaben zu den Panelzeitpunkten pro Panel-ID;
data p.panel_12131415_v1; 
   merge p.panel_12131415_v1 temp ;
   by idpers;
   ptyp = -1;  /* Angaben zum Panelzeitpunkt 201*: */
   if (n_t1=1 & n_t2=1 & n_t3=1 & n_t4=1) then ptyp =  0;
   if (n_t1=1 & n_t2=0 & n_t3=0 & n_t4=0) then ptyp =  1;
   if (n_t1=1 & n_t2=1 & n_t3=0 & n_t4=0) then ptyp =  2;
   if (n_t1=1 & n_t2=1 & n_t3=1 & n_t4=0) then ptyp =  3;
   if (n_t1=1 & n_t2=1 & n_t3=0 & n_t4=1) then ptyp =  4;
   if (n_t1=1 & n_t2=0 & n_t3=1 & n_t4=0) then ptyp =  5;
   if (n_t1=1 & n_t2=0 & n_t3=1 & n_t4=1) then ptyp =  6;
   if (n_t1=1 & n_t2=0 & n_t3=0 & n_t4=1) then ptyp =  7;
   if (n_t1=0 & n_t2=1 & n_t3=0 & n_t4=0) then ptyp =  8;
   if (n_t1=0 & n_t2=1 & n_t3=1 & n_t4=0) then ptyp =  9;
   if (n_t1=0 & n_t2=1 & n_t3=1 & n_t4=1) then ptyp = 10;
   if (n_t1=0 & n_t2=1 & n_t3=0 & n_t4=1) then ptyp = 11;
   if (n_t1=0 & n_t2=0 & n_t3=1 & n_t4=0) then ptyp = 12;
   if (n_t1=0 & n_t2=0 & n_t3=1 & n_t4=1) then ptyp = 13;
   if (n_t1=0 & n_t2=0 & n_t3=0 & n_t4=1) then ptyp = 14;
run;

proc format library = library;
 Value ptyp  0 = "[0] 2345"   1 = "[1] 2---"   2 = "[2] 23--"   3 = "[3] 234-"   
             4 = "[4] 23-5"   5 = "[5] 2-4-"   6 = "[6] 2-45"   7 = "[7] 2--5"
             8 = "[8] -3--"   9 = "[9] -34-"  10 = "[10] -345" 11 = "[11] -3-5"
            12 = "[12] --4-" 13 = "[13] --45" 14 = "[14] ---5"
            -1 = "[-1] Ausfallstze ef4<0 | ef5b<0 | ef63<0";
run;

proc freq data=p.panel_12131415_v1 ; 
    tables ptyp  /missing; 
	Format ptyp ptyp.;
run;

/*                                       Kumulative      Kumulativer
ptyp          Hufigkeit     Prozent     Hufigkeit      Prozentwert
--------------------------------------------------------------------
[0] 2345          363336       17.46        363336          17.46
[1] 2---          174783        8.40        538119          25.86
[2] 23--          270422       12.99        808541          38.85
[3] 234-          334800       16.09       1143341          54.94
[4] 23-5            1662        0.08       1145003          55.02
[5] 2-4-            2244        0.11       1147247          55.13
[6] 2-45            1182        0.06       1148429          55.18
[7] 2--5             138        0.01       1148567          55.19
[8] -3--           87416        4.20       1235983          59.39
[9] -34-           46260        2.22       1282243          61.61
[10] -345         235461       11.31       1517704          72.93
[11] -3-5           1334        0.06       1519038          72.99
[12] --4-          64831        3.12       1583869          76.11
[13] --45         314416       15.11       1898285          91.22
[14] ---5         182790        8.78       2081075         100.00
*/

* ============================================================================;

* 3 Typisierung zum Ausfall erstellen;

* === PSU-Ebene === ;
* ID Auswahlbezirk ;
data p.panel_12131415_v1;
  set p.panel_12131415_v1 ;
  
  *  Generiere Identifikator fr Auswahlbezirk (PSU) ;
  idpsu =    strip(putn(ef1,"Z2.0"))  /* Bundesland */
          || strip(putn(ef3,"Z6.0"))  /* Nr. des Auswahlbezirks (systemfrei) */
        ;
  label idpsu= "ID Auswahlbezirk (ef1 ef3)";
run;

*  Nach Sortierung stehen Ausfallstze nach Stzen befragter Personen;
proc sort data=p.panel_12131415_v1;
     by idpsu ausfall idpers ptyp;
run;

* psu_1: 1. Satz eines Auswahlbezirks ;
data p.panel_12131415_v1;
  set p.panel_12131415_v1;
  psu_1 + 1;
  by idpsu;
  if first.idpsu then psu_1 = 1;
run;

/* Ausfallgrund "Wechsel der Rotationsgruppe" nherungsweise ermitteln.
   Nur fr Stze, die in EF4 oder EF5b gltige Werte aufweisen, d. h. bei
   Ausfallstzen werden Stze ausgeschlossen, die in EF4 oder EF5b mit 
   -7 oder -8 codiert sind. */
data p.panel_12131415_v1;
  set p.panel_12131415_v1;
  psu12 = (t1=1 & ef5b>=0 & ef5b<=2 & ef4>=0 & ef4<=999);
  label psu12 = "Satz der Stichprobe 2012 (Panelzeitpunkt)";
  psu13 = (t2=1 & ef5b>=0 & ef5b<=2 & ef4>=0 & ef4<=999);
  label psu13 = "Satz der Stichprobe 2013 (Panelzeitpunkt)";
  psu14 = (t3=1 & ef5b>=0 & ef5b<=2 & ef4>=0 & ef4<=999);
  label psu14 = "Satz der Stichprobe 2014 (Panelzeitpunkt)";
  psu15 = (t4=1 & ef5b>=0 & ef5b<=2 & ef4>=0 & ef4<=999);
  label psu15 = "Satz der Stichprobe 2015 (Panelzeitpunkt)";
run; 

proc sort data=p.panel_12131415_v1;
     by idpsu ausfall idpers ptyp;
run;

proc summary data = p.panel_12131415_v1 nway noprint; 
 by idpsu; 
 var psu12 psu13 psu14 psu15;
       output out = temp(drop= _type_ _freq_) sum= n_psu12 n_psu13 n_psu14 n_psu15; 
run;

* Angaben zu den Panelzeitpunkten pro Auswahlbezirk (PSU);
data p.panel_12131415_v1;
    merge p.panel_12131415_v1 temp  ;
    by idpsu;
run;

data p.panel_12131415_v1;
   set p.panel_12131415_v1;
	ptyp_psu = .;
    if (n_psu12>=1  & n_psu13>=1 & n_psu14>=1 & n_psu15>=1) then ptyp_psu =  0;
    if (n_psu12>=1  & n_psu13=0  & n_psu14=0  & n_psu15=0)  then ptyp_psu =  1;
    if (n_psu12>=1  & n_psu13>=1 & n_psu14=0  & n_psu15=0)  then ptyp_psu =  2;
    if (n_psu12>=1  & n_psu13>=1 & n_psu14>=1 & n_psu15=0)  then ptyp_psu =  3;
    if (n_psu12>=1  & n_psu13>=1 & n_psu14=0  & n_psu15>=1) then ptyp_psu =  4;
    if (n_psu12>=1  & n_psu13=0  & n_psu14>=1 & n_psu15=0)  then ptyp_psu =  5;
    if (n_psu12>=1  & n_psu13=0  & n_psu14>=1 & n_psu15>=1) then ptyp_psu =  6;
    if (n_psu12>=1  & n_psu13=0  & n_psu14=0  & n_psu15>=1) then ptyp_psu =  7;
    if (n_psu12=0   & n_psu13>=1 & n_psu14=0  & n_psu15=0)  then ptyp_psu =  8;
    if (n_psu12=0   & n_psu13>=1 & n_psu14>=1 & n_psu15=0)  then ptyp_psu =  9;
    if (n_psu12=0   & n_psu13>=1 & n_psu14>=1 & n_psu15>=1) then ptyp_psu = 10;
    if (n_psu12=0   & n_psu13>=1 & n_psu14=0  & n_psu15>=1) then ptyp_psu = 11;
    if (n_psu12=0   & n_psu13=0  & n_psu14>=1 & n_psu15=0)  then ptyp_psu = 12;
    if (n_psu12=0   & n_psu13=0  & n_psu14>=1 & n_psu15>=1) then ptyp_psu = 13;
    if (n_psu12=0   & n_psu13=0  & n_psu14=0  & n_psu15>=1) then ptyp_psu = 14;
    if (ptyp_psu=. & ausfall=1)                             then ptyp_psu = -1;
    label ptyp_psu = "Panelstze - PSU-Ebene (ohne Ausfallstze: ef63<0 | ef5b<0 | ef31<0)";
    label n_psu12 = "Anzahl gltige Stze 2012 im Auswahlbezirk";
    label n_psu13 = "Anzahl gltige Stze 2013 im Auswahlbezirk";
    label n_psu14 = "Anzahl gltige Stze 2014 im Auswahlbezirk";
	label n_psu15 = "Anzahl gltige Stze 2015 im Auswahlbezirk";
run;

proc format library = library;
 Value ptyp_psu 0 = "[0] 2345"   1 = "[1] 2---"   2 = "[2] 23--"   3 = "[3] 234-"
                4 = "[4] 23-5"   5 = "[5] 2-4-"   6 = "[6] 2-45"   7 = "[7] 2--5"
                8 = "[8] -3--"   9 = "[9] -34-"  10 = "[10] -345" 11 = "[11] -3-5"
               12 = "[12] --4-" 13 = "[13] --45" 14 = "[14] ---5" 
               -1 = "[-1] Ausfallsatz";
run;

proc freq data=p.panel_12131415_v1; 
    tables ptyp_psu /missing ; 
		Format ptyp_psu ptyp_psu.;
run;
/*      ptyp_psu    Hufigkeit     Prozent     Hufigkeit      Prozentwert
--------------------------------------------------------------------------
[-1] Ausfallsatz        12998        0.62         12998           0.62
[0] 2345               514534       24.72        527532          25.35
[1] 2---               128531        6.18        656063          31.53
[2] 23--               265190       12.74        921253          44.27
[3] 234-               387740       18.63       1308993          62.90
[4] 23-5                  427        0.02       1309420          62.92
[5] 2-4-                   21        0.00       1309441          62.92
[8] -3--                38267        1.84       1347708          64.76
[9] -34-                 2677        0.13       1350385          64.89
[10] -345              285486       13.72       1635871          78.61
[11] -3-5                 178        0.01       1636049          78.62
[12] --4-                1674        0.08       1637723          78.70
[13] --45              319413       15.35       1957136          94.04
[14] ---5              123939        5.96       2081075         100.00
*/

/* t*_psu : Panelzeitpunkte eines Auswahlbezirks (1. Satz einer PSU, ohne 
            Ausfallstze, die in EF4 oder EF5b mit -7 oder -8 codiert sind.) */
data p.panel_12131415_v1;
   set p.panel_12131415_v1;
   if (psu_1=1) then do;
        if (n_psu12=0)                 then t1_psu=0;
		if (n_psu12>=1 & n_psu12<=999) then t1_psu=1;
		label t1_psu = "PSU in 2012  (ohne Ausfallstze, 1. PSU-Satz)";
        if (n_psu13=0)                 then t2_psu=0;
        if (n_psu13>=1 & n_psu13<=999) then t2_psu=1;
		label t2_psu = "PSU in 2013  (ohne Ausfallstze, 1. PSU-Satz)";
        if (n_psu14=0)                 then t3_psu=0;
        if (n_psu14>=1 & n_psu14<=999) then t3_psu=1;
		label t3_psu = "PSU in 2014  (ohne Ausfallstze, 1. PSU-Satz)";
		if (n_psu15=0)                 then t4_psu=0;
        if (n_psu15>=1 & n_psu15<=999) then t4_psu=1;
		label t4_psu = "PSU in 2015  (ohne Ausfallstze, 1. PSU-Satz)";
   end;
run;

* Ausfalltypisierung: Angaben fr Personen | Angaben fr Auswahlbezirke;
data p.panel_12131415_v1;
   set p.panel_12131415_v1;
      * ptyp = ptyp_psu;
      if (ptyp= 0 & ptyp_psu= 0) then ausftyp =  0;
      if (ptyp= 1 & ptyp_psu= 1) then ausftyp =  1;
      if (ptyp= 2 & ptyp_psu= 2) then ausftyp =  2;
      if (ptyp= 3 & ptyp_psu= 3) then ausftyp =  3;
      if (ptyp= 4 & ptyp_psu= 4) then ausftyp =  4;
      if (ptyp= 8 & ptyp_psu= 8) then ausftyp =  5;
      if (ptyp= 9 & ptyp_psu= 9) then ausftyp =  6;
      if (ptyp=10 & ptyp_psu=10) then ausftyp =  7;
      if (ptyp=11 & ptyp_psu=11) then ausftyp =  8;
      if (ptyp=12 & ptyp_psu=12) then ausftyp =  9;
      if (ptyp=13 & ptyp_psu=13) then ausftyp = 10;
      if (ptyp=14 & ptyp_psu=14) then ausftyp = 11;
      * ptyp < ptyp_psu;
      if (ptyp= 1 & ptyp_psu= 2) then ausftyp = 12;
      if (ptyp= 1 & ptyp_psu= 3) then ausftyp = 13;
      if (ptyp= 1 & ptyp_psu= 4) then ausftyp = 14;
      if (ptyp= 1 & ptyp_psu= 5) then ausftyp = 15;
      if (ptyp= 2 & ptyp_psu= 3) then ausftyp = 16;
      if (ptyp= 2 & ptyp_psu= 4) then ausftyp = 17;
      if (ptyp= 8 & ptyp_psu= 9) then ausftyp = 18;
      if (ptyp= 8 & ptyp_psu=10) then ausftyp = 19;
      if (ptyp= 8 & ptyp_psu=11) then ausftyp = 20;
      if (ptyp= 9 & ptyp_psu=10) then ausftyp = 21;
      if (ptyp=12 & ptyp_psu=13) then ausftyp = 22;
      * ptyp > ptyp_psu;
      if (ptyp= 1 & ptyp_psu= 0) then ausftyp = 23;
      if (ptyp= 2 & ptyp_psu= 0) then ausftyp = 24;
      if (ptyp= 3 & ptyp_psu= 0) then ausftyp = 25;
      if (ptyp= 4 & ptyp_psu= 0) then ausftyp = 26;
      if (ptyp= 5 & ptyp_psu= 0) then ausftyp = 27;
      if (ptyp= 5 & ptyp_psu= 3) then ausftyp = 28;
      if (ptyp= 6 & ptyp_psu= 0) then ausftyp = 29;
      if (ptyp= 7 & ptyp_psu= 0) then ausftyp = 30;
      if (ptyp= 8 & ptyp_psu= 0) then ausftyp = 31;
      if (ptyp= 8 & ptyp_psu= 2) then ausftyp = 32;
      if (ptyp= 8 & ptyp_psu= 3) then ausftyp = 33;
      if (ptyp= 8 & ptyp_psu= 4) then ausftyp = 34;
      if (ptyp= 9 & ptyp_psu= 0) then ausftyp = 35;
      if (ptyp= 9 & ptyp_psu= 3) then ausftyp = 36;
      if (ptyp=10 & ptyp_psu= 0) then ausftyp = 37;
      if (ptyp=11 & ptyp_psu= 0) then ausftyp = 38;
      if (ptyp=11 & ptyp_psu=10) then ausftyp = 39;
      if (ptyp=12 & ptyp_psu= 0) then ausftyp = 40;
      if (ptyp=12 & ptyp_psu= 3) then ausftyp = 41;
      if (ptyp=12 & ptyp_psu= 5) then ausftyp = 42;
      if (ptyp=12 & ptyp_psu= 9) then ausftyp = 43;
      if (ptyp=12 & ptyp_psu=10) then ausftyp = 44;
      if (ptyp=13 & ptyp_psu= 0) then ausftyp = 45;
      if (ptyp=13 & ptyp_psu=10) then ausftyp = 46;
      if (ptyp=14 & ptyp_psu= 0) then ausftyp = 47;
      if (ptyp=14 & ptyp_psu= 4) then ausftyp = 48;
      if (ptyp=14 & ptyp_psu=10) then ausftyp = 49;
      if (ptyp=14 & ptyp_psu=11) then ausftyp = 50;
      if (ptyp=14 & ptyp_psu=13) then ausftyp = 51;
      if (ausfall=1)             then ausftyp = -1;
      label ausftyp = "Ausfalltyp: Ausfall Satz |  Angaben Auswahlbezirk (Proxy) 201*";
run;

proc format library = library;
 Value ausftyp  0="[0] 2345|2345"     1="[1] 2---|2---"   2="[2] 23--|23--"
                3="[3] 234-|234-"     4="[4] 23-5|23-5"   5="[5] -3--|-3--"
                6="[6] -34-|-34-"     7="[7] -345|-345"   8="[8] -3-5|-3-5"
                9="[9] --4-|--4-"   10="[10] --45|--45"  11="[11] ---5|---5"
               12="[12] 2---|23--"  13="[13] 2---|234-"  14="[14] 2---|23-5"
               15="[15] 2---|2-4-"  16="[16] 23--|234-"  17="[17] 23--|23-5"
               18="[18] -3--|-34-"  19="[19] -3--|-345"  20="[20] -3--|-3-5"
               21="[21] -34-|-345"  22="[22] --4-|--45"  23="[23] 2---|2345"
               24="[24] 23--|2345"  25="[25] 234-|2345"  26="[26] 23-5|2345"
               27="[27] 2-4-|2345"  28="[28] 2-4-|234-"  29="[29] 2-45|2345"
               30="[30] 2--5|2345"  31="[31] -3--|2345"  32="[32] -3--|23--"
               33="[33] -3--|234-"  34="[34] -3--|23-5"  35="[35] -34-|2345"
               36="[36] -34-|234-"  37="[37] -345|2345"  38="[38] -3-5|2345"
               39="[39] -3-5|-345"  40="[40] --4-|2345"  41="[41] --4-|234-"
               42="[42] --4-|2-4-"  43="[43] --4-|-34-"  44="[44] --4-|-345"
               45="[45] --45|2345"  46="[46] --45|-345"  47="[47] ---5|2345"
               48="[48] ---5|23-5"  49="[49] ---5|-345"  50="[50] ---5|-3-5"
               51="[51] ---5|--45"  
               -1="[-1] Ausfallstze ef4<0 | ef5b<0 | ef63<0";
run;

proc freq data=p.panel_12131415_v1; 
    tables ausftyp /missing ; 
	Format ausftyp ausftyp.;
run;
/*                                                                  Kumulativer
ausftyp                                     Hufigkeit     Prozent  Prozentwert
-------------------------------------------------------------------------------
[-1] Ausfallstze ef4<0 | ef5b<0 | ef63<0       173605        8.34         8.34
[0] 2345|2345                                   352348       16.93        25.27
[1] 2---|2---                                   120644        5.80        31.07
[2] 23--|23--                                   218504       10.50        41.57
[3] 234-|234-                                   294330       14.14        55.71
[4] 23-5|23-5                                      111        0.01        55.72
[5] -3--|-3--                                    35843        1.72        57.44
[6] -34-|-34-                                     1886        0.09        57.53
[7] -345|-345                                   203895        9.80        67.33
[8] -3-5|-3-5                                       54        0.00        67.33
[9] --4-|--4-                                     1290        0.06        67.39
[10] --45|--45                                  262228       12.60        79.99
[11] ---5|---5                                  117580        5.65        85.64
[12] 2---|23--                                   13219        0.64        86.28
[13] 2---|234-                                   12384        0.60        86.87
[14] 2---|23-5                                      30        0.00        86.88
[15] 2---|2-4-                                       2        0.00        86.88
[16] 23--|234-                                   19328        0.93        87.80
[17] 23--|23-5                                      56        0.00        87.81
[18] -3--|-34-                                     190        0.01        87.82
[19] -3--|-345                                    9226        0.44        88.26
[20] -3--|-3-5                                      18        0.00        88.26
[21] -34-|-345                                   17482        0.84        89.10
[22] --4-|--45                                   18318        0.88        89.98
[23] 2---|2345                                   12651        0.61        90.59
[24] 23--|2345                                   19148        0.92        91.51
[25] 234-|2345                                   28338        1.36        92.87
[26] 23-5|2345                                     942        0.05        92.92
[27] 2-4-|2345                                     296        0.01        92.93
[28] 2-4-|234-                                     862        0.04        92.97
[29] 2-45|2345                                    1020        0.05        93.02
[30] 2--5|2345                                     102        0.00        93.03
[31] -3--|2345                                    2710        0.13        93.16
[32] -3--|23--                                   11076        0.53        93.69
[33] -3--|234-                                    2541        0.12        93.81
[34] -3--|23-5                                       3        0.00        93.81
[35] -34-|2345                                    3782        0.18        93.99
[36] -34-|234-                                   17174        0.83        94.82
[37] -345|2345                                   22473        1.08        95.90
[38] -3-5|2345                                     204        0.01        95.91
[39] -3-5|-345                                     684        0.03        95.94
[40] --4-|2345                                    2609        0.13        96.07
[41] --4-|234-                                   10287        0.49        96.56
[42] --4-|2-4-                                       5        0.00        96.56
[43] --4-|-34-                                     298        0.01        96.57
[44] --4-|-345                                    2877        0.14        96.71
[45] --45|2345                                   16352        0.79        97.50
[46] --45|-345                                   20266        0.97        98.47
[47] ---5|2345                                    9544        0.46        98.93
[48] ---5|23-5                                      58        0.00        98.93
[49] ---5|-345                                    7842        0.38        99.31
[50] ---5|-3-5                                      52        0.00        99.31
[51] ---5|--45                                   14308        0.69       100.00
* N = 2081075
*/

/* -----------------------------------------------------------------------------
ausftyp  Panelangaben zur Person   Auswahlbezirk 

       0  2345 2345 := Angaben zu 2012-2015 fr Personen und Auswahlbez. 
        
       1  2--- 2--- := nur Angaben zu 2012 fr Personen und Auswahlbez. 
                        ~ nicht informativer Ausfall (Rotationsgruppe ausgeschieden) ~
           (...)
      12  2--- 23-- := Angaben nur zu 2012 fr Personen, 2012-2013 fr Auswahlbez.
                        ~ Wegzug, Todesfall ... ~
           (...)
      30  2--5 2345 := Angaben zu 2012 und 2015 fr Personen, 2012-2015 fr Auswahlbez.
                        ~ temporrer Ausfall 2013 und 2014 ~ 
          (...) 
      47 ---5 2345  := Angaben zu 2015 fr Personen, 2012-2015 fr Auswahlbez.
                        ~ Ausflle 2012-2014 aufgrund von Zuzgen oder Geburten ~
--------
Hinweis auf Differenzierungsmglichkeiten nach EF45 Zuzug (i. d. letzten 
12 Monaten): -5 Entfllt (Keine Wiederholungsbefragung) 
= erstmals befragte Rotationsgruppe.
----------------------------------------------------------------------------- */

* Recodierung Panelzeitpunkte ;
data p.panel_12131415_v1;
   set p.panel_12131415_v1;
       if (file>=1 & file<=2) then t = 1; /* 2012 */
       if (file>=3 & file<=4) then t = 2; /* 2013 */
       if (file>=5 & file<=6) then t = 3; /* 2014 */
       if (file=7)            then t = 4; /* 2015 */
       label t = "Panelzeitpukt";
run;

* === Erste Ausfallanalysen  ===;

* --- Zusammenfhrung der Daten auf Auswahlbezirksebene (PSU) ---;

* Zusammenfhrung 2012 und 2013 - PSU-Ebene, ohne Ausfallstze, 
  Erhebungszeitpunkte 2012-2015;
proc freq data=p.panel_12131415_v1 
 (where = (psu_1=1 & ef63>0)); 
    tables t2_psu * t1_psu  /missing norow nopercent; 
run;
/*
Hufigkeit|
Col Pct   |       0|       1|  Summe
----------+--------+--------+
        0 |  19508 |   8543 |  28051
          |  68.21 |  25.37 |
----------+--------+--------+
        1 |   9092 |  25134 |  34226
          |  31.79 |  74.63 |
----------+--------+--------+
Summe        28600    33677    62277  */


* Zusammenfhrung 2012 und 2015 - PSU-Ebene, ohne Ausfallstze, 
*   Erhebungszeitpunkte 2012-2015;
proc freq data=p.panel_12131415_v1 
 (where = (psu_1=1 & ef63>0)); 
    tables t4_psu * t1_psu  /missing norow nopercent; 
run;
/*
Hufigkeit|
Col Pct   |       0|       1|  Summe
----------+--------+--------+
        0 |   2955 |  25389 |  28344
          |  10.33 |  75.39 |
----------+--------+--------+
        1 |  25645 |   8288 |  33933
          |  89.67 |  24.61 |
----------+--------+--------+
Summe        28600    33677    62277  */


* 1. Personensatz;
/* 
proc freq data=p.panel_121314_v1 (where = (p1=1)); 
    tables ausftyp * ptyp    / norow nocol nopercent missing; 
	format ausftyp ausftyp.;
	format ptyp ptyp.;
run;
*/

* ============================================================================;

* 4 Files nebeneinander stellen (wide format);

proc sort data=p.panel_12131415_v1;
     by idpers;
run;

/* Zuerst getrennte Dateien fr die Panelzeitpunkte erstellen.
   Ohne Variablen fr Auswahlbezirke (psu_1 psu12 psu13 psu14 psu15)
   sowie p1, t1, t2, t3 und t4. 
   Zeitvernderliche (xij) variablen umbenennen. */

*    Datei fr Panelzeitpunkt 2012 (t=1);
data tmp_t1 (compress=yes)  ;
  set p.panel_12131415_v1 (drop = p1 psu_1 t1 t2 t3 t4 psu12 psu13 psu14 psu15);
  where file>=1 & file<=2;
      /* xij variablen umbenennen */
  rename ef5a  = ef5a_a;
  rename ef5b  = ef5b_a;
  rename ef12  = ef12_a;
  rename ef30  = ef30_a;
  rename ef31  = ef31_a;
  rename ef45  = ef45_a;
  rename ef46  = ef46_a;
  rename ef47  = ef47_a;
  rename ef451 = ef451_a;
  rename ef952 = ef952_a;
  rename id12  = id12_a;
  rename id13  = id13_a;
  rename id14  = id14_a;
  rename id15  = id15_a;
  rename file  = file_a;
  rename ejahr = ejahr_a;
run;

*    Datei fr Panelzeitpunkt 2013 (t=2);
data tmp_t2 ;
  set p.panel_12131415_v1  (drop = p1 psu_1 t1 t2 t3 t4 psu12 psu13 psu14 psu15);
  where file>=3 & file<=4;
      /* xij variablen umbenennen */
  rename ef5a  = ef5a_b;
  rename ef5b  = ef5b_b;
  rename ef12  = ef12_b;
  rename ef30  = ef30_b;
  rename ef31  = ef31_b;
  rename ef45  = ef45_b;
  rename ef46  = ef46_b;
  rename ef47  = ef47_b;
  rename ef451 = ef451_b;
  rename ef952 = ef952_b;
  rename id12  = id12_b;
  rename id13  = id13_b;
  rename id14  = id14_b;
  rename id15  = id15_b;
  rename file  = file_b;
  rename ejahr = ejahr_b;
run;

*    Datei fr Panelzeitpunkt 2014 (t=3);
data tmp_t3 ;
  set p.panel_12131415_v1  (drop = p1 psu_1 t1 t2 t3 t4 psu12 psu13 psu14 psu15);
  where file>=5 & file<=6;
      /* xij variablen umbenennen */
  rename ef5a  = ef5a_c;
  rename ef5b  = ef5b_c;
  rename ef12  = ef12_c;
  rename ef30  = ef30_c;
  rename ef31  = ef31_c;
  rename ef45  = ef45_c;
  rename ef46  = ef46_c;
  rename ef47  = ef47_c;
  rename ef451 = ef451_c;
  rename ef952 = ef952_c;
  rename id12  = id12_c;
  rename id13  = id13_c;
  rename id14  = id14_c;
  rename id15  = id15_c;
  rename file  = file_c;
  rename ejahr = ejahr_c;
run;

*    Datei fr Panelzeitpunkt 2015 (t=4);
data tmp_t4 ;
  set p.panel_12131415_v1  (drop = p1 psu_1 t1 t2 t3 t4 psu12 psu13 psu14 psu15);
  where file=7;
      /* xij variablen umbenennen */
  rename ef5a  = ef5a_d;
  rename ef5b  = ef5b_d;
  rename ef12  = ef12_d;
  rename ef30  = ef30_d;
  rename ef31  = ef31_d;
  rename ef45  = ef45_d;
  rename ef46  = ef46_d;
  rename ef47  = ef47_d;
  rename ef451 = ef451_d;
  rename ef952 = ef952_d;
  rename id12  = id12_d;
  rename id13  = id13_d;
  rename id14  = id14_d;
  rename id15  = id15_d;
  rename file  = file_d;
  rename ejahr = ejahr_d;
run;

*  Zusammenfhrung der Dateien;
data p.panel_12131415_v1w (compress=yes);
     merge tmp_t1 (in=a) /* t1 = 2012 (_a) */
           tmp_t2 (in=b) /* t2 = 2013 (_b) */
           tmp_t3 (in=c) /* t3 = 2014 (_c) */
           tmp_t4 (in=d) /* t4 = 2015 (_d) */ ;
     by idpers;
     time1 = a;
     time2 = b;
     time3 = c;
	 time4 = d;
     label time1 = "Angaben zu 2012";
     label time2 = "Angaben zu 2013";
     label time3 = "Angaben zu 2014";
	 label time4 = "Angaben zu 2015";
run;

data p.panel_12131415_v1w (compress=yes);
     set p.panel_12131415_v1w;
        t1 = n_t1;
        t2 = n_t2;
        t3 = n_t3;
        t4 = n_t4;
        label t1 = "Angaben zu 2012"; /* 0=nein, 1=ja */
        label t2 = "Angaben zu 2013";
        label t3 = "Angaben zu 2014";
        label t4 = "Angaben zu 2015";
run;

proc freq data=p.panel_12131415_v1w; 
    tables ptyp ptyp_psu ausftyp / nocol norow missing;
	format ausftyp ausftyp.;
	format ptyp_psu ptyp_psu.;
	format ptyp ptyp.;
run;

/*                                    Kumulative      Kumulativer
ptyp       Hufigkeit     Prozent     Hufigkeit      Prozentwert
-----------------------------------------------------------------
[0] 2345       90834        8.19         90834           8.19
[1] 2---      174783       15.76        265617          23.95
[2] 23--      135211       12.19        400828          36.14
[3] 234-      111600       10.06        512428          46.20
[4] 23-5         554        0.05        512982          46.25
[5] 2-4-        1122        0.10        514104          46.35
[6] 2-45         394        0.04        514498          46.39
[7] 2--5          69        0.01        514567          46.40
[8] -3--       87416        7.88        601983          54.28
[9] -34-       23130        2.09        625113          56.36
[10] -345      78487        7.08        703600          63.44
[11] -3-5        667        0.06        704267          63.50
[12] --4-      64831        5.85        769098          69.34
[13] --45     157208       14.17        926306          83.52
[14] ---5     182790       16.48       1109096         100.00



                                               Kumulative      Kumulativer
ptyp_psu            Hufigkeit     Prozent     Hufigkeit      Prozentwert
--------------------------------------------------------------------------
[-1] Ausfallsatz         6879        0.62          6879           0.62
[0] 2345               183786       16.57        190665          17.19
[1] 2---               128511       11.59        319176          28.78
[2] 23--               150721       13.59        469897          42.37
[3] 234-               164549       14.84        634446          57.20
[4] 23-5                  289        0.03        634735          57.23
[5] 2-4-                   18        0.00        634753          57.23
[8] -3--                38134        3.44        672887          60.67
[9] -34-                 1666        0.15        674553          60.82
[10] -345              124850       11.26        799403          72.08
[11] -3-5                 149        0.01        799552          72.09
[12] --4-                1625        0.15        801177          72.24
[13] --45              183988       16.59        985165          88.83
[14] ---5              123931       11.17       1109096         100.00


                                                                        Kumulative      Kumulativer
ausftyp                                      Hufigkeit     Prozent     Hufigkeit      Prozentwert
---------------------------------------------------------------------------------------------------
[-1] Ausfallstze ef4<0 | ef5b<0 | ef63<0       132497       11.95        132497          11.95
[0] 2345|2345                                    88087        7.94        220584          19.89
[1] 2---|2---                                   120644       10.88        341228          30.77
[2] 23--|23--                                   109252        9.85        450480          40.62
[3] 234-|234-                                    98110        8.85        548590          49.46
[4] 23-5|23-5                                       37        0.00        548627          49.47
[5] -3--|-3--                                    35843        3.23        584470          52.70
[6] -34-|-34-                                      943        0.09        585413          52.78
[7] -345|-345                                    67965        6.13        653378          58.91
[8] -3-5|-3-5                                       27        0.00        653405          58.91
[9] --4-|--4-                                     1290        0.12        654695          59.03
[10] --45|--45                                  131114       11.82        785809          70.85
[11] ---5|---5                                  117580       10.60        903389          81.45
[12] 2---|23--                                   13219        1.19        916608          82.64
[13] 2---|234-                                   12384        1.12        928992          83.76
[14] 2---|23-5                                      30        0.00        929022          83.76
[15] 2---|2-4-                                       2        0.00        929024          83.76
[16] 23--|234-                                    9664        0.87        938688          84.64
[17] 23--|23-5                                      28        0.00        938716          84.64
[18] -3--|-34-                                     190        0.02        938906          84.66
[19] -3--|-345                                    9226        0.83        948132          85.49
[20] -3--|-3-5                                      18        0.00        948150          85.49
[21] -34-|-345                                    8741        0.79        956891          86.28
[22] --4-|--45                                   18318        1.65        975209          87.93
[23] 2---|2345                                   12651        1.14        987860          89.07
[24] 23--|2345                                    9574        0.86        997434          89.93
[25] 234-|2345                                    9446        0.85       1006880          90.78
[26] 23-5|2345                                     314        0.03       1007194          90.81
[27] 2-4-|2345                                     148        0.01       1007342          90.83
[28] 2-4-|234-                                     431        0.04       1007773          90.86
[29] 2-45|2345                                     340        0.03       1008113          90.90
[30] 2--5|2345                                      51        0.00       1008164          90.90
[31] -3--|2345                                    2710        0.24       1010874          91.14
[32] -3--|23--                                   11076        1.00       1021950          92.14
[33] -3--|234-                                    2541        0.23       1024491          92.37
[34] -3--|23-5                                       3        0.00       1024494          92.37
[35] -34-|2345                                    1891        0.17       1026385          92.54
[36] -34-|234-                                    8587        0.77       1034972          93.32
[37] -345|2345                                    7491        0.68       1042463          93.99
[38] -3-5|2345                                     102        0.01       1042565          94.00
[39] -3-5|-345                                     342        0.03       1042907          94.03
[40] --4-|2345                                    2609        0.24       1045516          94.27
[41] --4-|234-                                   10287        0.93       1055803          95.19
[42] --4-|2-4-                                       5        0.00       1055808          95.20
[43] --4-|-34-                                     298        0.03       1056106          95.22
[44] --4-|-345                                    2877        0.26       1058983          95.48
[45] --45|2345                                    8176        0.74       1067159          96.22
[46] --45|-345                                   10133        0.91       1077292          97.13
[47] ---5|2345                                    9544        0.86       1086836          97.99
[48] ---5|23-5                                      58        0.01       1086894          98.00
[49] ---5|-345                                    7842        0.71       1094736          98.71
[50] ---5|-3-5                                      52        0.00       1094788          98.71
[51] ---5|--45                                   14308        1.29       1109096         100.00
*/

proc freq data=p.panel_12131415_v1w; 
	* Angaben zu 2013 und 2012 - Befragtenstze incl. Ausfallstze;
    tables t2 * t1               / nocol norow nopercent missing;
	* Angaben zu 2014 und 2013;
    tables t3 * t2               / nocol norow nopercent missing;
	* Angaben zu 2015 und 2012;
    tables t4 * t1               / nocol norow nopercent missing;
	* Z. B. Bevlkerung am Hauptwohnsitz (ef30*) 2015 und 2012
      incl. Ausfallstze (ef30*=-8, -7) und Panelausflle (ef30*=.);
    tables ef30_d * ef30_a       / nocol norow nopercent missing;
run; 

/*
t2(Angaben zu 2013)
           t1(Angaben zu 2012)

Hufigkeit|       0|       1|  Summe
----------+--------+--------+
        0 | 404829 | 176368 | 581197
----------+--------+--------+
        1 | 189700 | 338199 | 527899
----------+--------+--------+
Summe       594529   514567  1109096


t3(Angaben zu 2014)
           t2(Angaben zu 2013)

Hufigkeit|       0|       1|  Summe
----------+--------+--------+
        0 | 357642 | 223848 | 581490
----------+--------+--------+
        1 | 223555 | 304051 | 527606
----------+--------+--------+
Summe       581197   527899  1109096


t4(Angaben zu 2015)
           t1(Angaben zu 2012)

Hufigkeit|       0|       1|  Summe
----------+--------+--------+
        0 | 175377 | 422716 | 598093
----------+--------+--------+
        1 | 419152 |  91851 | 511003
----------+--------+--------+
Summe       594529   514567  1109096


ef30_d(Bevlkerung: Haupt- oder Nebenwohnsitz)
           ef30_a(Bevlkerung: Haupt- oder Nebenwohnsitz)

Hufigkeit|       .|      -8|      -7|       1|       2|       3|  Summe
----------+--------+--------+--------+--------+--------+--------+
        . | 175377 |  24902 |   2231 | 383274 |   7323 |   4986 | 598093
----------+--------+--------+--------+--------+--------+--------+
       -8 |  25619 |   2344 |      0 |      0 |      0 |      0 |  27963
----------+--------+--------+--------+--------+--------+--------+
       -7 |  18799 |      0 |    678 |      0 |      0 |      0 |  19477
----------+--------+--------+--------+--------+--------+--------+
        1 | 364292 |      0 |      0 |  85721 |   1009 |    447 | 451469
----------+--------+--------+--------+--------+--------+--------+
        2 |   6001 |      0 |      0 |    613 |    374 |     58 |   7046
----------+--------+--------+--------+--------+--------+--------+
        3 |   4441 |      0 |      0 |    191 |     72 |    344 |   5048
----------+--------+--------+--------+--------+--------+--------+
Summe       594529    27246     2909   469799     8778     5835  1109096

ef30_*
 1 Bevlkerung am Hauptwohnsitz ohne weiteren Wohnsitz
 2 Bevlkerung am Hauptwohnsitz mit weiterem Wohnsitz
 3 Bevlkerung am Nebenwohnsitz (mit weiterem Wohnsitz)
-7 Entfllt (Auswahlbezirk ohne befragten Haushalt)
-8 Entfllt (leerstehende Wohnung, ausgefallene Privathaushalte und Gemeinschaftsunterknfte)
 . keine Angaben zum Panelzeitpunkt
*/

* ============================================================================;

/* === Weitere Ausfallanalysen ===

Fr die Zusammenfhrung der Daten 2012 und 2013 wird fr die Daten aus 2012
eine Zusammenfhrungsquote von 64,9 % und fr die Daten aus 2013 von 67,7 %
berichtet (Herter-Eschweiler/Schimpl-Neimanns 2018, S. 6).

Fr den Panelzeitpunkt t=2 (2013) sind aus der Erhebung 2014 Angaben aus den
Jahresberhngen hinzugekommen. Werden diese bercksichtigt, ergeben sich
andere Zusammenfhrungsquoten. */

* 2012 Befragte mit gltigen Angaben (ohne Ausfallstze) und mit Angaben 
* zu 2013;
proc freq data=p.panel_12131415_v1w; 
    where (ef30_a>=1 & ef30_a<=3) | (ef30_b>=1 & ef30_b<=3);
    tables t2 * t1  / norow nopercent  missing;;
run; 
/*
t2(Angaben zu 2013)
           t1(Angaben zu 2012)

Hufigkeit|
Col Pct   |       0|       1|  Summe
----------+--------+--------+
        0 |      0 | 159900 | 159900
          |   0.00 |  33.01 |
----------+--------+--------+
        1 | 157696 | 324512 | 482208
          | 100.00 |  66.99 |
----------+--------+--------+
Summe       157696   484412   642108
*/

* -----------------------------------------------------------------------------;

/* Differenzierung von Ausfallgrnden - der Fall neuer Rotationsgruppen

Siehe Herter-Eschweiler/Schimpl-Neimanns (2018, S. 8: 
"Nhere Aufklrungen fehlender Angaben zum Zeitpunkt t (2012) knnen mit den 
Angaben der Erhebung t + 1 (2013) zum Zuzug in den letzten 12 Monaten (EF45) 
oder zum Wohnsitz vor 12 Monaten (EF451, ohne Auskunftspflicht) ermittelt 
werden." 
Der Code EF45 = -5 "Entfllt (Keine Wiederholungsbefragung)" weist darauf hin, 
dass eine neue Rotationsgruppe erstmals befragt wurde.
Beispiel:
Fr die nicht zusammenfhrbaren (gltigen) Personenstze der Paneljahre 2012 und 
2013 (t1==0 & t2==1) soll geprft werden, ob die Ausflle mit erstmals befragten
Rotationsgruppen bedingt zusammenhngen. 
*/

proc freq data=p.panel_12131415_v1w ;
    where ( (ef30_a>=1 & ef30_a<=3) | (ef30_b>=1 & ef30_b<=3) ) & t2=1; 
     tables ausftyp * ef45_b  / nocol norow nopercent missing;
       format ausftyp ausftyp.;
run; 
/*
ausftyp(Ausfalltyp: Ausfall Satz |  Angaben Auswahlbezirk (Proxy) 201*)
                  ef45_b(F6 Zuzug (i. d. letzten 12 Monaten))

Hufigkeit       |      -5|       1|       8|       9|  Summe
-----------------+--------+--------+--------+--------+
[0] 2345|2345    |      0 |    182 |  87899 |      6 |  88087
[2] 23--|23--    |      0 |    238 | 109014 |      0 | 109252
[3] 234-|234-    |      0 |    179 |  97927 |      4 |  98110
[4] 23-5|23-5    |      0 |      0 |     37 |      0 |     37
[5] -3--|-3--    |  34922 |    418 |    503 |      0 |  35843
[6] -34-|-34-    |    331 |    221 |    391 |      0 |    943
[7] -345|-345    |  67474 |    125 |    366 |      0 |  67965
[8] -3-5|-3-5    |     27 |      0 |      0 |      0 |     27
[16] 23--|234-   |      0 |     71 |   9592 |      1 |   9664
[17] 23--|23-5   |      0 |      0 |     28 |      0 |     28
[18] -3--|-34-   |    109 |     34 |     47 |      0 |    190
[19] -3--|-345   |   9169 |     15 |     42 |      0 |   9226
[20] -3--|-3-5   |     18 |      0 |      0 |      0 |     18
[21] -34-|-345   |   8643 |     23 |     75 |      0 |   8741
[24] 23--|2345   |      0 |     74 |   9499 |      1 |   9574
[25] 234-|2345   |      0 |     41 |   9402 |      3 |   9446
[26] 23-5|2345   |      0 |      2 |    312 |      0 |    314
[31] -3--|2345   |      0 |   2113 |    597 |      0 |   2710
[32] -3--|23--   |      0 |   9231 |   1843 |      2 |  11076
[33] -3--|234-   |      0 |   2010 |    531 |      0 |   2541
[34] -3--|23-5   |      0 |      3 |      0 |      0 |      3
[35] -34-|2345   |      0 |   1489 |    402 |      0 |   1891
[36] -34-|234-   |      0 |   7215 |   1369 |      3 |   8587
[37] -345|2345   |      0 |   6003 |   1488 |      0 |   7491
[38] -3-5|2345   |      0 |     62 |     40 |      0 |    102
[39] -3-5|-345   |    342 |      0 |      0 |      0 |    342
-----------------+--------+--------+--------+--------+
Summe              121035    29749   331404       20   482208

EF45_* [-5] Entfllt (Keine Wiederholungsbefragung)
        [1] Ja
        [8] Nein
        [9] Keine Angabe

25,1 % (= 121035 / 482208) der Ausflle sind durch eine neue Rotationsgruppe 
bedingt (ef45_b = -5).
*/

* -----------------------------------------------------------------------------;

* 2012 Befragte mit gltigen Angaben (ohne Ausfallstze) und mit Angaben zu 
  2015 ;
proc freq data=p.panel_12131415_v1w ;
    where t1=1 & ( (ef30_a>=1 & ef30_a<=3) | (ef30_d>=1 & ef30_d<=3) ); 
     tables ausftyp ptyp;
	 format ptyp ptyp.;
     format ausftyp ausftyp.;
run; 

/*
                                           Kumulative      Kumulativer
ausftyp         Hufigkeit     Prozent     Hufigkeit      Prozentwert
----------------------------------------------------------------------
[0] 2345|2345       88087       18.18         88087          18.18
[1] 2---|2---      120644       24.91        208731          43.09
[2] 23--|23--      109252       22.55        317983          65.64
[3] 234-|234-       98110       20.25        416093          85.90
[4] 23-5|23-5          37        0.01        416130          85.90
[12] 2---|23--      13219        2.73        429349          88.63
[13] 2---|234-      12384        2.56        441733          91.19
[14] 2---|23-5         30        0.01        441763          91.20
[15] 2---|2-4-          2        0.00        441765          91.20
[16] 23--|234-       9664        1.99        451429          93.19
[17] 23--|23-5         28        0.01        451457          93.20
[23] 2---|2345      12651        2.61        464108          95.81
[24] 23--|2345       9574        1.98        473682          97.78
[25] 234-|2345       9446        1.95        483128          99.73
[26] 23-5|2345        314        0.06        483442          99.80
[27] 2-4-|2345        148        0.03        483590          99.83
[28] 2-4-|234-        431        0.09        484021          99.92
[29] 2-45|2345        340        0.07        484361          99.99
[30] 2--5|2345         51        0.01        484412         100.00

                                           Kumulative      Kumulativer
ptyp            Hufigkeit     Prozent     Hufigkeit      Prozentwert
----------------------------------------------------------------------
[0] 2345            88087       18.18         88087          18.18
[1] 2---           158930       32.81        247017          50.99
[2] 23--           128518       26.53        375535          77.52
[3] 234-           107556       22.20        483091          99.73
[4] 23-5              351        0.07        483442          99.80
[5] 2-4-              579        0.12        484021          99.92
[6] 2-45              340        0.07        484361          99.99
[7] 2--5               51        0.01        484412         100.00
*/

* ============================================================================;

/* Panelzeitpunkte fr Auswahlbezirke (PSU)
   - fr Auswertungen auf der Ebene der Auswahlbezirke 
   analog zu Auswertungen der untereinander stehenden Daten (long format) (3) -
*/

*  Nach Sortierung stehen Ausfallstze nach Stzen befragter Personen;
proc sort data=p.panel_12131415_v1w;
     by idpsu ausfall idpers ptyp;
run;

* psu_1: 1. Satz eines Auswahlbezirks ;
data p.panel_12131415_v1w;
  set p.panel_12131415_v1w;
  psu_1 + 1;
  by idpsu;
  if first.idpsu then psu_1 = 1;
  label psu_1 = "1. Satz eines Auswahlbezirks (PSU)";
run;

/* Ausfallgrund "Wechsel der Rotationsgruppe" nherungsweise ermitteln.
   Nur fr Stze, die in EF4 oder EF5b gltige Werte aufweisen, d. h. bei
   Ausfallstzen werden Stze ausgeschlossen, die in EF4 oder EF5b mit 
   -7 oder -8 codiert sind. */
data p.panel_12131415_v1w;
  set p.panel_12131415_v1w;
  psu12 = (time1=1 & ef5b_a>=0 & ef5b_a<=2 & ef4>=0 & ef4<=999);
  psu13 = (time2=1 & ef5b_b>=0 & ef5b_b<=2 & ef4>=0 & ef4<=999);
  psu14 = (time3=1 & ef5b_c>=0 & ef5b_c<=2 & ef4>=0 & ef4<=999);
  psu15 = (time4=1 & ef5b_d>=0 & ef5b_d<=2 & ef4>=0 & ef4<=999);
  label psu12 = "Satz der Stichprobe 2012 (Panelzeitpunkt)";
  label psu13 = "Satz der Stichprobe 2013 (Panelzeitpunkt)";
  label psu14 = "Satz der Stichprobe 2014 (Panelzeitpunkt)";
  label psu15 = "Satz der Stichprobe 2015 (Panelzeitpunkt)";
run; 

proc sort data=p.panel_12131415_v1w;
     by idpsu ausfall idpers ptyp;
run;

proc summary data = p.panel_12131415_v1w nway noprint; 
 by idpsu; 
 var psu12 psu13 psu14 psu15;
       output out = temp(drop= _type_ _freq_) sum= n_psu12 n_psu13 n_psu14 n_psu15; 
run;

* Angaben zu den Panelzeitpunkten pro Auswahlbezirk (PSU);
data p.panel_12131415_v1w;
    merge p.panel_12131415_v1w temp  ;
    by idpsu;
    label n_psu12 = "Anzahl gltige Stze 2012 im Auswahlbezirk";
    label n_psu13 = "Anzahl gltige Stze 2013 im Auswahlbezirk";
    label n_psu14 = "Anzahl gltige Stze 2014 im Auswahlbezirk";
    label n_psu15 = "Anzahl gltige Stze 2015 im Auswahlbezirk";
run;

proc sort data=p.panel_12131415_v1w;
     by idpsu ausfall idpers ptyp;
run;

/* t*_psu : Panelzeitpunkte eines Auswahlbezirks (1. Satz einer PSU, ohne 
            Ausfallstze, die in EF4 oder EF5b mit -7 oder -8 codiert sind.) */
data p.panel_12131415_v1w;
   set p.panel_12131415_v1w;
   if (psu_1=1) then 
      do;
         if (n_psu12=0)                 then t1_psu=0;
	     if (n_psu12>=1 & n_psu12<=999) then t1_psu=1;
	        label t1_psu = "PSU in 2012  (ohne Ausfallstze, 1. PSU-Satz)";
         if (n_psu13=0)                 then t2_psu=0;
         if (n_psu13>=1 & n_psu13<=999) then t2_psu=1;
	        label t2_psu = "PSU in 2013  (ohne Ausfallstze, 1. PSU-Satz)";
         if (n_psu14=0)                 then t3_psu=0;
         if (n_psu14>=1 & n_psu14<=999) then t3_psu=1;
	        label t3_psu = "PSU in 2014  (ohne Ausfallstze, 1. PSU-Satz)";
         if (n_psu15=0)                 then t4_psu=0;
         if (n_psu15>=1 & n_psu15<=999) then t4_psu=1;
	        label t4_psu = "PSU in 2015  (ohne Ausfallstze, 1. PSU-Satz)";
      end;
run;


/* Replikation der Tabellen in Abschnitt 3. Erste Ausfallanalysen.
   Beispiel: Zusammenfhrung der Daten auf Auswahlbezirksebene (PSU) 2012 und
   2015, ohne Ausfallstze, Erhebungszeitpunkte 2012-2015 */
proc freq data=p.panel_12131415_v1w;
   where psu_1=1 & ef63>0;
      tables t4_psu * t1_psu / norow nopercent;
run;
/*
t4_psu(PSU in 2015  (ohne Ausfallstze, 1. PSU-Satz))
           t1_psu(PSU in 2012  (ohne Ausfallstze, 1. PSU-Satz))

Hufigkeit|
Col Pct   |       0|       1|  Summe
----------+--------+--------+
        0 |   2955 |  25389 |  28344
          |  10.33 |  75.39 |
----------+--------+--------+
        1 |  25645 |   8288 |  33933
          |  89.67 |  24.61 |
----------+--------+--------+
Summe        28600    33677    62277
*/

* ============================================================================;

* 5   Beispielanalysen zur Antwortkonsistenz (Geschlecht und Geburtsjahr);

* Panelzeitpunkte 2012-2015, ohne Ausfallstze;
data tmp (keep = k1 k2);
  set p.panel_12131415_v1w (where = (ptyp=0 & ausfall=0));

    * (1) konsistente Angaben zum Geschlecht;
    k1 = (ptyp=0 & ausfall=0 & ef46_a=ef46_b & ef46_a=ef46_c & ef46_a=ef46_d);
	label k1 = "Konsistente Angaben Geschlecht (0=nein, 1=ja)";

	* (2) konsistente Angaben fr Geburtsjahrgnge 1917 - 2012
    *     (Unterschiedliche Zusammenfassungen fr Geburtsjahrgnge vor 1917);
    if (ptyp=0 & ausfall=0 & 
        ef47_a>=1917 & ef47_a<=2012 & ef47_b>=1917 & ef47_b<=2012 & 
        ef47_c>=1917 & ef47_c<=2012 & ef47_d>=1917 & ef47_d<=2012)  then k2 = 0;
    if (k2 = 0 & (ef47_a=ef47_b & ef47_a=ef47_c & ef47_a=ef47_d) )  then k2 = 1; 
	label k2 = "Konsistente Angaben Geburtsjahr (0=nein, 1=ja)";
run;

proc freq data = tmp ;
  tables k1 k2 ;
run; 

* Der Anteil konsistenter Angaben zum Geschlecht betrgt rund 99 %.

* Der Anteil konsistenter Angaben zum Geburtsjahr betrgt rund 95 %.
*/

* ============================================================================;

* ID fr Haushalte vergeben, Var Label ergnzen;
data p.panel_12131415_v1w (compress=yes);
     set p.panel_12131415_v1w;
     * ID Haushalte ohne Kennung fr Jahresberhnge:
          Bundesland x Nr. des Auswahlbezirks (systemfrei) 
          x Nr. des Haushalts im Auswahlbezirk (systemfrei);
     idhh =    strip(putn(ef1,"Z2.0"))
            || strip(putn(ef3,"Z6.0"))
            || strip(putn(ef4,"Z3.0"));

     label idhh    = "ID Haushalt (ef1 ef3 ef4)";
	 label n_t1    = "Angaben zu 2012 (Person)";
	 label n_t2    = "Angaben zu 2013 (Person)";
	 label n_t3    = "Angaben zu 2014 (Person)";
	 label n_t4    = "Angaben zu 2015 (Person)";
	 label ptyp    = "Panelstze - Personenebene (incl. Ausfallstze) 201*";
     label ef45_a  = "Zuzug (i. d. letzten 12 Monaten)";
	 label ef46_a  = "Geschlecht";
	 label ef47_a  = "Geburtsjahr";
	 label ef451_a = "Selber Wohnsitz (vor einem Jahr) (FB)";
     label ef45_b  = "Zuzug (i. d. letzten 12 Monaten)";
	 label ef46_b  = "Geschlecht";
	 label ef47_b  = "Geburtsjahr";
	 label ef451_b = "Selber Wohnsitz (vor einem Jahr) (FB)";
     label ef45_c  = "Zuzug (i. d. letzten 12 Monaten)";
	 label ef46_c  = "Geschlecht";
	 label ef47_c  = "Geburtsjahr";
	 label ef451_c = "Selber Wohnsitz (vor einem Jahr) (FB)";
     label ef45_d  = "Zuzug (i. d. letzten 12 Monaten)";
	 label ef46_d  = "Geschlecht";
	 label ef47_d  = "Geburtsjahr";
	 label ef451_d = "Selber Wohnsitz (vor einem Jahr) (FB)";
run;

* === Programmende ===;
