* Encoding: windows-1252.
* Diese Datei: panel_12131415_v1.sps (02/2020)
*    https://www.gesis.org/missy/files/documents/MZ/panel_12131415_v1.sps
* Dateiformat: Dos/Windows.
* Zeichensatz: Windows-1252.

* ==============================================================================
* Zusammenfhrung der Daten Mikrozensus Scientific Use File 2012 bis 2015
* zu einem Panel
*  
* Siehe 
* Herter-Eschweiler/Schimpl-Neimanns (2018): Mglichkeiten der Verknpfung von
* Mikrozensus-Querschnittserhebungen ab 2012 zu Panels. Bonn/Mannheim.
* https://www.gesis.org/missy/files/documents/MZ/panelbildung_suf2012.pdf
* 
* 3.  Panelbildung
* 3.1 Version 1 (Lngsschnittorientierung)
*     Fr die Analyse von Brutto-Vernderungen und Verlaufsdatenanalysen 
* 
* ------------------------------------------------------------------------------
* Programmstruktur
* 
* 1   Aufbereitung der Querschnittdaten SUF MZ 2012 ff.
*       Erstellung des Personenidentifkators ohne Kennung des Jahresberhangs
*       Prfung auf doppelte IDs
*       Zuordnung der Jahresberhnge aus Erhebung t zu t-1
* 
* 2   Files untereinander Stellen (long format)
*       Prfung auf doppelte Flle und Datenbereinigung
*       Ausschluss doppelter Stze pro Panelzeitpunkt
*       Kennzeichnung der Ausfallstze
*       Ermittlung der Anzahl der Stze mit Angaben zum Panelzeitpunkt
*       Fortlaufende Satznummer pro Panel-ID erstellen
* 
* 3   Typisierung zum Ausfall erstellen
*       Erste Ausfallanalysen
* 
* 4   Files nebeneinander stellen (wide format)
*       Weitere Ausfallanalysen
*
* 5   Beispielanalysen zur Antwortkonsistenz (Geschlecht und Geburtsjahr)
*
* ---
* Das Programm orientiert sich eng an der Version fr die Zusammenfhrung der 
* Daten 2012 und 2013, siehe 
* https://www.gesis.org/missy/files/documents/MZ/panel_1213_v1.sps.
* Die nderungen betreffen insbesondere die Typisierungen (ptyp* und ausftyp).
* Um Platz zu sparen werden die zeitbezogenen Angaben fr Personen und 
* Auswahlbezirke nicht mehr mit zwei, sondern nur noch mit einer Stelle 
* angegeben (z. B. fr den Panelzeitpunkt 2012, alt: "12"; neu: "2"). 
*
* Programmautor: Bernhard Schimpl-Neimanns
* 
* =============================================================================.

* IBM SPSS Statistics 24.0.0.1 .

* Ggf. Set-Kommandos aktivieren.
* set summary=none basetextdirection=automatic unicode=no tablerender=light 
    OLang=German Locale=German TLook=None printback=On TFit=Both.
* set decimal dot.
* set length none.
* set header off.

* Arbeitsverzeichnis eintragen, z.B: cd "c:\temp" .
cd "<Arbeitsverzeichnis>".

* 1   Aufbereitung der Querschnittdaten SUF MZ 2012 ff.

* 1.1 Aufbereitung SUF MZ 2012 - Variablenauswahl
*       Die Dateinamen entsprechen 
*       https://www.gesis.org/missy/files/documents/MZ/panel_1213_v1.sps .

get file = '<Vollstndiger Dateiname SUF MZ 2012>' /keep = 
 EF1   /* Bundesland 
 EF3   /* Nr. des Auswahlbezirks (systemfrei)
 EF4   /* Nr. des Haushalts im Auswahlbezirk (systemfrei)
 EF5b  /* Jahresberhang aus dem Vorjahr
 EF12  /* Berichtsquartal
 EF63  /* Personennummer  
 EF5a  /* Nr. der Person im Haushalt (systemfrei)
 EF30  /* Bevlkerung: Haupt- oder Nebenwohnsitz
 EF31  /* Bevlkerung: Privathaushalte
 EF45  /* Zuzug (i. d. letzten 12 Monaten)
 EF46  /* Geschlecht
 EF47  /* Geburtsjahr
 EF451 /* Selber Wohnsitz (vor einem Jahr) (FB)
 EF952 /* Standardhochrechnungsfaktor Jahr (in 1000) - neuer Hochrechnungsrahmen
 ID    /* Identifikationsnummer
 .
DATASET ACTIVATE $DataSet.
execute.

* Deklaration fehlender Werte aufheben.
missing values all().

rename variables id = id12.

* Auswahl fr Panel: Ohne Jahresberhnge (ef5b = 1, 2), die gem 
*         Stichprobenplan zu 2011 zhlen.
select if (ef5b=0).
* n = 498.033.

* Vorbereitung der Identifkatoren fr das Zusammenfhren der Querschnitte.
string s1 (A2) s3 (A6) s4 (A3) s63 (A2) .
compute s1  = string(ef1,n2).
compute s3  = string(ef3,n6).
* Fhrende Null umsetzten.
do if (ef4>=0).
   compute s4  = string(ef4,n3).
else if (ef4=-7).
  compute s4 = "0-7".
end if.
do if (ef63>=0).
   compute s63 = string(ef63,n2).
else if (ef63=-7).
  compute s63 = "-7".
else if (ef63=-8).
  compute s63 = "-8".
end if.
execute.

var lab s1  "Bundesland alphanum.".
var lab s3  "Nr. des Auswahlbezirks (systemfrei) alphanum".
var lab s4  "Nr. des Haushalts im Auswahlbezirk (systemfrei) alphanum.".
var lab s63 "Personennummer alphanum.".

* ID Person incl. Kennungen fr Jahresberhnge .
*    Verkettung der Ordnungsnummern zum alphanumerischen Indikator idpersx.
string idpers (A17).
compute idpers = concat(char.rpad(s1,2),char.rpad(s3,6),char.rpad(s4,3),
                        char.rpad(s63,2)).
var lab idpers "ID Person (ef1 ef3 ef4 ef63)".
exe.

* Doppelte IDs? .
sort cases by idpers.
aggregate outfile = * mode = addvariables /break idpers /n_idpers = nu(idpers).

fre n_idpers.
* ok.
delete variables n_idpers.

compute file = 1.
formats file (f2).
var lab file "Datenquelle".
val lab file 1 "2012" 2 "2012 <- 2013 ef5b=1,2" 3 "2013 ef5b=0,-7".

sort cases by file idpers.

* Dateiname ggf. ndern.
save outfile = 'suf12_1.sav'  /compressed.
* n = 498.033.

* ============================================================================.

* 1.2 Aufbereitung SUF MZ 2013, Variablenauswahl.
*       Die Dateinamen entsprechen
*       https://www.gesis.org/missy/files/documents/MZ/setups/spss/setup13.sps.

get file = '<Vollstndiger Dateiname SUF MZ 2013>' /keep =   
 EF1   /* Bundesland 
 EF3   /* Nr. des Auswahlbezirks (systemfrei)
 EF4   /* Nr. des Haushalts im Auswahlbezirk (systemfrei)
 EF5b  /* Jahresberhang aus dem Vorjahr
 EF12  /* Berichtsquartal
 EF63  /* Personennummer  
 EF5a  /* Nr. der Person im Haushalt (systemfrei)
 EF30  /* Bevlkerung: Haupt- oder Nebenwohnsitz
 EF31  /* Bevlkerung: Privathaushalte
 EF45  /* Zuzug (i. d. letzten 12 Monaten)
 EF46  /* Geschlecht
 EF47  /* Geburtsjahr
 EF451 /* Selber Wohnsitz (vor einem Jahr) (FB)
 EF952 /* Standardhochrechnungsfaktor Jahr (in 1000) - neuer Hochrechnungsrahmen
 ID    /* Identifikationsnummer */
 .
Dataset Name $DataSet WINDOW=FRONT.
execute.

* Deklaration fehlender Werte aufheben.
missing values all().

rename variables id = id13.

* Vorbereitung der Identifkatoren fr das Zusammenfhren der Querschnitte.
string s1 (A2) s3 (A6) s4 (A3) s63 (A2) .
compute s1  = string(ef1,n2).
compute s3  = string(ef3,n6).
* Fhrende Null umsetzten.
do if (ef4>=0).
   compute s4  = string(ef4,n3).
else if (ef4=-7).
  compute s4 = "0-7".
end if.
do if (ef63>=0).
   compute s63 = string(ef63,n2).
else if (ef63=-7).
  compute s63 = "-7".
else if (ef63=-8).
  compute s63 = "-8".
end if.
execute.

* ID Person ohne Kennungen fr Jahresberhnge .
*    Verkettung der Ordnungsnummern zum alphanumerischen Indikator idpers.
string idpers (A17).
compute idpers = concat(char.rpad(s1,2),char.rpad(s3,6),char.rpad(s4,3), 
                        char.rpad(s63,2)).
var lab idpers "ID Person (ef1 ef3 ef4 ef5b ef12 ef63)".
exe.

* Zuordnung Jahresberhnge => 2012, sonst => 2013.
recode ef5b (1, 2=2) (else=3) into file.
formats file (f2).
var lab file "Datenquelle".
val lab file 1 "2012" 2 "2012 <- 2013 ef5b=1,2" 3 "2013 ef5b=0,-7".


* Doppelte Flle ? .
sort cases by idpers.
aggregate outfile = * mode = addvariables
         /break idpers file /n_idpers = nu(idpers).
fre n_idpers.

temporary.
* Doppelte Flle.
select if n_idpers=2.
list variables idpers file ef1 ef3 ef4 ef5b ef12 ef63 id13.

* Datenbereinigung - betrifft nur Ausfallstze mit doppelter Panelzeit (file).
if (id13=55626)  file = -1.
if (id13=126328) file = -1.
if (id13=384549) file = -1.
if (id13=385396) file = -1.
if (id13=390124) file = -1.
add val lab file -1 'doppelte Stze: 2013, ef5b=-7'.
execute.
delete variables n_idpers.

sort cases by idpers.
aggregate outfile = * mode = addvariables 
         /break idpers file /n_idpers =  nu(idpers).
fre n_idpers.
* ok.
delete variables n_idpers.

sort cases by idpers.
aggregate outfile = * mode = addvariables 
         /break idpers /n_idpers =  nu(idpers).
fre n_idpers.
* ok.
delete variables n_idpers.
execute.

sort cases by file idpers.

* Dateiname ggf. ndern.
save outfile='suf13_1.sav'  /compressed.
* n = 525.787 .

* =============================================================================.

* 1.3 Aufbereitung SUF MZ 2014, Variablenauswahl.
*       Die Dateinamen entsprechen
*       https://www.gesis.org/missy/files/documents/MZ/setups/spss/setup14.sps.

get file = '<Vollstndiger Dateiname SUF MZ 2014>' /keep = 
 EF1   /* Bundesland 
 EF3   /* Nr. des Auswahlbezirks (systemfrei)
 EF4   /* Nr. des Haushalts im Auswahlbezirk (systemfrei)
 EF5b  /* Jahresberhang aus dem Vorjahr
 EF12  /* Berichtsquartal
 EF63  /* Personennummer  
 EF5a  /* Nr. der Person im Haushalt (systemfrei)
 EF30  /* Bevlkerung: Haupt- oder Nebenwohnsitz
 EF31  /* Bevlkerung: Privathaushalte
 EF45  /* Zuzug (i. d. letzten 12 Monaten)
 EF46  /* Geschlecht
 EF47  /* Geburtsjahr
 EF451 /* Selber Wohnsitz (vor einem Jahr) (FB)
 EF952 /* Standardhochrechnungsfaktor Jahr (in 1000) - neuer Hochrechnungsrahmen
 ID    /* Identifikationsnummer 
 .
Dataset Name $DataSet WINDOW=FRONT.
execute.

* Deklaration fehlender Werte aufheben.
missing values all().

rename variables id = id14.

* Vorbereitung der Identifkatoren fr das Zusammenfhren der Querschnitte.
string s1 (A2) s3 (A6) s4 (A3) s63 (A2) .
compute s1  = string(ef1,n2).
compute s3  = string(ef3,n6).
* Fhrende Null umsetzten.
do if (ef4>=0).
   compute s4  = string(ef4,n3).
else if (ef4=-7).
  compute s4 = "0-7".
end if.
do if (ef63>=0).
   compute s63 = string(ef63,n2).
else if (ef63=-7).
  compute s63 = "-7".
else if (ef63=-8).
  compute s63 = "-8".
end if.
execute.

* ID Person ohne Kennungen fr Jahresberhnge .
*    Verkettung der Ordnungsnummern zum alphanumerischen Indikator idpers.
string idpers (A17).
compute idpers = concat(char.rpad(s1,2),char.rpad(s3,6),char.rpad(s4,3), 
                        char.rpad(s63,2)).
var lab idpers "ID Person (ef1 ef3 ef4 ef5b ef12 ef63)".
exe.

* Zuordnung Jahresberhnge => 2013, sonst => 2014.
recode ef5b (1, 2=4) (else=5) into file.
formats file (f2).
var lab file "Datenquelle".

val lab file 1 "2012" 2 "2012 <- 2013 ef5b=1,2" 3 "2013 ef5b=0,-7"
             4 "2013 <- 2014 (2014: ef5b=1,2)"  5 "2014 (2014: ef5b<=0)".

* Doppelte Flle ? .
sort cases by idpers.
aggregate outfile = * mode = addvariables
         /break idpers file /n_idpers = nu(idpers).
fre n_idpers.

* Datenbereinigung - betrifft nur Ausfallstze mit doppelter Panelzeit (file)
* Satz mit niedrigerem Quartal als doppelt kennzeichnen.
aggregate outfile = * mode = addvariables
         /break idpers file /min_idpers = min(ef12).

if ( (ef12=min_idpers) & n_idpers=2) file = -2.
execute.

delete variables n_idpers.
execute.

aggregate outfile = * mode = addvariables
         /break idpers file /n_idpers = nu(idpers).
fre n_idpers.

temporary.
* Doppelte Flle.
select if n_idpers=2.
formats file (F2.0).
list variables idpers file id14 ef12 ef5b ef30 ef4 ef63.

* Datenbreinigung .
if (id14=351460 | id14=354667) file = 5.

add val lab file -2 'doppelte Stze: 2014, ef5b=-8'.
execute.

delete variables n_idpers.
execute.

sort cases by idpers.
aggregate outfile = * mode = addvariables 
         /break idpers file /n_idpers =  nu(idpers).
fre n_idpers.
* crosstabs n_idpers by file.

* ok.
delete variables n_idpers min_idpers.
execute.

sort cases by file idpers.

* Dateiname ggf. ndern.
save outfile='suf14_1.sav'  /compressed.
* n = 526.201 .

* =============================================================================.

* 1.4 Aufbereitung SUF MZ 2015, Variablenauswahl
*     Die Dateinamen entsprechen 
*        https://www.gesis.org/missy/files/documents/MZ/setups/spss/setup15.sps.

get file = '<Vollstndiger Dateiname SUF MZ 2015>' /keep = 
 EF1   /* Bundesland 
 EF3   /* Nr. des Auswahlbezirks (systemfrei)
 EF4   /* Nr. des Haushalts im Auswahlbezirk (systemfrei)
 EF5b  /* Jahresberhang aus dem Vorjahr
 EF12  /* Berichtsquartal
 EF63  /* Personennummer  
 EF5a  /* Nr. der Person im Haushalt (systemfrei)
 EF30  /* Bevlkerung: Haupt- oder Nebenwohnsitz
 EF31  /* Bevlkerung: Privathaushalte
 EF45  /* Zuzug (i. d. letzten 12 Monaten)
 EF46  /* Geschlecht
 EF47  /* Geburtsjahr
 EF451 /* Selber Wohnsitz (vor einem Jahr) (FB)
 EF952 /* Standardhochrechnungsfaktor Jahr (in 1000) - neuer Hochrechnungsrahmen
 ID    /* Identifikationsnummer 
 .
* ohne: idpers Lngsschnittorientierter Personenidentifikator; s.u..
Dataset Name $DataSet WINDOW=FRONT.
execute.

* Deklaration fehlender Werte aufheben.
missing values all().

rename variables id = id15.

* Vorbereitung der Identifkatoren fr das Zusammenfhren der Querschnitte.
string s1 (A2) s3 (A6) s4 (A3) s63 (A2) .
compute s1  = string(ef1,n2).
compute s3  = string(ef3,n6).
* Fhrende Null umsetzten.
do if (ef4>=0).
   compute s4  = string(ef4,n3).
else if (ef4=-7).
  compute s4 = "0-7".
end if.
do if (ef63>=0).
   compute s63 = string(ef63,n2).
else if (ef63=-7).
  compute s63 = "-7".
else if (ef63=-8).
  compute s63 = "-8".
end if.
execute.

* ID Person ohne Kennungen fr Jahresberhnge .
*    Verkettung der Ordnungsnummern zum alphanumerischen Indikator idpers.
string idpers (A17).
compute idpers = concat(char.rpad(s1,2),char.rpad(s3,6),char.rpad(s4,3), 
                        char.rpad(s63,2)).
var lab idpers "ID Person (ef1 ef3 ef4 ef5b ef12 ef63)".
exe.

* Zuordnung Jahresberhnge => 2014, sonst => 2015.
recode ef5b (1, 2=6) (else=7) into file.
formats file (f2).
var lab file "Datenquelle".

val lab file 1 "2012 (ef5b=0)"        2 "2012 <- 2013 (2013: ef5b=1,2)" 
             3 "2013 (2013: ef5b<=0"  4 "2013 <- 2014 (2014: ef5b=1,2)"
             5 "2014 (2014: ef5b<=0)" 6 "2014 <- 2015 (2015: ef5b=1,2)" 
             7 "2015 (2015: ef5b<=0)".

* Doppelte Flle ? .
sort cases by idpers.
aggregate outfile = * mode = addvariables
         /break idpers file /n_idpers = nu(idpers).
* fre n_idpers.
crosstabs n_idpers by file.
* OK.

delete variables n_idpers.
execute.

sort cases by file idpers.

save outfile='suf15_1.sav'  /compressed.
* n = 531.738.


* =============================================================================.

* 2 Files untereinander stellen (long format).

NEW FILE. 
DATASET NAME $DataSet WINDOW=FRONT.
ADD FILES file = 'suf12_1.sav' /in=ej1
         /file = 'suf13_1.sav' /in=ej2
         /file = 'suf14_1.sav' /in=ej3
         /file = 'suf15_1.sav' /in=ej4.
execute.
* n = 2.081.759 .

add val lab file 1 '2012 (ef5b=0)'
                 2 '2012 <- 2013 (2013: ef5b=1,2)'
                 3 '2013 (2013: ef5b<=0'
                 4 '2013 <- 2014 (2014: ef5b=1,2)'
                 5 '2014 (2014: ef5b<=0)'
                 6 '2014 <- 2015 (2015: ef5b=1,2)'
                 7 '2015 (2015: ef5b<=0)'
                -1 'doppelte Stze: 2013, ef5b=-7'
                -2 'doppelte Stze: 2014, ef5b=-8'.
formats file (f2).
fre file.

* recode file (1=1) (-1, 2, 3=2) (-2, 4, 5=3) (6, 7=4) into ejahr.
if (ej1=1) ejahr=1.
if (ej2=1) ejahr=2.
if (ej3=1) ejahr=3.
if (ej4=1) ejahr=4.
var lab ejahr 'Erhebungsjahr'.
val lab ejahr 1 '2012'  2 '2013' 3 '2014' 4 '2015'.
formats ejahr (F1.0).
execute.
delete variables ej1 ej2 ej3 ej4.


* crosstabs file by ejahr.

* === Datenbereinigungen === .
* Datenbereinigung - betrifft nur Ausfallstze mit doppelter Panelzeit (file) 

* ----------------------------------------------------------------------------.

* Prfung auf doppelte Flle und Datenbereinigung. 
* Datenbereinigung betrifft nur Stze mit doppelter Panelzeit (file).
* Die einzelnen Schritte der Dateninspektion werden aus Platzgrnden nicht 
* dargestellt.

* - MZ 2013 .
if (id13=74945)   file = -3.
if (id13=128105)  file = -3.
if (id13=225706)  file = -3. 
* - MZ 2015.
if (id15=175755)  file = -4.
if (id15=175756)  file = -4. 

add val lab file -3 'doppelte Stze: 2013 2012, 2013: ef5b=1'
                 -4 'doppelte Stze: 2015 2014, 2015: ef5b=1'.

* -----------------------------------------------------------------------------
* Bei Dateninspektionen ist aufgefallen, dass im Unterschied zum MZ 2014 im 
* MZ 2015 in Variable EF5b die Jahresberhnge bzw. Ausfallstze nicht mit 
* -8 oder -7 recodiert sind. 
* Die Angaben im MZ 2015 sind deshalb in Bezug auf Haushalte des Jahresberhangs
* informativer. 
* Dies spricht dafr, bei doppelten Fllen die Angaben zum Jahresberhang 
* (ef5b=1,2) aus dem MZ 2015 (ejahr=4) als Angaben zum Panelzeitpunkt 2014 zu 
* verwenden und die Angaben der Ausfallstze (EF5b<0) aus dem MZ 2014 (ejahr=3) 
* als 2013 zu befragende Jahresberhnge zu codieren.

temporary.
compute dopp = (file>=5 & file<=6).
aggregate outfile = * mode = addvariables
         /break idpers
         /n_t3 = sum(dopp).
* Alternativ: /n_t3 = CIN(file,5,6) XXX.
crosstabs file ef5b by n_t3.
* n=1.238 doppelte Nennungen (n_t3=2) bei Ausfallstzen (ef5b < 0).

do if (ejahr=3 & file>=5 & file<=6 & n_t3=2 & ef5b<0).
+ compute file = 4.
end if.

* Ausnahmen.
do if (ejahr=3 & file=4 & (id14=539591 | id14=539592)).
+ compute file = -4.
end if.
execute.

delete variables n_t3.
execute.

fre file.
* file                                       Hufigkeit
* -----------------------------------------------------
* -4 doppelte Stze: 2015 2014, 2015: ef5b=1          4
* -3 doppelte Stze: 2013 2012, 2013: ef5b=1          3
* -2 doppelte Stze: 2014, ef5b=-8                  672
* -1 doppelte Stze: 2013, ef5b=-7                    5
*  1 2012 (ef5b=0)                               498033
*  2 2012 <- 2013 (2013: ef5b=1,2)                16534
*  3 2013 (2013: ef5b<=0                         509245
*  4 2013 <- 2014 (2014: ef5b=1,2)                18654
*  5 2014 (2014: ef5b<=0)                        506873
*  6 2014 <- 2015 (2015: ef5b=1,2)                20733
*  7 2015 (2015: ef5b<=0)                        511003
* -----------------------------------------------------
*  Gesamt                                       2081759 .

* -----------------------------------------------------------------------------.

* doppelte Stze rekodieren bzw. ausschlieen.
select if (file>=1 & file<=7).
execute.
* n = 2.081.075 .

* Kennzeichnung der Ausfallstze.
compute ausfall = (ef63<0 | ef5b<0 | ef31<0).
var lab ausfall "Ausfallsatz (ef63<0 | ef5b<0 | ef31<0)".
val lab ausfall 0 'nein' 1 'ja'.
formats ausfall (f1.0).

* crosstabs file by ausfall.

* Fr jede Panel-ID (idpers) Anzahl der Stze mit Angaben zu den Paneljahren ermitteln.
* Sortierfolge "idpers ausfall file": Befragtenstze stehen vor Ausfallstzen.
sort cases by idpers ausfall file.

* neu erstellen: Satznummer pro idpers .
sort cases by idpers ausfall file.
if idpers ne lag(idpers,1) p1 = 0.
compute p1 = p1 + 1.
leave p1.
var lab p1 "Satznummer zu idpers".
formats p1 (f2).
execute.
* crosstabs file by p1.

recode file (1, 2 = 1) (else=0) into t1.
recode file (3, 4 = 1) (else=0) into t2.
recode file (5, 6 = 1) (else=0) into t3.
recode file (7    = 1) (else=0) into t4.
var lab t1 "Angaben zu 2012".
var lab t2 "Angaben zu 2013".
var lab t3 "Angaben zu 2014".
var lab t4 "Angaben zu 2015".

val lab t1 0 "nein" 1 "ja".
val lab t2 0 "nein" 1 "ja".
val lab t3 0 "nein" 1 "ja".
val lab t4 0 "nein" 1 "ja".

aggregate outfile= * mode=addvariables
  /break  = idpers
  /n_t1 = sum(t1)
  /n_t2 = sum(t2)
  /n_t3 = sum(t3) 
  /n_t4 = sum(t4) .

var lab n_t1 "Angaben zu 2012 (Person)".
var lab n_t2 "Angaben zu 2013 (Person)".
var lab n_t3 "Angaben zu 2014 (Person)".
var lab n_t4 "Angaben zu 2015 (Person)".
formats t1 t2 t3 t4 n_t1 n_t2 n_t3 n_t4 (f1).


* Angaben zu den Panelzeitpunkten pro Panel-ID .
if (n_t1=1 & n_t2=1 & n_t3=1 & n_t4=1) ptyp =  0.
if (n_t1=1 & n_t2=0 & n_t3=0 & n_t4=0) ptyp =  1.
if (n_t1=1 & n_t2=1 & n_t3=0 & n_t4=0) ptyp =  2.
if (n_t1=1 & n_t2=1 & n_t3=1 & n_t4=0) ptyp =  3.
if (n_t1=1 & n_t2=1 & n_t3=0 & n_t4=1) ptyp =  4.
if (n_t1=1 & n_t2=0 & n_t3=1 & n_t4=0) ptyp =  5.
if (n_t1=1 & n_t2=0 & n_t3=1 & n_t4=1) ptyp =  6.
if (n_t1=1 & n_t2=0 & n_t3=0 & n_t4=1) ptyp =  7.
if (n_t1=0 & n_t2=1 & n_t3=0 & n_t4=0) ptyp =  8.
if (n_t1=0 & n_t2=1 & n_t3=1 & n_t4=0) ptyp =  9.
if (n_t1=0 & n_t2=1 & n_t3=1 & n_t4=1) ptyp = 10.
if (n_t1=0 & n_t2=1 & n_t3=0 & n_t4=1) ptyp = 11.
if (n_t1=0 & n_t2=0 & n_t3=1 & n_t4=0) ptyp = 12.
if (n_t1=0 & n_t2=0 & n_t3=1 & n_t4=1) ptyp = 13.
if (n_t1=0 & n_t2=0 & n_t3=0 & n_t4=1) ptyp = 14.
formats ptyp (f1.0).
var lab ptyp "Panelstze - Personenebene (incl. Ausfallstze) 201*".
val lab ptyp 0 "2345"  1 "2---"  2 "23--"  3 "234-"  4 "23-5"  5 "2-4-"
             6 "2-45"  7 "2--5"  8 "-3--"  9 "-34-" 10 "-345" 11 "-3-5"
            12 "--4-" 13 "--45" 14 "---5".
fre ptyp.
*          Hufigkeit  Prozent  Kumulierte Prozente
* -------------------------------------------------
*  0 2345      363336     17,5      17,5
*  1 2---      174783      8,4      25,9
*  2 23--      270422     13,0      38,9
*  3 234-      334800     16,1      54,9
*  4 23-5        1662       ,1      55,0
*  5 2-4-        2244       ,1      55,1
*  6 2-45        1182       ,1      55,2
*  7 2--5         138       ,0      55,2
*  8 -3--       87416      4,2      59,4
*  9 -34-       46260      2,2      61,6
* 10 -345      235461     11,3      72,9
* 11 -3-5        1334       ,1      73,0
* 12 --4-       64831      3,1      76,1
* 13 --45      314416     15,1      91,2
* 14 ---5      182790      8,8     100,0
* -------------------------------------------------
* Gesamt      2081075    100,0                     .


* =============================================================================.

* 3 Typisierung zum Ausfall erstellen .

* === PSU-Ebene === .
string idpsu (A8).
compute idpsu = concat(char.rpad(s1,2),char.rpad(s3,6)).
var lab idpsu "ID Auswahlbezirk (ef1 o ef3)".
exe.

* 1. Satz eines Auswahlbezirks.
*    Nach Sortierung stehen Ausfallstze nach Stzen befragter Personen.
sort cases by idpsu ausfall idpers ptyp.
if idpsu ne lag(idpsu,1) psu_1 = 0.
compute psu_1 = psu_1 + 1.
leave psu_1.
var lab psu_1 "1. Satz eines Auswahlbezirks (PSU)".
formats psu_1 (f3).
execute.

* Ausfallgrund "Wechsel der Rotationsgruppe" nherungsweise ermitteln.
* Nur fr Stze, die in EF4 oder EF5b gltige Werte aufweisen, d. h. bei
*   Ausfallstzen werden Stze ausgeschlossen, die in EF4 oder EF5b mit 
*   -7 oder -8 codiert sind.

* Satz der Stichprobe 2012 (Panelzeitpunkt).
compute psu12 = (t1=1 & ef5b>=0 & ef5b<=2 & ef4>=0 & ef4<=999).
* Satz der Stichprobe 2013 (Panelzeitpunkt).
compute psu13 = (t2=1 & ef5b>=0 & ef5b<=2 & ef4>=0 & ef4<=999).
* Satz der Stichprobe 2014 (Panelzeitpunkt).
compute psu14 = (t3=1 & ef5b>=0 & ef5b<=2 & ef4>=0 & ef4<=999).
* Satz der Stichprobe 2015 (Panelzeitpunkt).
compute psu15 = (t4=1 & ef5b>=0 & ef5b<=2 & ef4>=0 & ef4<=999).

aggregate outfile= * mode=addvariables overwrite=yes
 /break   = idpsu
 /n_psu12 = sum(psu12)
 /n_psu13 = sum(psu13)
 /n_psu14 = sum(psu14)
 /n_psu15 = sum(psu15).
execute.

var lab n_psu12 "Anzahl gltige Stze 2012 im Auswahlbezirk".
var lab n_psu13 "Anzahl gltige Stze 2013 im Auswahlbezirk".
var lab n_psu14 "Anzahl gltige Stze 2014 im Auswahlbezirk".
var lab n_psu15 "Anzahl gltige Stze 2015 im Auswahlbezirk".
formats n_psu12 n_psu13 n_psu14 n_psu15 (f3.0).

sort cases by idpsu ausfall idpers ptyp.

if (n_psu12>=1  & n_psu13>=1 & n_psu14>=1 & n_psu15>=1) ptyp_psu =  0.
if (n_psu12>=1  & n_psu13=0  & n_psu14=0  & n_psu15=0 ) ptyp_psu =  1.
if (n_psu12>=1  & n_psu13>=1 & n_psu14=0  & n_psu15=0 ) ptyp_psu =  2.
if (n_psu12>=1  & n_psu13>=1 & n_psu14>=1 & n_psu15=0 ) ptyp_psu =  3.
if (n_psu12>=1  & n_psu13>=1 & n_psu14=0  & n_psu15>=1) ptyp_psu =  4.
if (n_psu12>=1  & n_psu13=0  & n_psu14>=1 & n_psu15=0 ) ptyp_psu =  5.
if (n_psu12>=1  & n_psu13=0  & n_psu14>=1 & n_psu15>=1) ptyp_psu =  6.
if (n_psu12>=1  & n_psu13=0  & n_psu14=0  & n_psu15>=1) ptyp_psu =  7.
if (n_psu12=0   & n_psu13>=1 & n_psu14=0  & n_psu15=0 ) ptyp_psu =  8.
if (n_psu12=0   & n_psu13>=1 & n_psu14>=1 & n_psu15=0 ) ptyp_psu =  9.
if (n_psu12=0   & n_psu13>=1 & n_psu14>=1 & n_psu15>=1) ptyp_psu = 10.
if (n_psu12=0   & n_psu13>=1 & n_psu14=0  & n_psu15>=1) ptyp_psu = 11.
if (n_psu12=0   & n_psu13=0  & n_psu14>=1 & n_psu15=0 ) ptyp_psu = 12.
if (n_psu12=0   & n_psu13=0  & n_psu14>=1 & n_psu15>=1) ptyp_psu = 13.
if (n_psu12=0   & n_psu13=0  & n_psu14=0  & n_psu15>=1) ptyp_psu = 14.
if (sysmis(ptyp_psu) & ausfall=1)                       ptyp_psu = -1.
formats ptyp_psu (f2.0).
var lab ptyp_psu "Panelstze - PSU-Ebene (ohne Ausfallstze: ef63<0   ef5b<0   ef31<0)".
val lab ptyp_psu 0 "2345"  1 "2---"  2 "23--"  3 "234-"  4 "23-5"  5 "2-4-"
                 6 "2-45"  7 "2--5"  8 "-3--"  9 "-34-" 10 "-345" 11 "-3-5"
                12 "--4-" 13 "--45" 14 "---5" -1 "Ausfallsatz".
fre ptyp_psu.
*           Hufigkeit
* --------------------
* -1 Ausfallsatz 12998
*  0 2345       514534
*  1 2---       128531
*  2 23--       265190
*  3 234-       387740
*  4 23-5          427
*  5 2-4-           21
*  8 -3--        38267
*  9 -34-         2677
* 10 -345       285486
* 11 -3-5          178
* 12 --4-         1674
* 13 --45       319413
* 14 ---5       123939
* --------------------
* Gesamt       2081075 .


* t*_psu : Panelzeitpunkte eines Auswahlbezirks (1. Satz einer PSU, ohne 
*          Ausfallstze, die in EF4 oder EF5b mit -7 oder -8 codiert sind.).
do if (psu_1=1). 
+ recode n_psu12 (0=0) (1 thru 999=1) into t1_psu.
+ recode n_psu13 (0=0) (1 thru 999=1) into t2_psu.
+ recode n_psu14 (0=0) (1 thru 999=1) into t3_psu.
+ recode n_psu15 (0=0) (1 thru 999=1) into t4_psu.
end if.
var lab t1_psu 'PSU in 2012 (ohne Ausfallstze, 1. PSU-Satz)'.
var lab t2_psu 'PSU in 2013 (ohne Ausfallstze, 1. PSU-Satz)'.
var lab t3_psu 'PSU in 2014 (ohne Ausfallstze, 1. PSU-Satz)'.
var lab t4_psu 'PSU in 2015 (ohne Ausfallstze, 1. PSU-Satz)'.
formats t1_psu t2_psu t3_psu t4_psu (F1.0).

* Ausfalltypisierung: Angaben fr Personen   Angaben fr Auswahlbezirke.
* ptyp = ptyp_psu.
if (ptyp= 0 & ptyp_psu= 0) ausftyp =  0.
if (ptyp= 1 & ptyp_psu= 1) ausftyp =  1.
if (ptyp= 2 & ptyp_psu= 2) ausftyp =  2.
if (ptyp= 3 & ptyp_psu= 3) ausftyp =  3.
if (ptyp= 4 & ptyp_psu= 4) ausftyp =  4.
if (ptyp= 8 & ptyp_psu= 8) ausftyp =  5.
if (ptyp= 9 & ptyp_psu= 9) ausftyp =  6.
if (ptyp=10 & ptyp_psu=10) ausftyp =  7.
if (ptyp=11 & ptyp_psu=11) ausftyp =  8.
if (ptyp=12 & ptyp_psu=12) ausftyp =  9.
if (ptyp=13 & ptyp_psu=13) ausftyp = 10.
if (ptyp=14 & ptyp_psu=14) ausftyp = 11.
* ptyp < ptyp_psu.
if (ptyp= 1 & ptyp_psu= 2) ausftyp = 12.
if (ptyp= 1 & ptyp_psu= 3) ausftyp = 13.
if (ptyp= 1 & ptyp_psu= 4) ausftyp = 14.
if (ptyp= 1 & ptyp_psu= 5) ausftyp = 15.
if (ptyp= 2 & ptyp_psu= 3) ausftyp = 16.
if (ptyp= 2 & ptyp_psu= 4) ausftyp = 17.
if (ptyp= 8 & ptyp_psu= 9) ausftyp = 18.
if (ptyp= 8 & ptyp_psu=10) ausftyp = 19.
if (ptyp= 8 & ptyp_psu=11) ausftyp = 20.
if (ptyp= 9 & ptyp_psu=10) ausftyp = 21.
if (ptyp=12 & ptyp_psu=13) ausftyp = 22.
* ptyp > ptyp_psu.
if (ptyp= 1 & ptyp_psu= 0) ausftyp = 23.
if (ptyp= 2 & ptyp_psu= 0) ausftyp = 24.
if (ptyp= 3 & ptyp_psu= 0) ausftyp = 25.
if (ptyp= 4 & ptyp_psu= 0) ausftyp = 26.
if (ptyp= 5 & ptyp_psu= 0) ausftyp = 27.
if (ptyp= 5 & ptyp_psu= 3) ausftyp = 28.
if (ptyp= 6 & ptyp_psu= 0) ausftyp = 29.
if (ptyp= 7 & ptyp_psu= 0) ausftyp = 30.
if (ptyp= 8 & ptyp_psu= 0) ausftyp = 31.
if (ptyp= 8 & ptyp_psu= 2) ausftyp = 32.
if (ptyp= 8 & ptyp_psu= 3) ausftyp = 33.
if (ptyp= 8 & ptyp_psu= 4) ausftyp = 34.
if (ptyp= 9 & ptyp_psu= 0) ausftyp = 35.
if (ptyp= 9 & ptyp_psu= 3) ausftyp = 36.
if (ptyp=10 & ptyp_psu= 0) ausftyp = 37.
if (ptyp=11 & ptyp_psu= 0) ausftyp = 38.
if (ptyp=11 & ptyp_psu=10) ausftyp = 39.
if (ptyp=12 & ptyp_psu= 0) ausftyp = 40.
if (ptyp=12 & ptyp_psu= 3) ausftyp = 41.
if (ptyp=12 & ptyp_psu= 5) ausftyp = 42.
if (ptyp=12 & ptyp_psu= 9) ausftyp = 43.
if (ptyp=12 & ptyp_psu=10) ausftyp = 44.
if (ptyp=13 & ptyp_psu= 0) ausftyp = 45.
if (ptyp=13 & ptyp_psu=10) ausftyp = 46.
if (ptyp=14 & ptyp_psu= 0) ausftyp = 47.
if (ptyp=14 & ptyp_psu= 4) ausftyp = 48.
if (ptyp=14 & ptyp_psu=10) ausftyp = 49.
if (ptyp=14 & ptyp_psu=11) ausftyp = 50.
if (ptyp=14 & ptyp_psu=13) ausftyp = 51.
if (ausfall=1)             ausftyp = -1.

var lab ausftyp "Ausfalltyp: Ausfall Satz   Angaben Auswahlbezirk (Proxy) 201*".
val lab ausftyp  0 "2345|2345"   1 "2---|2---"   2 "23--|23--"   3 "234-|234-"
                 4 "23-5|23-5"   5 "-3--|-3--"   6 "-34-|-34-"   7 "-345|-345"
                 8 "-3-5|-3-5"   9 "--4-|--4-"  10 "--45|--45"  11 "---5|---5"
                12 "2---|23--"  13 "2---|234-"  14 "2---|23-5"  15 "2---|2-4-"
                16 "23--|234-"  17 "23--|23-5"  18 "-3--|-34-"  19 "-3--|-345"
                20 "-3--|-3-5"  21 "-34-|-345"  22 "--4-|--45"  23 "2---|2345"
                24 "23--|2345"  25 "234-|2345"  26 "23-5|2345"  27 "2-4-|2345"
                28 "2-4-|234-"  29 "2-45|2345"  30 "2--5|2345"  31 "-3--|2345"
                32 "-3--|23--"  33 "-3--|234-"  34 "-3--|23-5"  35 "-34-|2345"
                36 "-34-|234-"  37 "-345|2345"  38 "-3-5|2345"  39 "-3-5|-345"
                40 "--4-|2345"  41 "--4-|234-"  42 "--4-|2-4-"  43 "--4-|-34-"
                44 "--4-|-345"  45 "--45|2345"  46 "--45|-345"  47 "---5|2345"
                48 "---5|23-5"  49 "---5|-345"  50 "---5|-3-5"  51 "---5|--45"
                -1 "Ausfallstze ef4<0   ef5b<0   ef63<0".
formats ausftyp (f2.0).

fre ausftyp.
*                Hufigkeit    Prozent  Kumulierte Prozente
* ---------------------------------------------------------
* -1 Ausfallstze    173605      8,3    8,3
*  0 2345 2345       352348     16,9    25,3
*  1 2--- 2---       120644      5,8    31,1
*  2 23-- 23--       218504     10,5    41,6
*  3 234- 234-       294330     14,1    55,7
*  4 23-5 23-5          111       ,0    55,7
*  5 -3-- -3--        35843      1,7    57,4
*  6 -34- -34-         1886       ,1    57,5
*  7 -345 -345       203895      9,8    67,3
*  8 -3-5 -3-5           54       ,0    67,3
*  9 --4- --4-         1290       ,1    67,4
* 10 --45 --45       262228     12,6    80,0
* 11 ---5 ---5       117580      5,6    85,6
* 12 2--- 23--        13219       ,6    86,3
* 13 2--- 234-        12384       ,6    86,9
* 14 2--- 23-5           30       ,0    86,9
* 15 2--- 2-4-            2       ,0    86,9
* 16 23-- 234-        19328       ,9    87,8
* 17 23-- 23-5           56       ,0    87,8
* 18 -3-- -34-          190       ,0    87,8
* 19 -3-- -345         9226       ,4    88,3
* 20 -3-- -3-5           18       ,0    88,3
* 21 -34- -345        17482       ,8    89,1
* 22 --4- --45        18318       ,9    90,0
* 23 2--- 2345        12651       ,6    90,6
* 24 23-- 2345        19148       ,9    91,5
* 25 234- 2345        28338      1,4    92,9
* 26 23-5 2345          942       ,0    92,9
* 27 2-4- 2345          296       ,0    92,9
* 28 2-4- 234-          862       ,0    93,0
* 29 2-45 2345         1020       ,0    93,0
* 30 2--5 2345          102       ,0    93,0
* 31 -3-- 2345         2710       ,1    93,2
* 32 -3-- 23--        11076       ,5    93,7
* 33 -3-- 234-         2541       ,1    93,8
* 34 -3-- 23-5            3       ,0    93,8
* 35 -34- 2345         3782       ,2    94,0
* 36 -34- 234-        17174       ,8    94,8
* 37 -345 2345        22473      1,1    95,9
* 38 -3-5 2345          204       ,0    95,9
* 39 -3-5 -345          684       ,0    95,9
* 40 --4- 2345         2609       ,1    96,1
* 41 --4- 234-        10287       ,5    96,6
* 42 --4- 2-4-            5       ,0    96,6
* 43 --4- -34-          298       ,0    96,6
* 44 --4- -345         2877       ,1    96,7
* 45 --45 2345        16352       ,8    97,5
* 46 --45 -345        20266      1,0    98,5
* 47 ---5 2345         9544       ,5    98,9
* 48 ---5 23-5           58       ,0    98,9
* 49 ---5 -345         7842       ,4    99,3
* 50 ---5 -3-5           52       ,0    99,3
* 51 ---5 --45        14308       ,7   100,0
* ---------------------------------------------------------
* Gesamt            2081075    100,0                      .


* -----------------------------------------------------------------------------.
* ausftyp  Panelangaben zur Person   Auswahlbezirk 
*
*        0  2345 2345 := Angaben zu 2012-2015 fr Personen und Auswahlbez. 
*         
*        1  2--- 2--- := nur Angaben zu 2012 fr Personen und Auswahlbez. 
*                         ~ nicht informativer Ausfall (Rotationsgruppe ausgeschieden) ~
*            (...)
*       12  2--- 23-- := Angaben nur zu 2012 fr Personen, 2012-2013 fr Auswahlbez.
*                         ~ Wegzug, Todesfall ... ~
*            (...)
*       30  2--5 2345 := Angaben zu 2012 und 2015 fr Personen, 2012-2015 fr Auswahlbez.
*                         ~ temporrer Ausfall 2013 und 2014 ~ 
*           (...) 
*       47 ---5 2345  := Angaben zu 2015 fr Personen, 2012-2015 fr Auswahlbez.
*                         ~ Ausflle 2012-2014 aufgrund von Zuzgen oder Geburten ~
* --------
* Hinweis auf Differenzierungsmglichkeiten nach 
* EF45 Zuzug (i. d. letzten 12 Monaten): 
*      Code -5 Entfllt (Keine Wiederholungsbefragung)
*      = erstmals befragte Rotationsgruppe.
* -----------------------------------------------------------------------------.

* Recodierung Panelzeitpunkte.
recode file (1,2 = 1) (3, 4 = 2) (5, 6 = 3) (7=4) into t.
var lab t "Panelzeitpukt".
val lab t 1 "2012" 2 "2013" 3 "2014" 4 "2015".
formats t (f1.0).


* === Erste Ausfallanalysen ===.

* --- Zusammenfhrung der Daten auf Auswahlbezirksebene (PSU) ---.

* Zusammenfhrung 2012 und 2013 - PSU-Ebene, ohne Ausfallstze, 
*  Erhebungszeitpunkte 2012-2014.
temporary.
select if (psu_1=1 & ef63>0).
crosstabs t2_psu by t1_psu /cells count col.
*            0        1   Gesamt
*---------------------------------
* 0      19508     8543    28051
*        68,2%    25,4%    45,0%
* 1       9092    25134    34226
*        31,8%    74,6%    55,0%
*---------------------------------
* Gesamt 28600    33677    62277
*       100,0%   100,0%   100,0%  
*---------------------------------.


* Zusammenfhrung 2012 und 2015 - PSU-Ebene, ohne Ausfallstze, 
*   Erhebungszeitpunkte 2012-2015.
temporary.
select if (psu_1=1 & ef63>0).
crosstabs t4_psu by t1_psu /cells count col.
*                    0          1      Gesamt
*-------------------------------------------
*        0        2955      25389       28344 
*                10,3%      75,4%       45,5% 
*-------------------------------------------
*        1       25645       8288       33933 
*                89,7%      24,6%       54,5% 
*-------------------------------------------
*   Gesamt       28600      33677       62277 
*               100,0%     100,0%      100,00
* -------------------------------------------.


* temporary.
* 1. Personensatz.
* select if p1=1.
* crosstabs ausftyp by ptyp /missing include.

* Dateiname ggf. ndern.
save outfile = 'panel_12131415_v1.sav' /compressed.

* =============================================================================.

* 4 Files nebeneinander stellen (wide format).

sort cases by idpers.

casestovars
 /id    = idpers
 /index = t
 /count = count
 /fixed = ef1 s1 ef3 s3 ef4 s4 ef63 s63 ausfall n_t1 n_t2 n_t3 n_t4 ptyp 
          idpsu n_psu12 n_psu13 n_psu14 n_psu15 ptyp_psu ausftyp id12 
          t1_psu t2_psu t3_psu t4_psu 
 /separator = "_".

var label count 'Anzahl Stze in untereinander stehenden Daten'.

fre ptyp.
*        Hufigkeit
* -----------------
*  0 2345     90834
*  1 2---    174783
*  2 23--    135211
*  3 234-    111600
*  4 23-5       554
*  5 2-4-      1122
*  6 2-45       394
*  7 2--5        69
*  8 -3--     87416
*  9 -34-     23130
* 10 -345     78487
* 11 -3-5       667
* 12 --4-     64831
* 13 --45    157208
* 14 ---5    182790
* -----------------
* Gesamt    1109096 .


fre ptyp_psu.
*             Hufigkeit
* ----------------------
* -1 Ausfallsatz    6879
*  0 2345         183786
*  1 2---         128511
*  2 23--         150721
*  3 234-         164549
*  4 23-5            289
*  5 2-4-             18
*  8 -3--          38134
*  9 -34-           1666
* 10 -345         124850
* 11 -3-5            149
* 12 --4-           1625
* 13 --45         183988
* 14 ---5         123931
* ----------------------
* Gesamt         1109096 .


fre ausftyp.
*              Hufigkeit
* -----------------------
* -1 Ausfallstze  132497
*  0 2345|2345      88087
*  1 2---|2---     120644
*  2 23--|23--     109252
*  3 234-|234-      98110
*  4 23-5|23-5         37
*  5 -3--|-3--      35843
*  6 -34-|-34-        943
*  7 -345|-345      67965
*  8 -3-5|-3-5         27
*  9 --4-|--4-       1290
* 10 --45|--45     131114
* 11 ---5|---5     117580
* 12 2---|23--      13219
* 13 2---|234-      12384
* 14 2---|23-5         30
* 15 2---|2-4-          2
* 16 23--|234-       9664
* 17 23--|23-5         28
* 18 -3--|-34-        190
* 19 -3--|-345       9226
* 20 -3--|-3-5         18
* 21 -34-|-345       8741
* 22 --4-|--45      18318
* 23 2---|2345      12651
* 24 23--|2345       9574
* 25 234-|2345       9446
* 26 23-5|2345        314
* 27 2-4-|2345        148
* 28 2-4-|234-        431
* 29 2-45|2345        340
* 30 2--5|2345         51
* 31 -3--|2345       2710
* 32 -3--|23--      11076
* 33 -3--|234-       2541
* 34 -3--|23-5          3
* 35 -34-|2345       1891
* 36 -34-|234-       8587
* 37 -345|2345       7491
* 38 -3-5|2345        102
* 39 -3-5|-345        342
* 40 --4-|2345       2609
* 41 --4-|234-      10287
* 42 --4-|2-4-          5
* 43 --4-|-34-        298
* 44 --4-|-345       2877
* 45 --45|2345       8176
* 46 --45|-345      10133
* 47 ---5|2345       9544
* 48 ---5|23-5         58
* 49 ---5|-345       7842
* 50 ---5|-3-5         52
* 51 ---5|--45      14308
* -----------------------
* Gesamt          1109096 .


recode n_t1 (0=0) (1=1) into t1.
recode n_t2 (0=0) (1=1) into t2.
recode n_t3 (0=0) (1=1) into t3.
recode n_t4 (0=0) (1=1) into t4.

var lab t1 'Angaben zu 2012'.
var lab t2 'Angaben zu 2013'.
var lab t3 'Angaben zu 2014'.
var lab t4 'Angaben zu 2015'.
* val lab t1 t2 t3 t4 0 "nein" 1 "ja".
formats t1 t2 t3 t4 (f1.0).


* Angaben zu 2013 und 2012.
* - Befragtenstze incl. Ausfallstze.
crosstabs t2 by t1 /missing include.
*                0         1    Gesamt
* ------------------------------------
* 0         404829    176368    581197
* 1         189700    338199    527899
* ------------------------------------
* Gesamt    594529    514567   1109096 .


* Angaben zu 2014 und 2013.
crosstabs t3 by t2 /missing include.
*                0         1    Gesamt
* ------------------------------------
* 0         357642    223848    581490
* 1         223555    304051    527606
* ------------------------------------
* Gesamt    581197    527899   1109096 .


* Angaben zu 2015 und 2012.
crosstabs t4 by t1 /missing include.
*                0         1     Gesamt
* -------------------------------------
* 0         175377    422716     598093
* 1         419152     91851     511003
* -------------------------------------
* Gesamt    594529    514567    1109096 .


* Z. B. Bevlkerung Bevlkerung: Haupt- oder Nebenwohnsitz (ef30*) 
*  incl. Ausfallstze (ef30*=-8, -7) und Panelausflle (ef30*=.,99).
temporary.
recode ef30_4 ef30_1 (sysmis=99).
add val lab ef30_4 99 "sysmis".
add val lab ef30_1 99 "sysmis".
crosstabs ef30_4 by ef30_1 /missing include.
*                                                             -8      -7         1       2       3        99     Gesamt
* ---------------------------------------------------------------------------------------------------------------------
* -8 Entfllt (leerstehende Wohnung, ausgefallene Priv      2344       0         0       0       0     25619      27963
* -7 Entfllt (Auswahlbezirk ohne befragten Haushalt)          0     678         0       0       0     18799      19477
*  1 Bevlkerung am Hauptwohnsitz ohne weiteren Wohnsitz       0       0     85721    1009     447    364292     451469
*  2 Bevlkerung am Hauptwohnsitz mit weiterem Wohnsitz        0       0       613     374      58      6001       7046
*  3 Bevlkerung am Nebenwohnsitz (mit weiterem Wohnsitz       0       0       191      72     344      4441       5048
* 99 sysmis                                                24902    2231    383274    7323    4986    175377     598093
* ---------------------------------------------------------------------------------------------------------------------
* Gesamt                                                   27246    2909    469799    8778    5835    594529    1109096 .

* ============================================================================.

* Weitere Ausfallanalysen .

* Fr die Zusammenfhrung der Daten 2012 und 2013 wird fr 2012 eine 
* Zusammenfhrungsquote von 64,9 % und fr 2013 von 67,7 % 
* berichtet (Herter-Eschweiler/Schimpl-Neimanns 2018, S. 6).
* 
* Fr den Panelzeitpunkt t=2 (2013) sind aus der Erhebung 2014 Angaben aus den
* Jahresberhngen hinzugekommen. Werden diese bercksichtigt, ergeben sich
* andere Zusammenfhrungsquoten.


* 2012 Befragte mit gltigen Angaben (ohne Ausfallstze) und mit Angaben 
* zu 2013.
temporary.
select if (ef30_1>=1 & ef30_1<=3) | (ef30_2>=1 & ef30_2<=3).
crosstabs t2 by t1 /missing include /cell count col.
*               0         1     Gesamt
* ------------------------------------
* 0             0    159900     159900
*             0,0%    33,0%      24,9%
* 
* 1         157696    324512    482208
*           100,0%     67,0%     75,1%
* ------------------------------------
* Gesamt    157696    484412    642108
*           100,0%    100,0%    100,0%

* -----------------------------------------------------------------------------.

* Differenzierung von Ausfallgrnden - der Fall neuer Rotationsgruppen.
* 
* Siehe Herter-Eschweiler/Schimpl-Neimanns (2018, S. 8: 
* "Nhere Aufklrungen fehlender Angaben zum Zeitpunkt t (2012) knnen mit den 
* Angaben der Erhebung t + 1 (2013) zum Zuzug in den letzten 12 Monaten (EF45) 
* oder zum Wohnsitz vor 12 Monaten (EF451, ohne Auskunftspflicht) ermittelt 
* werden." 
* Der Code EF45 = -5 "Entfllt (Keine Wiederholungsbefragung)" weist darauf hin, 
* dass eine neue Rotationsgruppe erstmals befragt wurde.
* Beispiel:
* Fr die nicht zusammenfhrbaren (gltigen) Personenstze der Paneljahre 2012 und 
* 2013 (t1=0 & t2=1) soll geprft werden, ob die Ausflle mit erstmals befragten
* Rotationsgruppen bedingt zusammenhngen. 
	
temporary.
select if (ef30_1>=1 & ef30_1<=3) | (ef30_2>=1 & ef30_2<=3) & t1=0 & t2=1.
crosstabs ausftyp by ef45_2.
*               -5 Entf       1 Ja    8 Nein  9 K.Ang.    Gesamt
* --------------------------------------------------------------
*  0 2345|2345        0        182     87899         6     88087
*  2 23--|23--        0        238    109014         0    109252
*  3 234-|234-        0        179     97927         4     98110
*  4 23-5|23-5        0          0        37         0        37
*  5 -3--|-3--     34922       418       503         0     35843
*  6 -34-|-34-       331       221       391         0       943
*  7 -345|-345     67474       125       366         0     67965
*  8 -3-5|-3-5        27         0         0         0        27
* 16 23--|234-         0        71      9592         1      9664
* 17 23--|23-5         0         0        28         0        28
* 18 -3--|-34-       109        34        47         0       190
* 19 -3--|-345      9169        15        42         0      9226
* 20 -3--|-3-5        18         0         0         0        18
* 21 -34-|-345      8643        23        75         0      8741
* 24 23--|2345         0        74      9499         1      9574
* 25 234-|2345         0        41      9402         3      9446
* 26 23-5|2345         0         2       312         0       314
* 31 -3--|2345         0      2113       597         0      2710
* 32 -3--|23--         0      9231      1843         2     11076
* 33 -3--|234-         0      2010       531         0      2541
* 34 -3--|23-5         0         3         0         0         3
* 35 -34-|2345         0      1489       402         0      1891
* 36 -34-|234-         0      7215      1369         3      8587
* 37 -345|2345         0      6003      1488         0      7491
* 38 -3-5|2345         0        62        40         0       102
* 39 -3-5|-345       342         0         0         0       342
* --------------------------------------------------------------
* Gesamt          121035     29749    331404        20    482208 .

* 25,1 % (= 121035 / 482208) der Ausflle sind durch eine neue Rotationsgruppe 
*    bedingt (ef45_2 = -5).

* -----------------------------------------------------------------------------.

* 2012 Befragte mit gltigen Angaben (ohne Ausfallstze) und mit Angaben zu 
*      2015.
temporary.
select if ((ef30_1>=1 & ef30_1<=3) | (ef30_4>=1 & ef30_4<=3)) & t1=1.
fre ausftyp ptyp.
* 
* ausftyp   Hufigkeit Prozent  Kumulierte Prozente
* -------------------------------------------------
*  0 2345|2345   88087    18,2    18,2
*  1 2---|2---  120644    24,9    43,1
*  2 23--|23--  109252    22,6    65,6
*  3 234-|234-   98110    20,3    85,9
*  4 23-5|23-5      37      ,0    85,9
* 12 2---|23--   13219     2,7    88,6
* 13 2---|234-   12384     2,6    91,2
* 14 2---|23-5      30      ,0    91,2
* 15 2---|2-4-       2      ,0    91,2
* 16 23--|234-    9664     2,0    93,2
* 17 23--|23-5      28      ,0    93,2
* 23 2---|2345   12651     2,6    95,8
* 24 23--|2345    9574     2,0    97,8
* 25 234-|2345    9446     1,9    99,7
* 26 23-5|2345     314      ,1    99,8
* 27 2-4-|2345     148      ,0    99,8
* 28 2-4-|234-     431      ,1    99,9
* 29 2-45|2345     340      ,1   100,0
* 30 2--5|2345      51      ,0   100,0
* ------------------------------------
* Gesamt        484412   100,0        .

* ptyp  Hufigkeit    Prozent Kumulierte Prozente
* -----------------------------------------------
* 0 2345     88087       18,2       18,2
* 1 2---    158930       32,8       51,0
* 2 23--    128518       26,5       77,5
* 3 234-    107556       22,2       99,7
* 4 23-5       351         ,1       99,8
* 5 2-4-       579         ,1       99,9
* 6 2-45       340         ,1      100,0
* 7 2--5        51         ,0      100,0
* --------------------------------------
* Gesamt    484412      100,0           .

* ============================================================================.

* Zusammenfhrung 2012 und 2015 - PSU-Ebene, ohne Ausfallstze, 
*   Erhebungszeitpunkte 2012-2015.
temporary.
select if ef63>0.
crosstabs t4_psu by t1_psu /cells count col.
*                 0          1     Gesamt
* ---------------------------------------
* 0            2955      25389      28344
*             10,3%      75,4%      45,5%
* 
* 1           25645       8288      33933
*             89,7%      24,6%      54,5%
* ---------------------------------------
* Gesamt      28600      33677      62277
*            100,0%     100,0%     100,0% .


* =============================================================================.

* 5   Beispielanalysen zur Antwortkonsistenz (Geschlecht und Geburtsjahr).

* (1) Antwortkonsistenz Geschlecht (ohne Ausfallstze).

* Tabelle einschlielich inkonsistenter Angaben fr Panelzeitpunkte 2012-2015,
*   ohne Ausfallstze.
temporary.
* Insgesamt.
select if (ptyp=0 & ausfall=0).
* darunter: konsistente Angaben  (k).
compute k = 0.
if (ptyp=0 & ausfall=0 & ef46_1=ef46_2 & ef46_1=ef46_3 & ef46_1=ef46_4) k=1.
fre k.
* Der Anteil konsistenter Angaben zum Geschlecht betrgt rund 99 %.

* -----------------------------------------------------------------------------.

* (2) Antwortkonsistenz Geburtsjahr fr Geburtsjahrgnge 1917 - 2012
*     (Unterschiedliche Zusammenfassungen fr Geburtsjahrgnge vor 1917).
temporary.
select if (ptyp=0 & ausfall=0).
select if ( (ef47_1>=1917 & ef47_1<=2012) &
            (ef47_2>=1917 & ef47_2<=2012) &
            (ef47_3>=1917 & ef47_3<=2012) &
            (ef47_4>=1917 & ef47_4<=2012) ).
* darunter: konsistente Angaben (k).
compute k = 0.
if (ef47_1 = ef47_2 & ef47_1=ef47_3 & ef47_1=ef47_4) k = 1.
fre k.

* Der Anteil konsistenter Angaben zum Geburtsjahr betrgt rund 95 %.


* ============================================================================.

* ID Haushalte ohne Kennung fr Jahresberhnge.

* Verkettung der Ordnungsnummern zum alphanumerischen Indikator idhh.
string idhh (A11).
compute idhh = concat(char.rpad(s1,2),char.rpad(s3,6),char.rpad(s4,3)).
var lab idhh 'ID Haushalt (ef1 ef3 ef4)'.
execute.

* Variablen Label ergnzen.
var lab EF45_1  'EF45_1: Zuzug (i. d. letzten 12 Monaten)'.
var lab EF45_2  'EF45_2: Zuzug (i. d. letzten 12 Monaten)'.
var lab EF45_3  'EF45_3: Zuzug (i. d. letzten 12 Monaten)'.
var lab EF45_4	'EF45_4: Zuzug (i. d. letzten 12 Monaten)'.
var lab EF46_1  'EF46_1: Geschlecht'.
var lab EF46_2  'EF46_2: Geschlecht'.
var lab EF46_3  'EF46_3: Geschlecht'.
var lab EF46_4  'EF46_4: Geschlecht'.
var lab EF47_1  'EF47_1: Geburtsjahr'.
var lab EF47_2  'EF47_2: Geburtsjahr'.
var lab EF47_3  'EF47_3: Geburtsjahr'.
var lab EF47_4  'EF47_4: Geburtsjahr'.
var lab EF451_1 'EF451_1: Selber Wohnsitz (vor einem Jahr) (FB)'.
var lab EF451_2 'EF451_2: Selber Wohnsitz (vor einem Jahr) (FB)'.
var lab EF451_3 'EF451_3: Selber Wohnsitz (vor einem Jahr) (FB)'.
var lab EF451_4 'EF451_4: Selber Wohnsitz (vor einem Jahr) (FB)'.
var lab s1 'Bundesland'.
var lab s3 'Nr. des Auswahlbezirks (systemfrei)'.
var lab s4 'Nr. des Haushalts im Auswahlbezirk (systemfrei)'.
var lab s63 'Personennummer'.
var lab n_t1 'Angaben zu 2012 (Person)'.
var lab n_t2 'Angaben zu 2013 (Person)'.
var lab n_t3 'Angaben zu 2014 (Person)'.
var lab n_t4 'Angaben zu 2015 (Person)'.
var lab psu12_1 'Stichprobe 2012 (gltige Angaben in EF4 und EF5b) - t1'.
var lab psu12_2 'Stichprobe 2012 (gltige Angaben in EF4 und EF5b) - t2'.
var lab psu12_3 'Stichprobe 2012 (gltige Angaben in EF4 und EF5b) - t3'.
var lab psu12_4 'Stichprobe 2012 (gltige Angaben in EF4 und EF5b) - t4'.
var lab psu13_1 'Stichprobe 2013 (gltige Angaben in EF4 und EF5b) - t1'.
var lab psu13_2 'Stichprobe 2013 (gltige Angaben in EF4 und EF5b) - t2'.
var lab psu13_3 'Stichprobe 2013 (gltige Angaben in EF4 und EF5b) - t3'.
var lab psu13_4 'Stichprobe 2013 (gltige Angaben in EF4 und EF5b) - t4'.
var lab psu14_1 'Stichprobe 2014 (gltige Angaben in EF4 und EF5b) - t1'.
var lab psu14_2 'Stichprobe 2014 (gltige Angaben in EF4 und EF5b) - t2'.
var lab psu14_3 'Stichprobe 2014 (gltige Angaben in EF4 und EF5b) - t3'.
var lab psu14_4 'Stichprobe 2014 (gltige Angaben in EF4 und EF5b) - t4'.
var lab psu15_1 'Stichprobe 2015 (gltige Angaben in EF4 und EF5b) - t1'.
var lab psu15_2 'Stichprobe 2015 (gltige Angaben in EF4 und EF5b) - t2'.
var lab psu15_3 'Stichprobe 2015 (gltige Angaben in EF4 und EF5b) - t3'.
var lab psu15_4 'Stichprobe 2015 (gltige Angaben in EF4 und EF5b) - t4'.

* Nicht bentigte Variablen lschen, ggf. nicht lschen.
save outfile = 'panel_12131415_v1w.sav'
   /drop =  p1_1    p1_2    p1_3    p1_4
            psu_1_1 psu_1_2 psu_1_3 psu_1_4
            psu12_1 psu12_2 psu12_3 psu12_4
            psu13_1 psu13_2 psu13_3 psu13_4
            psu14_1 psu14_2 psu14_3 psu14_4
            psu15_1 psu15_2 psu15_3 psu15_4 
   /compressed /map.
execute.

* === Programmende === .


